@@ -23,10 +23,8 @@
 /******************************************************************************
                                              REAL PROCEDURE ARCTAN2(r)       */
 
-double 
-__rarctan2 (r, s)
-     double r,
-       s;
+#include <math.h>
+double __rarctan2 (double r, double s)
 {
   return (atan2 (r, s));
 }
