@@ -19,12 +19,19 @@
 
 #include "cim.h"
 #include "align.h"
+#include "config.h"
+
+#if STDC_HEADERS || HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+
 
 /******************************************************************************
                                                         RutineBlockEnd       */
 
-void
-__rbe ()
+void __rbe (void)
 {
   __dhp x;
   long size;
