@@ -17,17 +17,15 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /* Bytefile */
 
 /******************************************************************************
                                          INTEGER PROCEDURE BYTESIZE          */
 
-long 
-__rbytesize (p)
-     __bs7FILE *p;
+long __rbytesize (__bs7FILE *p)
 {
   return (p->bytesize);
 }
