@@ -24,9 +24,7 @@
 /******************************************************************************
                                              RutineCopyArray                 */
 
-__dhp
-__rca (a)
-     __arrp a;
+__dhp __rca (__arrp a)
 {
   register __dhp *p,
    *q,
