@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          BOOLEAN PROCEDURE CLOSE             */
 
-char 
-__rdbclose (p)
-     __bs10FILE *p;
+char __rdbclose (__bs10FILE *p)
 {
   if (((__bs1FILE *) p)->open)
     {
