@@ -17,8 +17,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /* CHECKPOINT er lik den i DIRECTFILE */
 
@@ -27,9 +27,7 @@
 /******************************************************************************
                                          BOOLEAN PROCEDURE ENDFILE           */
 
-char 
-__rdbendfile (p)
-     __bs10FILE *p;
+char __rdbendfile (__bs10FILE *p)
 {
   return (((__bs1FILE *) p)->open && p->loc > __rdblastloc (p));
 }
