@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          (SHORT) INTEGER PROCEDURE INBYTE    */
 
-long 
-__rdbinbyte (p)
-     __bs10FILE *p;
+long __rdbinbyte (__bs10FILE *p)
 {
   long c;
   if (p->writeonly)
