@@ -17,16 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          TEXT PROCEDURE INTEXT(t)            */
 
-__txtvp
-__rdbintext (p, t)
-     __bs10FILE *p;
-     __txtvp t;
+__txtvp __rdbintext (__bs10FILE *p, __txtvp t)
 {
   __rtsetpos (t, 1L);
   while (__rtmore (t) & !((__bs7FILE *) p)->endfile)
