@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          INTEGER PROCEDURE LASTLOC           */
 
-long 
-__rdblastloc (p)
-     __bs10FILE *p;
+long __rdblastloc (__bs10FILE *p)
 {
   long i;
   if (fseek (((__bs1FILE *) p)->file, 0L, 2) == __EOF)
