@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          INTEGER PROCEDURE LOCATION          */
 
-long 
-__rdblocation (p)
-     __bs10FILE *p;
+long __rdblocation (__bs10FILE *p)
 {
   return (p->loc);
 }
