@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                            BOOLEAN PROCEDURE LOCKED          */
 
-char 
-__rdblocked (p)
-     __bs10FILE *p;
+char __rdblocked (__bs10FILE *p)
 {
   return (p->locked);
 }
