@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          BOOLEAN PROCEDURE CHECKPOINT        */
 
-char 
-__rdcheckpoint (p)
-     __bs5FILE *p;
+char __rdcheckpoint (__bs5FILE *p)
 {
   if (fflush (((__bs1FILE *) p)->file) == __EOF)
     return (__FALSE);
