@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                         INTEGER PROCEDURE LASTLOC            */
 
-long 
-__rdlastloc (p)
-     __bs5FILE *p;
+long __rdlastloc (__bs5FILE *p)
 {
   long pos,
     len;
