@@ -17,16 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          PROCEDURE LOCATE                    */
 
-__dhp 
-__rdlocate (p, i)
-     __bs5FILE *p;
-     long i;
+__dhp __rdlocate (__bs5FILE *p, long i)
 {
   if ((i < 1) | (i > p->maxloc))
     __rerror ("Locate: Parameter out of range");
