@@ -17,8 +17,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /* RUNTIME rutiner for klassen directfile  skrevet i c. */
 
@@ -28,9 +28,7 @@
 /* PS !!! HVIS DET IKKE SKAL V]RE NOEN TESTER INNE I LOCATE S] KAN ALLE
  * KALL rdlocate(((__bs5FILE *)p)->loc) SLETTES. */
 
-long 
-__rdlocation (p)
-     __bs5FILE *p;
+long __rdlocation (__bs5FILE *p)
 {
   return (p->loc);
 }
