@@ -17,20 +17,15 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
 #include "config.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          PROCEDURE LOCK                      */
 
 /*ARGSUSED */
-long 
-__rdlock (p, t, i, j)
-     __bs5FILE *p;
-     double t;
-     long i,
-       j;
+long __rdlock (__bs5FILE *p, double t, long i, long j)
 {
   long lock = -1;
   if (t > 0.0)
