@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          BOOLEAN PROCEDURE LOCKED            */
 
-char 
-__rdlocked (p)
-     __bs5FILE *p;
+char __rdlocked (__bs5FILE *p)
 {
   return (p->locked);
 }
