@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          INTEGER PROCEDURE MAXLOC            */
 
-long 
-__rdmaxloc (p)
-     __bs5FILE *p;
+long __rdmaxloc (__bs5FILE *p)
 {
   if (!((__bs1FILE *) p)->open)
     __rerror ("Maxloc: File not open");
