@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          BOOLEAN PROCEDURE UNLOCK            */
 
-char 
-__rdunlock (p)
-     __bs5FILE *p;
+char __rdunlock (__bs5FILE *p)
 {
   char c;
   c = __rdcheckpoint (p);
