@@ -18,14 +18,12 @@
  */
 
 #include "cim.h"
-#include "config.h"
+#include "limit.h"
 
 /******************************************************************************
                                             INTEGER PROCEDURE ENTIER(r)      */
 
-long 
-__rentier (r)
-     double r;
+long __rentier (double r)
 {
   long j;
   if ((r >= ((double) MAX_INT) + 1.0) ||
