@@ -18,12 +18,15 @@
  */
 
 #include "file.h"
+#if STDC_HEADERS
+#include <stdlib.h>
+#endif
+
 
 /******************************************************************************
                                                                 RutineERROR  */
 
-__rerror (s)
-     char *s;
+void *__rerror (char *s)
 {
   __rprintfilline ();
   (void) fprintf (stderr, "%s: %s\n", __progname, s);
