@@ -19,6 +19,13 @@
 
 #include "cim.h"
 #include "align.h"
+#include "config.h"
+
+#if STDC_HEADERS || HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
 
 /******************************************************************************
                                                         RutineEndThunk       */
@@ -26,8 +33,7 @@
 /* Denne rutinen kalles for aa terminere en thunk og pr|ver } deallokere
  * objektet. */
 
-void
-__reth ()
+void __reth (void)
 {
   __dhp x;
   __goto = __pb->ex;
