@@ -17,16 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                                 TEXT PROCEDURE FILENAME      */
 
-__txtvp 
-__rfilename (as, p)
-     __bs1FILE *p;
-     long as;
+__txtvp __rfilename (long as, __bs1FILE *p)
 {
   return (__rcopy (as, &p->filename));
 }
