@@ -17,9 +17,16 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
 #include "align.h"
-#include "simfile.h"
+#include "config.h"
+
+#if STDC_HEADERS || HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
 
 /******************************************************************************
                                                        DO_FOR_STACK_POINTERS */
@@ -30,9 +37,7 @@
  * Dessuten kalles den ogs} fra add_to_pointers i det tilfellet 
  * at poolen blir flyttet */
 
-static
-do_for_stack_pointers (doit)
-     void (*doit) ();
+static do_for_stack_pointers (void (*doit) ())
 {
   int i,
     ar,
@@ -57,10 +62,7 @@ do_for_stack_pointers (doit)
  * Dessuten kalles den ogs} fra add_to_pointers i det tilfellet 
  * at poolen blir flyttet */
 
-__do_for_each_pointer (p, doit, doit_notest)
-     __dhp p;
-     void (*doit) (),
-  (*doit_notest) ();
+void __do_for_each_pointer (__dhp p, void (*doit) (), void (*doit_notest) ())
 {
   __dhp *ph,
    *qh;
@@ -68,7 +70,7 @@ __do_for_each_pointer (p, doit, doit_notest)
   long i,
     j;
 
-  switch ((int) p->pp)
+  switch ((long int) p->pp)
     {
     case __TEXT:
       break;
@@ -126,12 +128,10 @@ __do_for_each_pointer (p, doit, doit_notest)
 
 /* Denne rutinen finner st|rrelsen p} et data objekt inklusive alignment */
 
-static long
-get_size (p)
-     __dhp p;
+static long get_size (__dhp p)
 {
   long size;
-  switch ((int) p->pp)
+  switch ((long int) p->pp)
     {
     case __TEXT:
       size = ((__textref) p)->h.size + sizeof (__th) + 1;
@@ -163,9 +163,7 @@ static __dhp p;
  * hjelp av GB-ordet. Objekter blir kjedet inn rett bak p.
  * P peker en hver tid p} det objektet som er under prosessering. */
 
-static
-do_add_to_list (qp)
-     __dhp *qp;
+static void do_add_to_list (__dhp *qp)
 {
   __dhp q;
   if ((q = *qp) != __NULL)
@@ -186,9 +184,7 @@ do_add_to_list (qp)
  * til et objekt ligger i objektets GB-ord. 
  * Denne informasjonen er lagt i GB-ordet av GBC pass 2 */
 
-static
-do_update_pointer (qp)
-     __dhp *qp;
+static void do_update_pointer (__dhp *qp)
 {
   if (*qp != __NULL)
     *qp = (*qp)->gl;
@@ -203,8 +199,7 @@ do_update_pointer (qp)
  * 3. pass oppdaterer pekere
  * 4. pass skyver de aksesserbare objektene sammen */
 
-void
-__rgbc ()
+void __rgbc (void)
 {
   static __dhp hppp;
   static __dhp hpp;
@@ -227,16 +222,16 @@ __rgbc ()
   do_add_to_list (&__pb);
   do_add_to_list (&__sl);
   do_add_to_list (&__er);
-  do_add_to_list (&__t1.obj);
-  do_add_to_list (&__t2.obj);
+  do_add_to_list ((__dhp *) &__t1.obj);
+  do_add_to_list ((__dhp *) &__t2.obj);
 
   do_for_stack_pointers (do_add_to_list);
 
   __do_for_each_stat_pointer (do_add_to_list, do_add_to_list, __FALSE);
 
-  __do_for_each_pointer (&__sysin, do_add_to_list, do_add_to_list);
-  __do_for_each_pointer (&__sysout, do_add_to_list, do_add_to_list);
-  __do_for_each_pointer (&__syserr, do_add_to_list, do_add_to_list);
+  __do_for_each_pointer ((__dhp) &__sysin, do_add_to_list, do_add_to_list);
+  __do_for_each_pointer ((__dhp) &__sysout, do_add_to_list, do_add_to_list);
+  __do_for_each_pointer ((__dhp) &__syserr, do_add_to_list, do_add_to_list);
 
   while (p != &__nil)
     {
@@ -268,9 +263,9 @@ __rgbc ()
   do_for_stack_pointers (do_update_pointer);
 
   __do_for_each_stat_pointer (do_update_pointer, do_update_pointer, __FALSE);
-  __do_for_each_pointer (&__sysin, do_update_pointer, do_update_pointer);
-  __do_for_each_pointer (&__sysout, do_update_pointer, do_update_pointer);
-  __do_for_each_pointer (&__syserr, do_update_pointer, do_update_pointer);
+  __do_for_each_pointer ((__dhp) &__sysin, do_update_pointer, do_update_pointer);
+  __do_for_each_pointer ((__dhp) &__sysout, do_update_pointer, do_update_pointer);
+  __do_for_each_pointer ((__dhp) &__syserr, do_update_pointer, do_update_pointer);
 
   p = __min;
 
@@ -287,8 +282,8 @@ __rgbc ()
   do_update_pointer (&__pb);
   do_update_pointer (&__sl);
   do_update_pointer (&__er);
-  do_update_pointer (&__t1.obj);
-  do_update_pointer (&__t2.obj);
+  do_update_pointer ((__dhp *) &__t1.obj);
+  do_update_pointer ((__dhp *) &__t2.obj);
 
   /* PAS 4 */
   p = q = __min;
@@ -334,25 +329,22 @@ static long disp;
 static char *new_fri,
  *new_min;
 
-static
-do_add_to_pointer (qp)
-     __dhp *qp;
+static void do_add_to_pointer (__dhp *qp)
 {
   if (*qp >= __min & *qp < __fri)
     *qp = (__dhp) ((char *) (*qp) + disp);
 }
 
-static
-add_to_pointers ()
+static void add_to_pointers (void)
 {
   char *p;
 
   do_for_stack_pointers (do_add_to_pointer);
 
   __do_for_each_stat_pointer (do_add_to_pointer, do_add_to_pointer, __TRUE);
-  __do_for_each_pointer (&__sysin, do_add_to_pointer, do_add_to_pointer);
-  __do_for_each_pointer (&__sysout, do_add_to_pointer, do_add_to_pointer);
-  __do_for_each_pointer (&__syserr, do_add_to_pointer, do_add_to_pointer);
+  __do_for_each_pointer ((__dhp) &__sysin, do_add_to_pointer, do_add_to_pointer);
+  __do_for_each_pointer ((__dhp) &__sysout, do_add_to_pointer, do_add_to_pointer);
+  __do_for_each_pointer ((__dhp) &__syserr, do_add_to_pointer, do_add_to_pointer);
 
   p = new_min;
 
@@ -377,9 +369,7 @@ add_to_pointers ()
  * Blir poolen flyttet s} blir add_to_pointers kalt for } oppdatere pekere,
  * og nytt omr}de blir fylt med nuller. */
 
-__dhp
-__ralloc (size)
-     long size;
+__dhp __ralloc (long size)
 {
   void __rgbc ();
   static __dhp mem;
