@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                                         RutineGoto           */
 
-void
-__rgoto (ob)
-     __dhp ob;
+void __rgoto (__dhp ob)
 {
   __dhp x;
 
