@@ -17,17 +17,15 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /* Inbytefile */
 
 /******************************************************************************
                                          BOOLEAN PROCEDURE ENDFILE           */
 
-char 
-__ribendfile (p)
-     __bs8FILE *p;
+char __ribendfile (__bs8FILE *p)
 {
   return (((__bs7FILE *) p)->endfile);
 }
