@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          (SHORT) INTEGER PROCEDURE INBYTE    */
 
-long 
-__ribinbyte (p)
-     __bs8FILE *p;
+long __ribinbyte (__bs8FILE *p)
 {
   long c;
   if (((__bs7FILE *) p)->endfile == __TRUE)
