@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          CHARACTER PROCEDURE INCHAR          */
 
-char 
-__riinchar (p)
-     __bs2FILE *p;
+char __riinchar (__bs2FILE *p)
 {
   if (!__rtmore (&(p->IMAGE)))
     {				/* Sorger for at riktige inimage kalles */
