@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                            INTEGER PROCEDURE ININT           */
 
-long 
-__riinint (p)
-     __bs2FILE *p;
+long __riinint (__bs2FILE *p)
 {
   __txt t;
   long inint;
