@@ -17,16 +17,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
 #include "config.h"
-#include "simfile.h"
 
 /******************************************************************************
                                            REAL PROCEDURE INREAL             */
 
-double 
-__riinreal (p)
-     __bs2FILE *p;
+double __riinreal (__bs2FILE *p)
 {
   __txt t;
   double inreal;
