@@ -17,22 +17,17 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                           TEXT PROCEDURE INTEXT              */
 
-__txtvp 
-__riintext (as, p, w)
-     __bs2FILE *p;
-     long as,
-       w;
+__txtvp __riintext (long as, __bs2FILE *p, long w)
 {
   long i;
-  __er = (__dhp) p;
   (void) __rblanks (as, w);
   for (i = 0; i < w; i++)
-    __et.obj->string[i] = __riinchar (__er);
+    __et.obj->string[i] = __riinchar (p);
   return (&__et);
 }
