@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          BOOLEAN PROCEDURE LASTITEM          */
 
-char 
-__rilastitem (p)
-     __bs2FILE *p;
+char __rilastitem (__bs2FILE *p)
 {
   char c;
   if (p->IMAGE.obj == __NULL)
