@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                                 INTEGER PROCEDURE ISOPEN     */
 
-char 
-__risopen (p)
-     __bs1FILE *p;
+char __risopen (__bs1FILE *p)
 {
   return (p->open);
 }
