@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                                                LENGTH        */
 
-long 
-__rlength (p)
-     __bs2FILE *p;
+long __rlength (__bs2FILE *p)
 {
   return ((long) p->IMAGE.length);
 }
