@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                                               MORE           */
 
-char 
-__rmore (p)
-     __bs2FILE *p;
+char __rmore (__bs2FILE *p)
 {
   if (p->IMAGE.obj == __NULL)
     return (__FALSE);
