@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          BOOLEAN PROCEDURE CLOSE             */
 
-char 
-__robclose (p)
-     __bs9FILE *p;
+char __robclose (__bs9FILE *p)
 {
   if (((__bs1FILE *) p)->open)
     {
