@@ -17,15 +17,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 /******************************************************************************
                                          PROCEDURE OUTBYTE(x)                */
 
-__dhp 
-__roboutbyte (p, x)
-     __bs9FILE *p;
-     long x;
+__dhp __roboutbyte (__bs9FILE *p, long x)
 {
   if (!((__bs1FILE *) p)->open)
     __rerror ("Outbyte: File closed");
