@@ -17,16 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          PROCEDURE OUTTEXT(t)                */
 
-__dhp 
-__robouttext (p, t)
-     __bs9FILE *p;
-     __txtvp t;
+__dhp __robouttext (__bs9FILE *p, __txtvp t)
 {
   __rtsetpos (t, 1L);
   while (__rtmore (t))
