@@ -17,16 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          PROCEDURE OUTCHAR(c)                */
 
-__dhp 
-__rooutchar (p, c)
-     __bs2FILE *p;
-     char c;
+__dhp __rooutchar (__bs2FILE *p, char c)
 {
   if (!__rtmore (&(p->IMAGE)))
     {				/* Sorger for at riktige outimage kalles */
