@@ -17,15 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "file.h"
-#include "simfile.h"
 
 /******************************************************************************
                                         PROCEDURE OUTRECORD                  */
 
-__dhp 
-__rooutrecord (p)
-     __bs2FILE *p;
+__dhp __rooutrecord (__bs2FILE *p)
 {
   char *s;
   register long i,
