@@ -17,16 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          PROCEDURE OUTTEXT(t)                */
 
-__dhp 
-__roouttext (p, t)
-     __bs2FILE *p;
-     __txtvp t;
+__dhp __roouttext (__bs2FILE *p, __txtvp t)
 {
   register long i;
   char *s;
