@@ -17,8 +17,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /* CHECKPOINT er lik den i DIRECTFILE */
 
@@ -27,9 +27,7 @@
 /******************************************************************************
                                          INTEGER PROCEDURE LINE              */
 
-long 
-__rpline (p)
-     __bs6FILE *p;
+long __rpline (__bs6FILE *p)
 {
   return (p->line);
 }
