@@ -17,17 +17,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "config.h"
-#include "simfile.h"
+#include "limit.h"
 
 /******************************************************************************
                                          INTEGER PROCEDURE LINESPERPAGE      */
 
-long 
-__rplinesperpage (p, n)
-     __bs6FILE *p;
-     long n;
+long __rplinesperpage (__bs6FILE *p, long n)
 {
   long i;
   i = p->lines_per_page;
