@@ -17,14 +17,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 /******************************************************************************
                                          INTEGER PROCEDURE PAGE              */
 
-long 
-__rppage (p)
-     __bs6FILE *p;
+long __rppage (__bs6FILE *p)
 {
   return (p->page);
 }
