@@ -17,16 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                          PROCEDURE SPACING                   */
 
-__dhp 
-__rpspacing (p, n)
-     __bs6FILE *p;
-     long n;
+__dhp __rpspacing (__bs6FILE *p, long n)
 {
   if (0 <= n && n <= p->lines_per_page)
     p->spacing = n;
