@@ -17,7 +17,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "config.h"
+#include "limit.h"
 #include "cim.h"
 
 #if SIZEOF_LONG == 8
