@@ -19,12 +19,18 @@
 
 #include "cim.h"
 #include "align.h"
+#include "config.h"
+
+#if STDC_HEADERS || HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
 
 /******************************************************************************
                                                         RutineRestoreStack   */
 
-void
-__rrs ()
+void __rrs (void)
 {
   long i;
   __stkp x;
