@@ -17,18 +17,15 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /* Run time rutiner for klassen IMAGEFILE */
 
 /******************************************************************************
                                                             SETPOS           */
 
-__dhp 
-__rsetpos (p, i)
-     __bs2FILE *p;
-     long i;
+__dhp __rsetpos (__bs2FILE *p, long i)
 {
   p->IMAGE.pos = ((i < 1 || i > p->IMAGE.length + 1) ? p->IMAGE.length + 1 : i);
   return ((__dhp) p);
