@@ -16,10 +16,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */
 
-void __m_SIMENVIR()
+void __m_SIMENVIR(void)
 {
 }
 
-void __init_SIMENVIR()
+void __init_SIMENVIR(void)
 {
 }
