@@ -1,9 +1,9 @@
 /*Cim_ccode*/
-#include "./cim.h"
+#include "../../lib/cim.h"
 void __m_SIMSET();
-__map __mapSIMSET[3]={"./simset.sim",0L,1L,
+__map __mapSIMSET[3]={"../../lib/simset.sim",0L,1L,
 "",-123L,124L,
-"",0L,2147483647L};
+"",0L,9223372036854775807L};
 typedef struct /*  */
     {
         __dh h;
@@ -158,18 +158,20 @@ typedef struct /* FOLLOW */
     {
         __dh h;
 	__dhp  PTR;
+        __dhp __r1;
     } __bs213;
-short __rl213SIMSET[1]={(short)((char *)&((__bs213 *)0)->PTR-(char *)0),};
+short __rl213SIMSET[2]={(short)((char *)&((__bs213 *)0)->__r1-(char *)0),(short)((char *)&((__bs213 *)0)->PTR-(char *)0),};
 extern __ptyp __p213SIMSET;__pty   __pl213SIMSET[1]={&__p213SIMSET};
-__ptyp __p213SIMSET={'P',0,4,sizeof(__bs213),15,__m_SIMSET,0,0,1,0,__rl213SIMSET,0,__pl213SIMSET,__NULL};
+__ptyp __p213SIMSET={'P',0,4,sizeof(__bs213),15,__m_SIMSET,0,0,2,0,__rl213SIMSET,0,__pl213SIMSET,__NULL};
 typedef struct /* PRECEDE */
     {
         __dh h;
 	__dhp  PTR;
+        __dhp __r1;
     } __bs214;
-short __rl214SIMSET[1]={(short)((char *)&((__bs214 *)0)->PTR-(char *)0),};
+short __rl214SIMSET[2]={(short)((char *)&((__bs214 *)0)->__r1-(char *)0),(short)((char *)&((__bs214 *)0)->PTR-(char *)0),};
 extern __ptyp __p214SIMSET;__pty   __pl214SIMSET[1]={&__p214SIMSET};
-__ptyp __p214SIMSET={'P',0,4,sizeof(__bs214),16,__m_SIMSET,0,0,1,0,__rl214SIMSET,0,__pl214SIMSET,__NULL};
+__ptyp __p214SIMSET={'P',0,4,sizeof(__bs214),16,__m_SIMSET,0,0,2,0,__rl214SIMSET,0,__pl214SIMSET,__NULL};
 typedef struct /* INTO */
     {
         __dh h;
@@ -223,123 +225,126 @@ typedef struct /* CLEAR */
         __dh h;
 	__dhp  PTR;
 	__dhp  PTRSUC;
+        __dhp __r1;
     } __bs221;
-short __rl221SIMSET[2]={(short)((char *)&((__bs221 *)0)->PTR-(char *)0),(short)((char *)&((__bs221 *)0)->PTRSUC-(char *)0),};
+short __rl221SIMSET[3]={(short)((char *)&((__bs221 *)0)->__r1-(char *)0),(short)((char *)&((__bs221 *)0)->PTR-(char *)0),(short)((char *)&((__bs221 *)0)->PTRSUC-(char *)0),};
 extern __ptyp __p221SIMSET;__pty   __pl221SIMSET[1]={&__p221SIMSET};
-__ptyp __p221SIMSET={'P',0,4,sizeof(__bs221),25,__m_SIMSET,0,0,2,0,__rl221SIMSET,0,__pl221SIMSET,__NULL};
-void __m_SIMSET(){goto __s;goto __ll0;/* START CLASS SIMSET *//* START CLASS LINKAGE *//* START PROCEDURE SUC */__l8:
-# 31 "./simset.sim"
+__ptyp __p221SIMSET={'P',0,4,sizeof(__bs221),25,__m_SIMSET,0,0,3,0,__rl221SIMSET,0,__pl221SIMSET,__NULL};
+void __m_SIMSET(void){goto __s;
+# 25 "../../lib/simset.sim"
+__sto= (__dhp)&__blokk205SIMSET;__rb(&__p205SIMSET);goto __ll0;/* START CLASS SIMSET *//* START CLASS LINKAGE *//* START PROCEDURE SUC */__l8:
+# 31 "../../lib/simset.sim"
 
-# 32 "./simset.sim"
+# 32 "../../lib/simset.sim"
 ;((__bs208 *)__lb)->er=(((__bp=(__rin(((__bs207 *)__lb->sl)->zzsuc,&__p211SIMSET)?((__bs207 *)__lb->sl)->zzsuc:__NULL))!=__NULL && (__bp->pp->pref[1]!= &__p211SIMSET))?(__dhp)__rerror(__errqual):__bp);__er=((__bs208 *)__lb)->er;__rep();goto __sw;/* SLUTT PROCEDURE SUC *//* START PROCEDURE PRED */__l9:
-# 34 "./simset.sim"
+# 34 "../../lib/simset.sim"
 
-# 35 "./simset.sim"
+# 35 "../../lib/simset.sim"
 ;((__bs209 *)__lb)->er=(((__bp=(__rin(((__bs207 *)__lb->sl)->zzpred,&__p211SIMSET)?((__bs207 *)__lb->sl)->zzpred:__NULL))!=__NULL && (__bp->pp->pref[1]!= &__p211SIMSET))?(__dhp)__rerror(__errqual):__bp);__er=((__bs209 *)__lb)->er;__rep();goto __sw;/* SLUTT PROCEDURE PRED *//* START PROCEDURE PREV */__l10:
-# 37 "./simset.sim"
+# 37 "../../lib/simset.sim"
 ;((__bs210 *)__lb)->er=((__bs207 *)__lb->sl)->zzpred;__er=((__bs210 *)__lb)->er;__rep();goto __sw;/* SLUTT PROCEDURE PREV */__l5:
-# 28 "./simset.sim"
+# 28 "../../lib/simset.sim"
 __renddecl(0);goto __sw;__l6:__rinner(0);goto __sw;__l7:
-# 39 "./simset.sim"
+# 39 "../../lib/simset.sim"
 __rendclass(0);goto __sw;/* SLUTT CLASS LINKAGE *//* START CLASS LINK *//* START PROCEDURE OUT */__l14:
-# 45 "./simset.sim"
+# 45 "../../lib/simset.sim"
 
-# 46 "./simset.sim"
+# 46 "../../lib/simset.sim"
 ;if(!((((__bs207 *)__lb->sl)->zzsuc!=__NULL)))goto __ll1;
-# 47 "./simset.sim"
+# 47 "../../lib/simset.sim"
 ;((__bs207 *)((__bp=((__bs207 *)__lb->sl)->zzsuc)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzpred=((__bs207 *)__lb->sl)->zzpred;
-# 48 "./simset.sim"
+# 48 "../../lib/simset.sim"
 ;((__bs207 *)((__bp=((__bs207 *)__lb->sl)->zzpred)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzsuc=((__bs207 *)__lb->sl)->zzsuc;
-# 49 "./simset.sim"
+# 49 "../../lib/simset.sim"
 ;((__bs207 *)__lb->sl)->zzsuc=((__bs207 *)__lb->sl)->zzpred=__NULL;
-# 50 "./simset.sim"
+# 50 "../../lib/simset.sim"
 __ll1:__repp();goto __sw;/* SLUTT PROCEDURE OUT *//* START PROCEDURE FOLLOW */__l15:
-# 52 "./simset.sim"
+# 52 "../../lib/simset.sim"
 (((__bp=((__bs213 *)__lb)->PTR)!=__NULL && (__bp->pp->pref[0]!= &__p207SIMSET))?(__dhp)__rerror(__errqual):__bp);
-# 53 "./simset.sim"
+# 53 "../../lib/simset.sim"
 __sl=__lb->sl;__rcpp(&__p212SIMSET);__rcpb(26,__m_SIMSET);goto __sw;__l26:;;
-# 54 "./simset.sim"
+# 54 "../../lib/simset.sim"
 ;if(!(((((__bs213 *)__lb)->PTR!=__NULL)&&(((__bs207 *)((__bp=((__bs213 *)__lb)->PTR)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzsuc!=__NULL))))goto __ll2;
-# 55 "./simset.sim"
+# 55 "../../lib/simset.sim"
 ;((__bs207 *)__lb->sl)->zzpred=((__bs213 *)__lb)->PTR;
-# 56 "./simset.sim"
+# 56 "../../lib/simset.sim"
 ;((__bs207 *)__lb->sl)->zzsuc=((__bs207 *)((__bp=((__bs213 *)__lb)->PTR)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzsuc;
-# 57 "./simset.sim"
-(__r[1]=(((__bs207 *)__lb->sl)->zzsuc));((__bs207 *)((__bp=__r[1])==__NULL?(__dhp)__rerror(__errnone):__bp))->zzpred=((__bs207 *)((__bp=((__bs213 *)__lb)->PTR)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzsuc=__lb->sl;
-# 58 "./simset.sim"
+# 57 "../../lib/simset.sim"
+(((__bs213 *)__lb)->__r1=(((__bs207 *)__lb->sl)->zzsuc));((__bs207 *)((__bp=((__bs213 *)__lb)->__r1)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzpred=((__bs207 *)((__bp=((__bs213 *)__lb)->PTR)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzsuc=__lb->sl;
+# 58 "../../lib/simset.sim"
 __ll2:__repp();goto __sw;/* SLUTT PROCEDURE FOLLOW *//* START PROCEDURE PRECEDE */__l16:
-# 60 "./simset.sim"
+# 60 "../../lib/simset.sim"
 (((__bp=((__bs214 *)__lb)->PTR)!=__NULL && (__bp->pp->pref[0]!= &__p207SIMSET))?(__dhp)__rerror(__errqual):__bp);
-# 61 "./simset.sim"
+# 61 "../../lib/simset.sim"
 __sl=__lb->sl;__rcpp(&__p212SIMSET);__rcpb(27,__m_SIMSET);goto __sw;__l27:;;
-# 62 "./simset.sim"
+# 62 "../../lib/simset.sim"
 ;if(!(((((__bs214 *)__lb)->PTR!=__NULL)&&(((__bs207 *)((__bp=((__bs214 *)__lb)->PTR)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzpred!=__NULL))))goto __ll3;
-# 63 "./simset.sim"
+# 63 "../../lib/simset.sim"
 ;((__bs207 *)__lb->sl)->zzsuc=((__bs214 *)__lb)->PTR;
-# 64 "./simset.sim"
+# 64 "../../lib/simset.sim"
 ;((__bs207 *)__lb->sl)->zzpred=((__bs207 *)((__bp=((__bs214 *)__lb)->PTR)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzpred;
-# 65 "./simset.sim"
-(__r[1]=(((__bs207 *)__lb->sl)->zzpred));((__bs207 *)((__bp=__r[1])==__NULL?(__dhp)__rerror(__errnone):__bp))->zzsuc=((__bs207 *)((__bp=((__bs214 *)__lb)->PTR)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzpred=__lb->sl;
-# 66 "./simset.sim"
+# 65 "../../lib/simset.sim"
+(((__bs214 *)__lb)->__r1=(((__bs207 *)__lb->sl)->zzpred));((__bs207 *)((__bp=((__bs214 *)__lb)->__r1)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzsuc=((__bs207 *)((__bp=((__bs214 *)__lb)->PTR)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzpred=__lb->sl;
+# 66 "../../lib/simset.sim"
 __ll3:__repp();goto __sw;/* SLUTT PROCEDURE PRECEDE *//* START PROCEDURE INTO */__l17:
-# 68 "./simset.sim"
+# 68 "../../lib/simset.sim"
 (((__bp=((__bs215 *)__lb)->S)!=__NULL && (__bp->pp->pref[1]!= &__p216SIMSET))?(__dhp)__rerror(__errqual):__bp);__sl=__lb->sl;__rcpp(&__p214SIMSET);((__bs214 *)__pb)->PTR=((__bs215 *)__lb)->S;__rcpb(28,__m_SIMSET);goto __sw;__l28:;;__repp();goto __sw;/* SLUTT PROCEDURE INTO */__l11:
-# 42 "./simset.sim"
+# 42 "../../lib/simset.sim"
 __renddecl(1);goto __sw;__l12:__rinner(1);goto __sw;__l13:
-# 70 "./simset.sim"
+# 70 "../../lib/simset.sim"
 __rendclass(1);goto __sw;/* SLUTT CLASS LINK *//* START CLASS HEAD *//* START PROCEDURE FIRST */__l21:
-# 76 "./simset.sim"
+# 76 "../../lib/simset.sim"
 
-# 78 "./simset.sim"
+# 78 "../../lib/simset.sim"
 ;((__bs217 *)__lb)->er=(((__bp=(__rin(((__bs207 *)__lb->sl)->zzsuc,&__p211SIMSET)?((__bs207 *)__lb->sl)->zzsuc:__NULL))!=__NULL && (__bp->pp->pref[1]!= &__p211SIMSET))?(__dhp)__rerror(__errqual):__bp);__er=((__bs217 *)__lb)->er;__rep();goto __sw;/* SLUTT PROCEDURE FIRST *//* START PROCEDURE LAST */__l22:
-# 80 "./simset.sim"
+# 80 "../../lib/simset.sim"
 
-# 82 "./simset.sim"
+# 82 "../../lib/simset.sim"
 ;((__bs218 *)__lb)->er=(((__bp=(__rin(((__bs207 *)__lb->sl)->zzpred,&__p211SIMSET)?((__bs207 *)__lb->sl)->zzpred:__NULL))!=__NULL && (__bp->pp->pref[1]!= &__p211SIMSET))?(__dhp)__rerror(__errqual):__bp);__er=((__bs218 *)__lb)->er;__rep();goto __sw;/* SLUTT PROCEDURE LAST *//* START PROCEDURE EMPTY */__l23:
-# 84 "./simset.sim"
+# 84 "../../lib/simset.sim"
 ;(((__bs219 *)__lb)->ec=((((__bs207 *)__lb->sl)->zzsuc==__lb->sl)));__ev.c=((__bs219 *)__lb)->ec;__rep();goto __sw;/* SLUTT PROCEDURE EMPTY *//* START PROCEDURE CARDINAL */__l24:
-# 86 "./simset.sim"
+# 86 "../../lib/simset.sim"
 
-# 94 "./simset.sim"
+# 94 "../../lib/simset.sim"
 ;((__bs220 *)__lb)->PTR=((__bs207 *)__lb->sl)->zzsuc;
-# 95 "./simset.sim"
+# 95 "../../lib/simset.sim"
 __ll4:;if(!((((__bs220 *)__lb)->PTR!=__lb->sl)))goto __ll5;
-# 96 "./simset.sim"
+# 96 "../../lib/simset.sim"
 ;(((__bs220 *)__lb)->I=((((__bs220 *)__lb)->I+1L)));
-# 97 "./simset.sim"
+# 97 "../../lib/simset.sim"
 ;((__bs220 *)__lb)->PTR=((__bs207 *)((__bp=((__bs220 *)__lb)->PTR)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzsuc;
-# 98 "./simset.sim"
+# 98 "../../lib/simset.sim"
 goto __ll4;__ll5:
-# 101 "./simset.sim"
+# 101 "../../lib/simset.sim"
 ;(((__bs220 *)__lb)->ev=(((__bs220 *)__lb)->I));__ev.i=((__bs220 *)__lb)->ev;__rep();goto __sw;/* SLUTT PROCEDURE CARDINAL *//* START PROCEDURE CLEAR */__l25:
-# 104 "./simset.sim"
+# 104 "../../lib/simset.sim"
 
-# 107 "./simset.sim"
+# 107 "../../lib/simset.sim"
 ;((__bs221 *)__lb)->PTR=((__bs207 *)__lb->sl)->zzsuc;
-# 108 "./simset.sim"
+# 108 "../../lib/simset.sim"
 __ll6:;if(!((((__bs221 *)__lb)->PTR!=__lb->sl)))goto __ll7;
-# 110 "./simset.sim"
+# 110 "../../lib/simset.sim"
 ;((__bs221 *)__lb)->PTRSUC=((__bs207 *)((__bp=((__bs221 *)__lb)->PTR)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzsuc;
-# 111 "./simset.sim"
-(__r[1]=(((__bs221 *)__lb)->PTR));((__bs207 *)((__bp=__r[1])==__NULL?(__dhp)__rerror(__errnone):__bp))->zzsuc=((__bs207 *)((__bp=((__bs221 *)__lb)->PTR)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzpred=__NULL;
-# 112 "./simset.sim"
+# 111 "../../lib/simset.sim"
+(((__bs221 *)__lb)->__r1=(((__bs221 *)__lb)->PTR));((__bs207 *)((__bp=((__bs221 *)__lb)->__r1)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzsuc=((__bs207 *)((__bp=((__bs221 *)__lb)->PTR)==__NULL?(__dhp)__rerror(__errnone):__bp))->zzpred=__NULL;
+# 112 "../../lib/simset.sim"
 ;((__bs221 *)__lb)->PTR=((__bs221 *)__lb)->PTRSUC;
-# 113 "./simset.sim"
+# 113 "../../lib/simset.sim"
 goto __ll6;__ll7:
-# 115 "./simset.sim"
+# 115 "../../lib/simset.sim"
 ;((__bs207 *)__lb->sl)->zzsuc=((__bs207 *)__lb->sl)->zzpred=__lb->sl;__repp();goto __sw;/* SLUTT PROCEDURE CLEAR */__l18:
-# 73 "./simset.sim"
+# 73 "../../lib/simset.sim"
 __renddecl(1);goto __sw;__l19:
-# 118 "./simset.sim"
+# 118 "../../lib/simset.sim"
 ;((__bs207 *)__lb)->zzsuc=((__bs207 *)__lb)->zzpred=__lb;
-# 73 "./simset.sim"
+# 73 "../../lib/simset.sim"
 __rinner(1);goto __sw;__l20:
-# 118 "./simset.sim"
+# 118 "../../lib/simset.sim"
 __rendclass(1);goto __sw;/* SLUTT CLASS HEAD */__l2:
-# 25 "./simset.sim"
+# 25 "../../lib/simset.sim"
 __renddecl(0);goto __sw;__l3:__rinner(0);goto __sw;__l4:
-# 120 "./simset.sim"
-__rendclass(0);goto __sw;/* SLUTT CLASS SIMSET */__ll0:__sw:if(__goto.ment!=(void (*)())__m_SIMSET)return;__s:switch(__goto.ent){case 2: goto __l2;
+# 120 "../../lib/simset.sim"
+__rendclass(0);goto __sw;/* SLUTT CLASS SIMSET */__ll0:__rbe();__sw:if(__goto.ment!=(void (*)())__m_SIMSET)return;__s:switch(__goto.ent){case 2: goto __l2;
 case 3: goto __l3;
 case 4: goto __l4;
 case 5: goto __l5;
