@@ -17,14 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                             REF(printfile) PROCEDURE SYSERR  */
 
-__dhp 
-__rsyserr ()
+__dhp __rsyserr (void)
 {
   return ((__dhp) & __syserr);
 }
