@@ -17,14 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                                REF(infile) PROCEDURE SYSIN   */
 
-__dhp 
-__rsysin ()
+__dhp __rsysin (void)
 {
   return ((__dhp) & __sysin);
 }
