@@ -17,14 +17,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#define INCLUDE_SIMFILE_H
 #include "cim.h"
-#include "simfile.h"
 
 /******************************************************************************
                                             REF(printfile) PROCEDURE SYSOUT  */
 
-__dhp 
-__rsysout ()
+__dhp __rsysout (void)
 {
   return ((__dhp) & __sysout);
 }
