@@ -19,12 +19,14 @@
 
 #include "file.h"
 
+#if STDC_HEADERS
+#include <stdlib.h>
+#endif
+
 /******************************************************************************
                                                         RutineSYSTEMERROR    */
 
-void
-__rsystemerror (s)
-     char *s;
+void __rsystemerror (char *s)
 {
   __rprintfilline ();
   (void) fprintf (stderr, "SYSTEM-ERROR: %s\n", s);
