@@ -18,15 +18,17 @@
  */
 
 #include "cim.h"
+#include "config.h"
 
 #include <stdio.h>
+#if STDC_HEADERS
+#include <stdlib.h>
+#endif
 
 /******************************************************************************
                                                       PROCEDURE TERROR	     */
 
-void 
-__rterror (t)
-     __txtvp t;
+void __rterror (__txtvp t)
 {
   long i;
   __rprintfilline ();
