@@ -18,12 +18,13 @@
  */
 
 #include "cim.h"
+#include "config.h"
 
-extern char *malloc();
+#if STDC_HEADERS
+#include <stdlib.h>
+#endif
 
-char *
-xmalloc (size)
-     unsigned int size;
+char *xmalloc (unsigned int size)
 {
   char *ptr = malloc (size);
   if (! ptr) __rerror ("Xmalloc: Virtual memory exhausted");
