@@ -16,17 +16,19 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */
 
+#include "builder.h"
+
 /* In computeconst.c */
 
-char computeconst ();
-char setdanger_const ();
-int sstrlen ();
+char computeconst (exp_t *re);
+char setdanger_const (exp_t *re);
+int sstrlen (char s[]);
 
 /* In sentchecker.c */
 
-void sentCheck ();
+void sent_check (sent_t *parent_sent, char res_labels);
 
 /* In expchecker.c */
 
-void expCheckerInit ();
-void mainExpcheck ();
+void exp_checker_init_pass2 (void);
+void main_exp_check (exp_t *re);
