@@ -26,16 +26,16 @@
 #include "cimcomp.h"
 #include "error.h"
 #include "lex.h"
-#include "mellbuilder.h"
 #include "checker.h"
 #include "gen.h"
 #include "trans.h"
+#include "passes.h"
 
 #if STDC_HEADERS || HAVE_STRING_H
 #include <string.h>
-#else /* not STDC_HEADERS and not HAVE_STRING_H */
+#else
 #include <strings.h>
-#endif /* not STDC_HEADERS and not HAVE_STRING_H */
+#endif
 
 #if HAVE_UNISTD_H
 #include <unistd.h>
@@ -51,18 +51,16 @@
 
 #include "getopt.h"
 
-struct SENT *mainSent;
-
 FILE *ccode;
 
 char *extcodename;
 char *mifcodename;
+char *sourcename;
+char *ccodename;
 
 static char *outputname = "";
 static char *exekname;
-static char *sourcename;
 static char *listname;
-static char *ccodename;
 static char *ocodename;
 static char *shlname;
 
@@ -85,6 +83,7 @@ int option_init_poolsize;
 int option_dyn_poolsize;
 int option_max_poolsize;
 int option_bl_in_dir_line;
+int option_quiet;
 
 static int option_static;
 static int option_pic;
@@ -95,15 +94,14 @@ static int option_nocc;
 static int option_checkdif;
 static int option_notempdel;
 static int option_noexecdel;
-static int option_quiet;
 static int option_sscheck;
 #ifdef DEBUG
-static int option_lex,
-static int option_gen_test;
-static int option_declarations;
-static int option_expressions;
-static int option_msymbols;
-static int option_input;
+int option_lex;
+int option_declarations;
+int option_input;
+int option_dump_build;
+int option_dump_check;
+int option_dump_trans;
 #endif
 
 #ifdef DEBUG
@@ -114,73 +112,51 @@ char separat_comp;		/* Sier om kj|ringen er en separat
 
 char *progname;
 
-/******************************************************************************
-                                                                     XMALLOC */
-
-char *
-xmalloc (size)
-     unsigned int size;
-{
-  char *ptr = malloc (size);
-  if (! ptr)
-    {
-      fprintf (stderr, "%s: virtual memory exhausted\n", progname);
-      exit (1);
-    }
-  return ptr;
-}
-
 /******************************************************************************
                                                                TRAP-ROUTINES */
 #if HAVE_SIGFPE
-static RETSIGTYPE
-float_trap ()
+static RETSIGTYPE float_trap (int ignore)
 {
   lerror (25);
 }
 #endif
 
 #if HAVE_SIGSEGV
-static RETSIGTYPE
-seg_trap ()
+static RETSIGTYPE seg_trap (int ignore)
 {
   lerror (26);
 }
 #endif
 
 #if HAVE_SIGILL
-static RETSIGTYPE
-illegal_trap ()
+static RETSIGTYPE illegal_trap (int ignore)
 {
   lerror (28);
 }
 #endif
 
 #if HAVE_SIGTRAP
-static RETSIGTYPE
-trace_trap ()
+static RETSIGTYPE trace_trap (int ignore)
 {
   lerror (29);
 }
 #endif
 
 #if HAVE_SIGBUS
-static RETSIGTYPE
-bus_trap ()
+static RETSIGTYPE bus_trap (int ignore)
 {
   lerror (27);
 }
 #endif
 
 #if HAVE_SIGSYS
-static RETSIGTYPE
-sys_trap ()
+static RETSIGTYPE sys_trap (int ignore)
 {
   lerror (30);
 }
 #endif
 
-static init_trap_routines()
+static void init_trap_routines(void)
 {
 #if HAVE_SIGFPE
   signal (SIGFPE, float_trap);
@@ -207,9 +183,7 @@ static init_trap_routines()
 
 #if HAVE_GETENV
 extern char *getenv ();
-static xgetenv (name, var)
-     char *name;
-     char **var;
+static void xgetenv (char *name, char **var)
 {
   char *value;
   value = getenv (name);
@@ -218,7 +192,7 @@ static xgetenv (name, var)
 }
 #endif
 
-static get_all_env()
+static void get_all_env(void)
 {
 #if HAVE_GETENV
   xgetenv ("CIMLIBDIR", &systemlibdir);
@@ -228,91 +202,10 @@ static get_all_env()
 #endif
 }
 
-/******************************************************************************
-                                                                     SIMCOMP */
-static simcomp ()
-{
-  mbuilderInit();
-
-  if (initLex (sourcename)) return (TRUE);
-  if (option_write_tokens)
-    {
-      scan_and_write_tokens ();
-      return (FALSE);
-    }
-#ifdef DEBUG
-  if (option_declarations || option_expressions
-      || option_msymbols || option_input || option_lex)
-    {
-      s_out = dup (stdout->_file);
-      if (freopen (listname, "w", stdout) == NULL)
-	{
-	  perror (newstrcat3 (progname, ": ", listname));
-	  return (TRUE);
-	}
-    }
-#endif
-  if ((ccode = fopen (ccodename, "w")) == NULL)
-    {
-      perror (newstrcat3 (progname, ": ", ccodename));
-      return (TRUE);
-    }
-  if (!option_quiet)
-    fprintf (stderr, "Compiling %s:\n", sourcename);
-
-  /* PASS 1 */
-
-  initExtspec ();
-  init_parser ();
-  initDecl ();
-  yyparse ();
-
-  /* PASS 2 AV KOMPILATOREN */
-
-  if (anterror == 0)
-    {
-      mbuilderReinit();
-      ebuilderInit();
-      sbuilderInit();
-      mainSent= sbuild();
-      reinit ();
-      expCheckerInit ();
-      genInit ();
-      sentCheck (mainSent, TRUE);
-      if (anterror == 0)
-	{
-	  sentTrans (mainSent);
-	  sentGen (mainSent);
-	}
-      if (separat_comp && (anterror == 0 || option_atr))
-	write_all_ext ();
-#ifdef DEBUG
-      if (option_declarations)
-	dump ();
-#endif
-    }
-  fclose (ccode);
-#ifdef DEBUG
-  if (option_declarations || option_expressions
-      || option_msymbols || option_input || option_lex)
-    {
-      fclose (stdout);
-      fdopen (s_out, "w");
-      dup2 (s_out, fileno (stdout));
-    }
-#endif
-  if (anterror != 0)
-    return (TRUE);
-  else
-    return (FALSE);
-}
-
 /******************************************************************************
                                                                STRINGTOUPPER */
 
-static char *
-stringtoupper (s)
-     char *s;
+static char *stringtoupper (char *s)
 {
   char *st;
   for (st = s; *st != '\0'; st++)
@@ -323,8 +216,7 @@ stringtoupper (s)
 
 /******************************************************************************
                                                                     BASENAME */
-static char *
-basename (str) char *str;
+static char *basename (char *str)
 {
   int i,j;
   for (i = strlen (str) - 2; i >= 0; i--)
@@ -347,7 +239,7 @@ basename (str) char *str;
 /******************************************************************************
                                                                   PRINT_HELP */
 
-static int print_help(status)int status;
+static int print_help(int status)
 {
   fprintf(stderr,"Usage: %s"
 	  " [-a] [--atr]"
@@ -403,9 +295,7 @@ static int print_help(status)int status;
 
 /******************************************************************************
                                                                 PARSEOPTIONS */
-static parseoptions (argc, argv)
-     int argc;
-     char *argv[];
+static int parseoptions (int argc, char *argv[])
 {
   int c;
   int index;
@@ -449,12 +339,12 @@ static parseoptions (argc, argv)
 	  {"version", 0, 0, 'V'},
 	  {"no-warn", 0, 0, 'w'},
 #ifdef DEBUG
-	  {"dd", 0, &option_declarations, 1},
-	  {"de", 0, &option_expressions, 1},
-	  {"dm", 0, &option_msymbols, 1},
-	  {"di", 0, &option_input, 1},
-	  {"dl", 0, &option_lex, 1},
-	  {"dg", 0, &option_gen, 1},
+	  {"debug-declarations", 0, &option_declarations, 1},
+	  {"debug-input", 0, &option_input, 1},
+	  {"debug-lex", 0, &option_lex, 1},
+	  {"debug-dump-build", 0, &option_dump_build, 1},
+	  {"debug-dump-check", 0, &option_dump_check, 1},
+	  {"debug-dump-trans", 0, &option_dump_trans, 1},
 #endif
 	  {"oc", 1, 0, 'b'},
 	  {"ol", 1, 0, 'B'},
@@ -499,7 +389,7 @@ static parseoptions (argc, argv)
 	  option_reuse_timestamp = TRUE;
 	  break;
 	case 'D':
-	  defineName (tag (stringtoupper (optarg)), TRUE);
+	  define_name (tag (stringtoupper (optarg)), TRUE);
 	  break;
 	case 'e':
 	  option_static = TRUE;
@@ -604,7 +494,7 @@ static parseoptions (argc, argv)
 	  option_bl_in_dir_line = TRUE;
 	  break;
 	case 'U':
-	  defineName (tag (stringtoupper (optarg)), FALSE);
+	  define_name (tag (stringtoupper (optarg)), FALSE);
 	  break;
 	case 'v':
 	  option_verbose = TRUE;
@@ -690,10 +580,7 @@ static parseoptions (argc, argv)
 /******************************************************************************
                                                                         MAIN */
 
-main (argc, argv, envp)
-     int argc;
-     char *argv[];
-     char *envp[];
+main (int argc, char *argv[], char *envp[])
 {
   char *archname;
   char *kom;
@@ -701,8 +588,8 @@ main (argc, argv, envp)
 
   progname = argv[0];
 
-  initNewstr ();
-  initFilelist ();
+  init_newstr ();
+  init_filelist ();
 
   ccomp = newstrcat3 (SCC, " ", SCFLAGS);
 
@@ -712,7 +599,7 @@ main (argc, argv, envp)
   
   insert_name_in_dirlist (systemlibdir);
 
-  initName ();
+  init_name ();
 
   if (parseoptions (argc, argv))
     return (1);
@@ -741,7 +628,7 @@ main (argc, argv, envp)
       rename (ccodename, newstrcat2 (ccodename, ".old")); 
     }
 
-  if (!option_nosim && simcomp ())
+  if (!option_nosim && passes_do ())
     {
       unlink (ccodename);
 
@@ -752,6 +639,14 @@ main (argc, argv, envp)
       return (1);
     }
 
+#if 0
+  /* Flgende skal ikke gjre skade. 
+     M f dette til  virke fr cim
+     kan gjre mer enn en kompilering. */
+
+  simcomp ();
+#endif
+
   if (option_write_tokens)
     return (0);
 
@@ -910,6 +805,7 @@ main (argc, argv, envp)
       fclose (shlfile);
       system (newstrcat2 ("chmod +x ", shlname));
     }
+  fflush (stdout);
   argv[0]= shlname;
   execve (shlname, argv, envp);
 }
