@@ -23,18 +23,24 @@
 #include "const.h"
 #include "lex.h"
 #include "name.h"
+#include "salloc.h"
+#include "cimcomp.h"
 
 #include <stdio.h>
 #include <obstack.h>
+#include "config.h"
+
+#if STDC_HEADERS
+#include <stdlib.h>
+#endif
 
 char *xmalloc();
-void free();
 
 #define obstack_chunk_alloc xmalloc
 #define obstack_chunk_free free
 
-static struct obstack osDecl;
-static struct obstack osPref;
+static struct obstack os_pref;
+static char *first_object_allocated_ptr_pref;
 
 
 /*****************************************************************************/
@@ -56,17 +62,21 @@ int localused;
 int arrdim;
 
 
-struct BLOCK *ssblock; /* First system block 
+block_t *ssblock; /* First system block 
                           (The outermost system block with blev=0) 
                           the system environment is conected to this block */
 
-struct BLOCK *cblock; /* Current block */
-struct BLOCK *sblock; /* First non system block 
+block_t *cblock; /* Current block */
+block_t *sblock; /* First non system block 
                          (The outermost block with blev=1)
                          sblock is connected with ssblock through
                          two INSP blocks (sysin and sysout) */
+static block_t *lblock;
 
-struct BLOCK *seenthrough;	/* Settes av findGlobal og findLocal og peker 
+static int cblno;
+
+
+block_t *seenthrough;	/* Settes av find_global og find_local og peker 
 				 * p}  en utenforliggende inspect blokk(hvis
 				 * den      finnes). Det er fordi jeg onsker
 				 * } vite n}r en variable er sett gjennom
@@ -74,56 +84,52 @@ struct BLOCK *seenthrough;	/* Settes av findGlobal og findLocal og peker
 				 * kode genereringen for }    aksessere
 				 * variable fra den inspiserte klassen 
 				 * gjennom inspect variabelen */
-struct DECL *classtext;
+decl_t *classtext;
 
 
 int cblev;
 
-struct DECL *cprevdecl;
+decl_t *cprevdecl;
  
 /* Har en peker som peker p} en array deklarasjon som ikke har f}tt
  * satt sin dim verdi. */
-struct DECL *lastArray;
+decl_t *last_array;
 
 /* Under sjekkingen og innlesingen av deklarasjonene
  * trenger jeg  merke de ulike objektene
  * Lar atributter peke paa ulike objekter for merkeingen */
-static struct DECL *sjekkdeklcalled;
-static struct DECL *lastunknowns;
-static struct BLOCK *unknowns;
-struct DECL *commonprefiks;	/* Felles prefiks til alle ikke prefiksede
+static decl_t *sjekkdeklcalled;
+static decl_t *lastunknowns;
+static block_t *unknowns;
+decl_t *commonprefiks;	/* Felles prefiks til alle ikke prefiksede
 				 * klasser Inneholder prosedyren DETACH */
-static struct DECL *switchparam;
-static struct DECL *procparam;
-static struct DECL *sluttparam;
-static struct DECL *arrayparam;
+static decl_t *switchparam;
+static decl_t *procparam;
+static decl_t *sluttparam;
+static decl_t *arrayparam;
 
 /******************************************************************************
 						      PCLEAN, PPUSH and PPOP */
-static ppush(rd)struct DECL *rd;
+static void ppush(decl_t *rd)
 {
-#if 0
-  obstack_ptr_grow (&osPref, rd);
-#else
-  obstack_grow(&osPref, &rd, sizeof (void *));
-#endif
+  obstack_grow (&os_pref, &rd, sizeof (void *));
 }
 
-static pclean()
+static void pclean(void)
 {
   void *p;
-  p= obstack_finish (&osPref);
-  obstack_free (&osPref, p);
+  p= obstack_finish (&os_pref);
+  obstack_free (&os_pref, p);
 }
 
-static struct DECL *ppop()
+static decl_t *ppop(void)
 {
-  struct DECL *rd;
-  if (obstack_next_free (&osPref) == obstack_base (&osPref))
+  decl_t *rd;
+  if (obstack_next_free (&os_pref) == obstack_base (&os_pref))
     return (NULL);
 
-  rd= * ((struct DECL * *) obstack_next_free (&osPref) - 1);
-  obstack_blank (&osPref, - sizeof (void *));
+  rd= * ((decl_t * *) obstack_next_free (&os_pref) - 1);
+  obstack_blank (&os_pref, - (int) sizeof (void *));
   return (rd);
 }
 
@@ -131,41 +137,49 @@ static struct DECL *ppop()
 						        NEW-DECL/BLOCK       */
 
 
-struct DECL *newDecl()
+decl_t *new_decl(void)
 {
-  struct DECL *rd;
-  rd= (struct DECL *) obstack_alloc (&osDecl, sizeof (struct DECL));
-  memset (rd, 0, sizeof (struct DECL));
-  return rd;
+  return (decl_t *) salloc (sizeof (decl_t));
 }
 
-static struct BLOCK *newBlock()
+static block_t *new_block(void)
 {
-  struct BLOCK *rb;
-  rb= (struct BLOCK *)obstack_alloc (&osDecl, sizeof (struct BLOCK));
-  memset (rb, 0, sizeof (struct BLOCK));
+  block_t *rb;
+  rb= (block_t *) salloc (sizeof (block_t));
   rb->quant.descr = rb;
   return rb;
 }
 
 /******************************************************************************
-                                                                INITDECL     */
+                                                                  DECL_INIT  */
 
-/* InitDecl kalles fr selve innlesingen */
-
-initDecl ()
+void decl_init (void)
 {
-  struct BLOCK *rb;
-  struct DECL *rd;
+  obstack_init(&os_pref);
+  first_object_allocated_ptr_pref= obstack_alloc (&os_pref, 0);
+
+  sjekkdeklcalled = new_decl ();
+}
+
+
+/******************************************************************************
+                                                             DECL_INIT_PASS1 */
+
+/* decl_init_pass1 kalles fr selve innlesingen */
+
+void decl_init_pass1 (void)
+{
+  block_t *rb;
+  decl_t *rd;
   
-  obstack_init(&osDecl);
-  obstack_init(&osPref);
   cblev= -1;
-  sjekkdeklcalled = newDecl ();
-  unknowns = newBlock ();
+  unknowns = new_block ();
   unknowns->quant.kind = KERROR;
 
-  beginBlock (KBLOKK);
+  cblno = STARTBLNO;
+  lastunknowns= NULL;
+  lblock= cblock= NULL;
+  begin_block (KBLOKK);
   ssblock=cblock;
 
   /* ssblock->quant.encl= ssblock; Dersom denne er med gr kompilatoren inn
@@ -174,73 +188,74 @@ initDecl ()
 
   lesinn_external_spec (tag ("TEXTOBJ*"), "simenvir");
 
-  commonprefiks = findGlobal (tag ("COMMON*"), TRUE);
+  commonprefiks = find_global (tag ("COMMON*"), TRUE);
   commonprefiks->plev = -1;
-  classtext = findGlobal (tag ("TEXTOBJ*"), TRUE);
+  classtext = find_global (tag ("TEXTOBJ*"), TRUE);
 
-  beginBlock (KINSP);
-  beginBlock (KINSP);
-  rd = findGlobal (tag ("MAXLONGREAL"), TRUE);
+  begin_block (KINSP);
+  begin_block (KINSP);
+  rd = find_global (tag ("MAXLONGREAL"), TRUE);
   rd->value.rval = MAX_DOUBLE;
-  rd = findGlobal (tag ("MINLONGREAL"), TRUE);
+  rd = find_global (tag ("MINLONGREAL"), TRUE);
   rd->value.rval = -MAX_DOUBLE;
-  rd = findGlobal (tag ("MAXREAL"), TRUE);
+  rd = find_global (tag ("MAXREAL"), TRUE);
   rd->value.rval = MAX_DOUBLE;
-  rd = findGlobal (tag ("MINREAL"), TRUE);
+  rd = find_global (tag ("MINREAL"), TRUE);
   rd->value.rval = -MAX_DOUBLE;
-  rd = findGlobal (tag ("MAXRANK"), TRUE);
+  rd = find_global (tag ("MAXRANK"), TRUE);
   rd->value.ival = MAXRANK;
-  rd = findGlobal (tag ("MAXINT"), TRUE);
+  rd = find_global (tag ("MAXINT"), TRUE);
   rd->value.ival = MAX_INT;
-  rd = findGlobal (tag ("MININT"), TRUE);
+  rd = find_global (tag ("MININT"), TRUE);
   rd->value.ival = -MAX_INT - 1;
 }
 
 /******************************************************************************
-                                                                REINIT       */
+                                                                DECL_INIT_PASS2  */
 
-/* Reinit kalles fr sjekkingen starter */
+/* decl_init_pass2 kalles fr sjekkingen starter */
 
-reinit ()
+void decl_init_pass2 (void)
 {
-  struct DECL *rd;
-  endBlock (NULL,CCNO);
-  endBlock (NULL,CCNO);
-  endBlock (NULL,CCNO);
+  decl_t *rd;
+  end_block (NULL,CCNO);
+  end_block (NULL,CCNO);
+  end_block (NULL,CCNO);
   /* M} gj|re et hack for } f} satt kvalifikasjon p} inspect sysin */
   /* og inspect sysout, da neste blokk ikke er en connection blokk */
-  inBlock ();
-  inBlock (findGlobal (tag ("INFILE"), TRUE));
-  cblock->when = findGlobal (tag ("INFILE"), TRUE);
-  inBlock (findGlobal (tag ("PRINTFILE"), TRUE));
-  cblock->when = findGlobal (tag ("PRINTFILE"), TRUE);
+  lblock= NULL;
+  in_block ();
+  in_block ();
+  cblock->when = find_global (tag ("INFILE"), TRUE);
+  in_block ();
+  cblock->when = find_global (tag ("PRINTFILE"), TRUE);
   sblock = cblock = cblock->next_block;
 
-  switchparam = newDecl ();
+  switchparam = new_decl ();
   switchparam->type = TINTG;
   switchparam->kind = KSIMPLE;
   switchparam->categ = CDEFLT;
   switchparam->encl = unknowns;
 
-  switchparam->next = newDecl ();
+  switchparam->next = new_decl ();
   switchparam->next->type = TINTG;
   switchparam->next->kind = KSIMPLE;
   switchparam->next->categ = CDEFLT;
   switchparam->next->encl = unknowns;
   switchparam->next->next = switchparam->next;
 
-  procparam = newDecl ();
+  procparam = new_decl ();
   procparam->type = TERROR;
   procparam->kind = TERROR;
   procparam->categ = CNAME;
   procparam->encl = unknowns;
   procparam->next = procparam;
 
-  sluttparam = newDecl ();
+  sluttparam = new_decl ();
   sluttparam->encl = unknowns;
   sluttparam->next = sluttparam;
 
-  arrayparam = newDecl ();
+  arrayparam = new_decl ();
   arrayparam->type = TINTG;
   arrayparam->kind = KSIMPLE;
   arrayparam->categ = CDEFLT;
@@ -248,6 +263,16 @@ reinit ()
   arrayparam->next = arrayparam;
 }
 
+/******************************************************************************
+                                                                DECL_REINIT  */
+
+/* Decl_reinit kalles fr sjekkingen starter */
+
+void decl_reinit (void)
+{
+   obstack_free (&os_pref, first_object_allocated_ptr_pref);
+}
+
 /*****************************************************************************/
 /*                               HJELPE-PROSEDYRER                           */
 /*****************************************************************************/
@@ -255,17 +280,17 @@ reinit ()
 /******************************************************************************
                                                            SETARRAYDIM       */
 
-/* LastArray peker p frste array i siste arraydeklarasjon og setArrayDim
+/* Last_array peker p frste array i siste arraydeklarasjon og set_array_dim
  * settes disse arrayenes dimensjon (dim). S lengde next ogs er en array
  * skal ogs denne ha dimmensjonen arrdim.( integer array a,b(...); */
 
-setArrayDim (arrdim) int arrdim;
+void set_array_dim (int arrdim)
 {
-  while (lastArray != NULL)
+  while (last_array != NULL)
     {
-      lastArray->dim = arrdim;
-      lastArray = (lastArray->next == NULL ? NULL :
-	      (lastArray->next->kind == KARRAY ? lastArray->next : NULL));
+      last_array->dim = arrdim;
+      last_array = (last_array->next == NULL ? NULL :
+	      (last_array->next->kind == KARRAY ? last_array->next : NULL));
     }
   arrdim = 0;
 }
@@ -276,14 +301,12 @@ setArrayDim (arrdim) int arrdim;
 /* Newnotseen kalles hver gang det er noe udeklarert
  * Den legger alle disse inn i en liste med de ukjente */
 
-static struct DECL *
-newnotseen (ident)
-     char *ident;
+static decl_t *newnotseen (char *ident)
 {
   if (lastunknowns == NULL)
-    unknowns->parloc = lastunknowns = newDecl ();
+    unknowns->parloc = lastunknowns = new_decl ();
   else
-    lastunknowns = lastunknowns->next = newDecl ();
+    lastunknowns = lastunknowns->next = new_decl ();
   lastunknowns->ident = ident;
   lastunknowns->type = TERROR;
   lastunknowns->kind = KERROR;
@@ -297,24 +320,20 @@ newnotseen (ident)
 /******************************************************************************
                                                          FINDDECL            */
 
-/* FindDecl leter etter deklarasjonen ident lokalt i blokken og langs
+/* Find_decl leter etter deklarasjonen ident lokalt i blokken og langs
  *  den prefikskjede.Den kalles rekursivt for hvert BLOCK objekt langs 
  *  prefikskjeden.Ved en inspect blokk kalles den for den ispiserte 
  *  klassen og dens prefikser.Finnes den returneres en peker til 
  *  deklarasjonspakka, hvis ikke returneres NULL                         
  *  HVIS virt==TRUE skal det frst letes i evt. virtuell liste */
 
-struct DECL *
-findDecl (ident, rb, virt)
-     char *ident;
-     struct BLOCK *rb;
-     char virt;
+decl_t *find_decl (char *ident, block_t *rb, char virt)
 {
-  struct DECL *rd;
+  decl_t *rd;
   if ((rb->quant.kind == KINSP) && (rb->when != NULL))
     {
       seenthrough = rb;
-      if ((rd = findDecl (ident, rb->when->descr, virt)) != NULL
+      if ((rd = find_decl (ident, rb->when->descr, virt)) != NULL
 	  && rd->type != TLABEL)
 	return (rd);
       seenthrough = NULL;
@@ -334,7 +353,7 @@ findDecl (ident, rb, virt)
   if (rb->quant.kind == KCLASS || rb->quant.kind == KINSP || rb->quant.kind == KPRBLK
       || rb->quant.kind == KFOR || rb->quant.kind == KCON)
     if (rb->quant.plev > -1 && rb->quant.prefqual != NULL)
-      if ((rd = findDecl (ident, rb->quant.prefqual->descr,
+      if ((rd = find_decl (ident, rb->quant.prefqual->descr,
 			  rb->quant.kind == KCLASS | rb->quant.kind == KPRBLK ? FALSE : virt)) != NULL)
 	return (rd);
 
@@ -344,22 +363,19 @@ findDecl (ident, rb, virt)
 /******************************************************************************
                                                                 FINDGLOBAL   */
 
-/* FindGlobal  finner  den deklarasjonen som  svarer til et navn 
+/* Find_global  finner  den deklarasjonen som  svarer til et navn 
  * Den leter for  hvert  blokknivaa, i  prefikskjeden  og lokalt 
  * Stopper ved f\rste forekomst, fins den ikke kalles newnotseen 
  * Hvis virt==true skal det frst letes i evt. virtuell liste */
 
-struct DECL *
-findGlobal (ident, virt)
-     char *ident;
-     char virt;
+decl_t *find_global (char *ident, char virt)
 {
-  struct DECL *rd;
-  struct BLOCK *rb;
+  decl_t *rd;
+  block_t *rb;
 
   seenthrough = NULL;
   for (rb= cblock; rb; rb= rb->quant.encl)
-    if ((rd= findDecl (ident, rb, virt)) != NULL)
+    if ((rd= find_decl (ident, rb, virt)) != NULL)
       {
 	if (rd->encl->blev == cblock->blev &&
 	    (rd->categ == CLOCAL || rd->categ == CVIRT))
@@ -378,11 +394,9 @@ findGlobal (ident, virt)
 
 /* Sjekker om parameterene er de samme */
 
-sameParam (rb1, rb2)
-     struct BLOCK *rb1,
-      *rb2;
+int same_param (block_t *rb1, block_t *rb2)
 {
-  struct DECL *rd1,
+  decl_t *rd1,
    *rd2;
   int i;
   if (rb1 == NULL || rb2 == NULL)
@@ -413,7 +427,7 @@ sameParam (rb1, rb2)
 	    else return (FALSE);
 	}
       if (rd1->kind == KPROC &&
-	  sameParam (rd2->descr, rd1->descr) == FALSE)
+	  same_param (rd2->descr, rd1->descr) == FALSE)
 	return (FALSE);
       rd1 = rd1->next;
       rd2 = rd2->next;
@@ -426,9 +440,7 @@ sameParam (rb1, rb2)
 
 /* Gjr rd1 lik rd2 ved  kopiere atributter */
 
-static makeequal (rd1, rd2)
-     struct DECL *rd1,
-      *rd2;
+static void makeequal (decl_t *rd1, decl_t *rd2)
 {
   rd1->ident = rd2->ident;
   rd1->line = rd2->line;
@@ -452,10 +464,7 @@ static makeequal (rd1, rd2)
 /* Finner felles kvalifikasjon for to klasser
  * NULL hviss ingen slik finnes */
 
-struct DECL *
-commonqual (rdx, rdy)
-     struct DECL *rdx,
-      *rdy;
+decl_t *commonqual (decl_t *rdx, decl_t *rdy)
 {				/* Hvis rdx eller rdy peker p
 				 * commonprefiks (som har plev=-1) s} vil 
 				 * den leveres som felles kvalifikasjon, som
@@ -487,10 +496,7 @@ commonqual (rdx, rdy)
 
 /* Er rdx en subklasse til rdy, returnerer TRUE eller FALSE */
 
-char 
-subclass (rdx, rdy)
-     struct DECL *rdx,
-      *rdy;
+char subclass (decl_t *rdx, decl_t *rdy)
 {
   if (rdx == rdy)
     return (TRUE);
@@ -505,10 +511,7 @@ subclass (rdx, rdy)
 /******************************************************************************
                                                                 SUBORDINATE  */
 
-char 
-subordinate (rda, rdb)
-     struct DECL *rda,
-      *rdb;
+char subordinate (decl_t *rda, decl_t*rdb)
 {
   return ((rda->type != TREF && rda->type == rdb->type)
 	  || rdb->type == TNOTY || (rda->type == TREF && rdb->type == TREF
@@ -526,32 +529,27 @@ subordinate (rda, rdb)
 
 /* Kalles fra  syntakssjekkeren hver gang en ny blokk entres */
 
-beginBlock (kind)
-     char kind;
+void begin_block (char kind)
 {
-  static int cblno = STARTBLNO;
-  static struct BLOCK *lblock;
-  struct DECL *rd2;
+  decl_t *rd2;
   if (yaccerror)
     return;
 #ifdef DEBUG
   if (option_input)
-    printf (
-	     "beginBlock---line:%ld type:%c kind:%c categ:%c\t"
-	     ,lineno, type, kind, categ);
+    printf ("begin_block---line:%ld kind:%c\t", lineno, kind);
 #endif
 
   {
-    struct BLOCK *lastcblock= cblock;
+    block_t *lastcblock= cblock;
 
     if (kind == KPROC || kind == KCLASS)
       {
-	cblock = (struct BLOCK *) cprevdecl;
+	cblock = (block_t *) cprevdecl;
 	cprevdecl->match = cprevdecl;
       }
     else
       {
-	cblock = newBlock ();
+	cblock = new_block ();
 	cblock->quant.line = lineno;
 	cblock->quant.kind = kind;
 #if 1
@@ -586,6 +584,7 @@ beginBlock (kind)
 	cblock->stat = TRUE;
       break;
     case KFOR:
+    case KFORLIST:
     case KINSP:
     case KCON:
       cblock->quant.ident = NULL;
@@ -612,10 +611,11 @@ beginBlock (kind)
 	}
       switch (kind)
 	{
-	case KFOR:
-	  cblock->fornest+= 1;
+	case KFORLIST:
+	  cblock->fornest++;
 	  if (cblock->quant.match->descr->fornest < cblock->fornest)
 	    cblock->quant.match->descr->fornest++;
+	  cblock->quant.kind = KFOR;
 	  break;
 	case KINSP:
 	  cblock->connest+= 1;
@@ -654,14 +654,11 @@ beginBlock (kind)
 /* Kalles  fra  syntakssjekkeren hver gang en blokk terminerer */
 
 /*VARARGS0 */
-endBlock (rtname, codeclass)
-     char *rtname;
-     char codeclass;
+void end_block (char *rtname, char codeclass)
 {
 #ifdef DEBUG
   if (option_input)
-    printf ("endBlock---line:%ld type:%c kind:%c categ:%c\t"
-	    ,lineno, type, kind, categ);
+    printf ("end_block---line:%ld\t", lineno);
 #endif
   if (yaccerror)
     return;
@@ -689,17 +686,16 @@ endBlock (rtname, codeclass)
 /******************************************************************************
                                                              REGDECL         */
 
-/* RegDecl kalles fra syntakssjekkeren
+/* Reg_decl kalles fra syntakssjekkeren
  * hver gang  vi leser  en deklarasjon */
 
-regDecl (ident, type, kind, categ)
-     char *ident, type, kind, categ;
+void reg_decl (char *ident, char type, char kind, char categ)
 {
-  struct DECL *pd,
+  decl_t *pd,
    *pdx = NULL;
 #ifdef DEBUG
   if (option_input)
-    printf ("regDecl---line:%ld navn:%s type:%c kind:%c categ:%c\n"
+    printf ("reg_decl---line:%ld navn:%s type:%c kind:%c categ:%c\n"
 	    ,lineno, ident, type, kind, categ);
 #endif
   if (yaccerror)
@@ -740,11 +736,11 @@ regDecl (ident, type, kind, categ)
     proceed:
       if (kind == KCLASS || kind == KPROC)
 	{
-	  pd = (struct DECL *) newBlock ();
+	  pd = (decl_t *) new_block ();
 	}
       else
 	{
-	  pd = newDecl ();
+	  pd = new_decl ();
 	}
       if (cblock->lastparloc == NULL)
 	cprevdecl = cblock->parloc = cblock->lastparloc = pd;
@@ -789,11 +785,11 @@ regDecl (ident, type, kind, categ)
 	  if (kind == KPROC)
 	    {
 	      /* Bytter ut dette objektet med et st|rre */
-	      cprevdecl = &newBlock ()->quant;
+	      cprevdecl = &new_block ()->quant;
 	      if (cblock->lastparloc == pd)
 		cblock->lastparloc = cprevdecl;
 	      makeequal (cprevdecl, pd);
-	      cprevdecl->descr = (struct BLOCK *) cprevdecl;
+	      cprevdecl->descr = (block_t *) cprevdecl;
 	      cprevdecl->next = pd->next;
 	      if (pdx == NULL)
 		cblock->parloc = cprevdecl;
@@ -825,9 +821,9 @@ regDecl (ident, type, kind, categ)
       else
 	{
 	  if (pd == NULL)
-	    cblock->hiprot = pd = newDecl ();
+	    cblock->hiprot = pd = new_decl ();
 	  else
-	    pd = pd->next = newDecl ();
+	    pd = pd->next = new_decl ();
 	  pd->ident = ident;
 	  pd->line = lineno;
 	  pd->type = TNOTY;
@@ -839,11 +835,11 @@ regDecl (ident, type, kind, categ)
     case CVIRT:
       if (kind == KCLASS || kind == KPROC)
 	{
-	  pd = (struct DECL *) newBlock ();
+	  pd = (decl_t *) new_block ();
 	}
       else
 	{
-	  pd = newDecl ();
+	  pd = new_decl ();
 	}
       if (cblock->lastvirt == NULL)
 	cblock->virt = pd = cblock->lastvirt= pd;
@@ -877,11 +873,11 @@ regDecl (ident, type, kind, categ)
 /* Kalles fra syntakssjekkeren hver gang  
  * inner oppdages, sjekker da lovligheten */
 
-regInner ()
+void reg_inner (void)
 {
 #ifdef DEBUG
   if (option_input)
-    printf ("regInner---line:%ld cblev:%d\t"
+    printf ("reg_inner---line:%ld cblev:%d\t"
 	    ,lineno, cblev);
 #endif
   if (cblock->quant.kind != KCLASS)
@@ -911,8 +907,9 @@ regInner ()
 
 #ifdef DEBUG
 
-static dumpdekl (rd)
-     struct DECL *rd;
+static 
+dumpdekl (rd)
+     decl_t *rd;
 {
   printf ("        --DECL:%s=%d, k:%c,t:%c,c:%c, plev:%d, dim:%d, virtno:%d, line:%ld", rd->ident, rd->ident, rd->kind, rd->type, rd->categ, rd->plev, rd->dim, rd->virtno, rd->line);
   if (rd->protected == TRUE)
@@ -966,10 +963,10 @@ static dumpdekl (rd)
 /* Dumpblock skriver ut  tilstanden til en blokk
  * Den gjr i sin tur en rekke kall paa dumpdekl */
 
-static dumpblock (rb)
-     struct BLOCK *rb;
+dumpblock (rb)
+     block_t *rb;
 {
-  struct DECL *rd;
+  decl_t *rd;
   printf 
     ("->BLOCK:(%d,%d)  k:%c, np:%d, nv:%d, nvl:%d, f:%d, c:%d, l:%ld, ",
      rb->blno, rb->blev, rb->quant.kind,
@@ -1064,9 +1061,9 @@ static dumpblock (rb)
 /* Dump skriver ut tilstanden til hele strukturen
  * Den gjr et kall p  dumpblock for hver blokk */
 
-static dump ()
+dump ()
 {
-  struct BLOCK *rb;
+  block_t *rb;
   printf ("BLOKK:Blno,Blev,kind,napar,navirt,navirtlab,");
   printf ("fornest,connest,line1,line2,localclasses,thisused\n\n");
   printf ("DECL:navn,kind,type,categ,plev,dim,virtno,line\n\n");
@@ -1086,13 +1083,10 @@ static dump ()
 
 /* Setter/fjerner protected merket nr klasser entres/forlates */
 
-static setprotectedvirt (rb, rd, protected)
-     struct BLOCK *rb;
-     struct DECL *rd;
-     char protected;
+static setprotectedvirt (block_t *rb, decl_t *rd, char protected)
 {
-  struct BLOCK *rbx;
-  struct DECL *rdx;
+  block_t *rbx;
+  decl_t *rdx;
   rbx = rb;
   /* Den virtuelle listen for innerste prefiksniv} er ikke akkumulert opp */
   if (rb->navirt == 0 & rb->navirtlab == 0)
@@ -1115,12 +1109,10 @@ static setprotectedvirt (rb, rd, protected)
     }
 }
 
-static setprotected (rb, protected)
-     struct BLOCK *rb;
-     char protected;
+static void setprotected (block_t *rb, char protected)
 {
-  struct BLOCK *rbx;
-  struct DECL *rd;
+  block_t *rbx;
+  decl_t *rd;
   for (rd = rb->hiprot; rd != NULL; rd = rd->next)
     if (rd->match != NULL && rd->match->encl == rb)
       {
@@ -1151,10 +1143,9 @@ static setprotected (rb, protected)
  * Oppdager ulovlig prefiks og feil prefiksniv 
  * Oppdager ved merking sirkulr prefikskjede */
 
-static setprefchain (rd)
-     struct DECL *rd;
+static void setprefchain (decl_t *rd)
 {
-  struct DECL *rdx;
+  decl_t *rdx;
   if (rd->plev <= 0 && rd->identqual==NULL)
     {
       if (rd->plev == 0)
@@ -1162,7 +1153,7 @@ static setprefchain (rd)
     }
   else
     {
-      rdx = findGlobal (rd->identqual, FALSE);
+      rdx = find_global (rd->identqual, FALSE);
       rd->identqual=NULL;
       rd->plev = 0;
       if (rdx->categ == CNEW)
@@ -1219,12 +1210,9 @@ static setprefchain (rd)
 /* Setter opp prefikskjeden og kvalifikasjonen til pekere        
  * gjr kall p setprefchain og sjekker  kvalifikasjonen */
 
-static struct DECL *
-setqualprefchain (rd, param)
-     struct DECL *rd;
-     int param;
+static decl_t *setqualprefchain (decl_t *rd, int param)
 {
-  struct DECL *rdx;
+  decl_t *rdx;
   for (; rd != NULL; rd = rd->next)
     {
       if (param && (rd->categ == CLOCAL || rd->categ == CCONSTU
@@ -1233,7 +1221,7 @@ setqualprefchain (rd, param)
 	return (rd);
       if (rd->type == TREF)
 	{
-	  rdx = findGlobal (rd->identqual, FALSE);
+	  rdx = find_global (rd->identqual, FALSE);
 	  rd->plev = 0;
 	  if (rdx->categ == CNEW)
 	    {
@@ -1263,16 +1251,15 @@ setqualprefchain (rd, param)
  * Prefikskjeden og kvalifikasjoner settes ved kall p setqualprefchain 
  * den sjekker ogs konsistensen for type kind og categ */
 
-static sjekkdekl (rb)
-     struct BLOCK *rb;
+static void sjekkdekl (block_t *rb)
 {
-  struct DECL *rd = NULL,
+  decl_t *rd = NULL,
    *rdx = NULL,
    *rdy,
    *va = NULL,
    *vb = NULL,
    *vc = NULL;
-  struct BLOCK *rbx = NULL;
+  block_t *rbx = NULL;
   int vno,
     vnolab,
     kind;
@@ -1341,11 +1328,11 @@ static sjekkdekl (rb)
 		  rd->categ != CNAME && rd->categ != CVAR)
 		{
 		  char *s;
-		  obstack_grow (&osDecl, "__", 2);
-		  obstack_grow0 (&osDecl, rdx->ident, strlen(rdx->ident));
-		  s= obstack_finish(&osDecl);
+		  obstack_grow (&os_pref, "__", 2);
+		  obstack_grow0 (&os_pref, rdx->ident, strlen(rdx->ident));
+		  s= obstack_finish(&os_pref);
 		  rdx->ident = tag (s);
-		  obstack_free (&osDecl, s);
+		  obstack_free (&os_pref, s);
 		}
 	      else
 		d2error (55, rd);
@@ -1447,9 +1434,9 @@ static sjekkdekl (rb)
 	     vc != NULL; vc = vc->next)
 	  {
 	    if (va == NULL)
-	      va = vb = newDecl ();
+	      va = vb = new_decl ();
 	    else
-	      vb = vb->next = newDecl ();
+	      vb = vb->next = new_decl ();
 	    makeequal (vb, vc);
 	    vb->encl = rb;
 	    vb->dim = 0;
@@ -1557,7 +1544,7 @@ static sjekkdekl (rb)
 	      || (vc->type == TLABEL && va->type == TLABEL 
 		  && vc->kind == va->kind)
 	  || (vc->kind == KPROC && va->kind == KPROC && subordinate (va, vc)
-	      && sameParam (vc->descr, va->descr)))
+	      && same_param (vc->descr, va->descr)))
 	    {
 	      vc->match = va;
 	      vc->type = va->type;
@@ -1574,7 +1561,7 @@ static sjekkdekl (rb)
       /* Listen av hidden og protected sjekkes og match settes opp */
       for (rd = rb->hiprot; rd != NULL; rd = rd->next)
 	{
-	  rdx = findLocal (rd->ident, &rb->quant, TRUE);
+	  rdx = find_local (rd->ident, &rb->quant, TRUE);
 	  if (rdx->categ == CNEW)
 	    {
 	      d2error (74, rd);
@@ -1623,14 +1610,13 @@ static sjekkdekl (rb)
 /******************************************************************************
   							      FIRSTCLASS     */
 
-struct BLOCK *
-firstclass ()
+block_t *firstclass (void)
 {				/* Retunerer med blev for den n{rmeste
 				 * klassen eller prefiksblokk sett
 				 * fra cblock */
 
   int i;
-  struct BLOCK *rb;
+  block_t *rb;
   i = cblev;
   for (rb = cblock; rb->quant.kind != KCLASS && rb->quant.kind != KPRBLK; rb = rb->quant.encl)
     if ((rb->quant.kind == KFOR || rb->quant.kind == KINSP
@@ -1644,11 +1630,9 @@ firstclass ()
 /******************************************************************************
                                                                    INBLOCK   */
 
-/* InBlock kalles fra sjekkeren hver  gang en  blokk  entres */
-nextblock ()
+/* In_block kalles fra sjekkeren hver  gang en  blokk  entres */
+static void nextblock (void)
 {
-  static struct BLOCK *lblock;
-
   if (lblock == NULL)
     lblock = ssblock;
   else
@@ -1664,7 +1648,7 @@ nextblock ()
   cblock= lblock;
 }
 
-inBlock ()
+void in_block (void)
 {
   nextblock ();
   cblev = cblock->blev;
@@ -1677,9 +1661,9 @@ inBlock ()
 /******************************************************************************
                                                              OUTBLOCK        */
 
-/* OutBlock kalles fra sjekkeren hver gang  en blokk  forlates */
+/* Out_block kalles fra sjekkeren hver gang  en blokk  forlates */
 
-outBlock ()
+void out_block (void)
 {
   if (cblock->quant.kind == KCLASS || cblock->quant.kind == KPRBLK)
     setprotected (cblock, TRUE);
@@ -1701,7 +1685,7 @@ outBlock ()
                                                                 REGWHEN      */
 
 
-regwhen (rb, rd) struct BLOCK *rb; struct DECL *rd;
+void regwhen (block_t *rb, decl_t *rd)
 {
   rb->quant.prefqual->descr->when= rd;
 }
@@ -1710,12 +1694,12 @@ regwhen (rb, rd) struct BLOCK *rb; struct DECL *rd;
                                                                 REGINSP      */
 
 
-reginsp (rb, rd) struct BLOCK *rb; struct DECL *rd;
+void reginsp (block_t *rb, decl_t *rd)
 {
   if (rd == NULL)
     {
       d2error (73, &rb->quant);
-      rd = findGlobal (tag ("Noqual"), FALSE);
+      rd = find_global (tag ("Noqual"), FALSE);
       rd->categ = CERROR;
     }
   rb->virt = rd;
@@ -1727,17 +1711,15 @@ reginsp (rb, rd) struct BLOCK *rb; struct DECL *rd;
 /* Kalles fra sjekkeren hver gang this oppdages,
  * sjekker da lovligheten */
 
-struct DECL *
-regThis (ident)
-     char *ident;
+decl_t *reg_this (char *ident)
 {
-  struct DECL *rd,
+  decl_t *rd,
    *rdt,
    *rdx;
-  struct BLOCK *rb;
+  block_t *rb;
 #ifdef DEBUG
   if (option_input)
-    printf ("regThis---line:%ld cblev:%d\t"
+    printf ("reg_this---line:%ld cblev:%d\t"
 	    ,lineno, cblev);
 #endif
   for (rb = cblock; rb->blev > 0; rb= rb->quant.encl)	/* Skal det v}re i>=0 .(Omgivelsene) */
@@ -1780,30 +1762,26 @@ regThis (ident)
   if (option_input)
     printf ("---end\n");
 #endif
-  d2error (79, rd = findGlobal (ident, FALSE));
+  d2error (79, rd = find_global (ident, FALSE));
   return (rd);
 }
 
 /******************************************************************************
                                                                 FINDLOCAL    */
 
-/* FindLocal  finner  den  deklarasjonen som  svarer til  et navn 
+/* Find_local  finner  den  deklarasjonen som  svarer til  et navn 
  * Den leter lokalt i den lista den har ft og dens prefikskjede 
- * Har den ikke  ft noen liste  leter den slik  findGlobal gjr 
+ * Har den ikke  ft noen liste  leter den slik  find_global gjr 
  * Den registrerer ogs localused 
  * Hvis virt==TRUE skal det frst letes i evt. virtuell liste */
 
-struct DECL *
-findLocal (ident, rd, virt)
-     char *ident;
-     struct DECL *rd;
-     char virt;
+decl_t *find_local (char *ident, decl_t *rd, char virt)
 {
   seenthrough = NULL;
   if (rd != NULL && rd->descr != NULL)
-    rd = findDecl (ident, rd->descr, virt);
+    rd = find_decl (ident, rd->descr, virt);
   else
-    return (findGlobal (ident, virt));
+    return (find_global (ident, virt));
   if (rd != NULL)
     return (rd);
   for (rd = unknowns->parloc; rd != NULL; rd = rd->next)
@@ -1819,11 +1797,9 @@ findLocal (ident, rd, virt)
  * til en prosedyre eller klasse 
  * Fr som input forrige parameter */
 
-struct DECL *
-nextParam (rd)
-     struct DECL *rd;
+decl_t *next_param (decl_t *rd)
 {
-  struct DECL *rdx;
+  decl_t *rdx;
   int plev;
   if (rd == NULL)
     return (NULL);
@@ -1849,11 +1825,9 @@ nextParam (rd)
   return (sluttparam);
 }
 
-static struct DECL *
-firstclassparam (rd)
-     struct DECL *rd;
+static decl_t *firstclassparam (decl_t *rd)
 {
-  struct DECL *rdx,
+  decl_t *rdx,
    *rdy;
   if (rd->plev > 0)
     {
@@ -1875,11 +1849,9 @@ firstclassparam (rd)
 
 
 
-struct DECL *
-firstParam (rd)
-     struct DECL *rd;
+decl_t *first_param (decl_t *rd)
 {
-  struct DECL *rdx;
+  decl_t *rdx;
   if (rd->kind == KCLASS)
     {
       pclean ();
@@ -1915,8 +1887,7 @@ firstParam (rd)
 
 /* Forlanges det flere parametere */
 
-moreParam (rd)
-     struct DECL *rd;
+int more_param (decl_t *rd)
 {
   if (rd == sluttparam)
     return (FALSE);
@@ -1945,10 +1916,9 @@ moreParam (rd)
 
 /* Er vi inne i en prosedyre kropp */
 
-body (rd)
-     struct DECL *rd;
+int body (decl_t *rd)
 {
-  struct BLOCK *rb, *rbx;
+  block_t *rb, *rbx;
   rbx = cblock;
   rb = rd->descr;
   for (rbx= cblock; rbx->blev > 0; rbx= rbx->quant.encl)
@@ -1969,9 +1939,7 @@ body (rd)
 
 /* Er prosedyren farlig og m] isoleres i uttrykk */
 
-char 
-dangerProc (rd)
-     struct DECL *rd;
+char danger_proc (decl_t *rd)
 {
   switch (rd->descr->codeclass)
     {
@@ -1992,9 +1960,9 @@ dangerProc (rd)
 /*****************************************************************************
                                                                 REMOVEBLOCK */
 
-removeBlock (rb) struct BLOCK *rb;
+void remove_block (block_t *rb)
 {
-  struct DECL *rd;
+  decl_t *rd;
   if (rb->quant.encl->parloc->descr == rb) 
     rb->quant.encl->parloc= rb->quant.encl->parloc->next;
   else
