@@ -27,7 +27,6 @@
  * av feilmeldinger. */
 
 #include "const.h"
-#include "dekl.h"
 #include "cimcomp.h"
 #include "error.h"
 #include "lex.h"
@@ -38,12 +37,20 @@
 #include <stdlib.h>
 #endif
 
+#include "config.h"
+
+#if STDC_HEADERS || HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+
 int anterror;
 
 /******************************************************************************
                                                                   STARTERROR */
-static starterror (line)
-     long line;
+static void
+starterror (long line)
 {
   anterror++;
   if (line == 0)
@@ -57,8 +64,7 @@ static starterror (line)
 
 /* Feil som oppdages av LEX */
 
-lerror (errcode)
-     int errcode;
+void lerror (int errcode)
 {
   if (option_nowarning && (errcode == 8 || errcode == 32))
     return;
@@ -180,9 +186,7 @@ lerror (errcode)
 /* Feil som oppdages av YACC */
 
 /*VARARGS1 */
-yerror (errcode, txt)
-     int errcode;
-     char *txt;
+void yerror (int errcode, char *txt)
 {
   char c;
   starterror (lineno);
@@ -250,9 +254,7 @@ yerror (errcode, txt)
 /* Feil som oppdages av DECL PASS 1 */
 
 /*VARARGS1 */
-d1error (errcode, name)
-     int errcode;
-     char *name;
+void d1error (int errcode, char *name)
 {
   starterror (lineno);
   switch (errcode)
@@ -293,10 +295,7 @@ d1error (errcode, name)
 /* Feil som oppdages av DECL PASS 2 */
 
 /*VARARGS1 */
-d2error (errcode, rd1, rd2)
-     int errcode;
-     struct DECL *rd1,
-      *rd2;
+void d2error (int errcode, decl_t *rd1, decl_t *rd2)
 {
   char *name1 = rd1->ident;
   starterror (errcode == 79 ? lineno : rd1->line);
@@ -411,9 +410,7 @@ d2error (errcode, rd1, rd2)
 /******************************************************************************
                                 				TEXTNUMBER   */
 
-char *
-textnumber (i)
-     int i;
+char *textnumber (int i)
 {
   static char s[10];
   switch (i)
@@ -460,10 +457,7 @@ textnumber (i)
 /* Feil som oppdages av SJEKKEREN */
 
 /*VARARGS1 */
-serror (errcode, name, ant)
-     int errcode,
-       ant;
-     char *name;
+void serror (int errcode, char *name, int ant)
 {
   char *antt;
   if (option_nowarning && errcode >= 81 && errcode <= 83 )
@@ -648,12 +642,10 @@ serror (errcode, name, ant)
 /******************************************************************************
                                 				GERROR       */
 
-/* Feil som oppdages av kodeGENERATOREN */
+/* Feil som oppdages av kodegeneratoren */
 
 /*VARARGS1 */
-gerror (errcode, name)
-     int errcode;
-     char *name;
+void gerror (int errcode, char *name)
 {
   starterror (lineno);
   switch (errcode)
@@ -684,9 +676,7 @@ gerror (errcode, name)
 /* Feil som oppdages under innlesing av eksterne moduler */
 
 /*VARARGS1 */
-merror (errcode, name)
-     int errcode;
-     char *name;
+void merror (int errcode, char *name)
 {
   if (option_nowarning && errcode == 3 && option_atr)
     return;
