@@ -26,5 +26,14 @@
  * Dette tabellverket brukes s} i forbindelse med utskrift              
  * av feilmeldinger. */
 
-extern int anterror;
+#include "dekl.h"
 
+extern int anterror;
+void lerror (int errcode);
+void yerror (int errcode, char *txt);
+void d1error (int errcode, char *name);
+void d2error (int errcode, decl_t *rd1, decl_t *rd2);
+char *textnumber (int i);
+void serror (int errcode, char *name, int ant);
+void gerror (int errcode, char *name);
+void merror (int errcode, char *name);
