@@ -30,9 +30,9 @@
 
 #if STDC_HEADERS || HAVE_STRING_H
 #include <string.h>
-#else /* not STDC_HEADERS and not HAVE_STRING_H */
+#else
 #include <strings.h>
-#endif /* not STDC_HEADERS and not HAVE_STRING_H */
+#endif
 
 #ifdef TIME_WITH_SYS_TIME
 #include <sys/time.h>
@@ -53,11 +53,11 @@ double strtod ();
 
 #include <obstack.h>
 char *xmalloc();
-void free();
 
 #define obstack_chunk_alloc xmalloc
 #define obstack_chunk_free free
-static struct obstack osExtspec;
+static struct obstack os_extspec;
+static char *first_object_allocated_ptr_extspec;
 
 /* HUSK AT REKKEF\LGEN SKAL V[RE categ,type,kind 
  *
@@ -66,7 +66,8 @@ static struct obstack osExtspec;
  * Deklarasjon av en klasse:
  *
  * <categ><type><kind><navn><blank><'!'<prefiks navn><blank> | '&'>
- * <fornest><blank><connest><blank><blno><blank><ent>
+ * <fornest><blank><connest><blank><maxusedref><blank>
+ * <maxusedtxt><blank><maxusedval><blank><blno><blank><ent>
  * <param.spec><virt. spec><hidden og protected spec><deklarasjoner><LF>
  *
  * Deklarasjon og spesifisering av prosedyre:
@@ -101,29 +102,35 @@ static struct obstack osExtspec;
 #define NO_MARKER '$'
 #define inchar(f) getc(f)
 #define getval(f, i)  { int tmp;fscanf(f,"%d",&tmp);i=tmp;}
-#define getconst(f, i)  { fscanf(f,"%d",&i);}
+#define getconst(f, i)  { fscanf(f,"%ld",&i);}
 
 /******************************************************************************
                                                               INITEXTSPEC    */
-void initExtspec ()
+void extspec_init (void)
 {
-  obstack_init (&osExtspec);
+  obstack_init (&os_extspec);
+  first_object_allocated_ptr_extspec= obstack_alloc (&os_extspec, 0);
+}
+
+void extspec_reinit (void)
+{
+  obstack_free (&os_extspec, first_object_allocated_ptr_extspec);
 }
 
 /******************************************************************************
                                                                   GETNAME    */
 
-static char * getname (f) FILE *f;
+static char * getname (FILE *f)
 {
   int c;
   char *s, *sx;
   for (c= getc (f); c !=EOF && c != '\n' && c!= ' '; c= getc (f))
-    obstack_1grow (&osExtspec, c);
+    obstack_1grow (&os_extspec, c);
 
-  obstack_1grow (&osExtspec, 0);
-  s= obstack_finish (&osExtspec);
+  obstack_1grow (&os_extspec, 0);
+  s= obstack_finish (&os_extspec);
   sx= tag (s);
-  obstack_free (&osExtspec, s);
+  obstack_free (&os_extspec, s);
   return sx;
 }
 
@@ -148,11 +155,11 @@ static char timestampchars[63] =
 /******************************************************************************
                                                           GETTIMESTAMP       */
 
-void gettimestamp ()
+void gettimestamp (void)
 {
 #if GET_TIME_OF_DAY
-  static struct timeval tp;
-  static struct timezone tzp;
+  struct timeval tp;
+  struct timezone tzp;
 #endif
 
   FILE *f;
@@ -189,46 +196,42 @@ void gettimestamp ()
 #endif
       th /= 252;
 
-      obstack_1grow (&osExtspec, timestampchars[th - th / 63 * 63]);
+      obstack_1grow (&os_extspec, timestampchars[th - th / 63 * 63]);
       th /= 63;
-      obstack_1grow (&osExtspec, timestampchars[th - th / 63 * 63]);
+      obstack_1grow (&os_extspec, timestampchars[th - th / 63 * 63]);
       while (t != 0)
 	{
-	  obstack_1grow (&osExtspec, timestampchars[t - t / 63 * 63]);
+	  obstack_1grow (&os_extspec, timestampchars[t - t / 63 * 63]);
 	  t /= 63;
 	}
-      obstack_1grow (&osExtspec, 0);
-      timestamp= obstack_finish (&osExtspec);
+      obstack_1grow (&os_extspec, 0);
+      timestamp= obstack_finish (&os_extspec);
     }
 }
 
 /******************************************************************************
                                                  GENATRFILENAMEFROMID        */
 
-static char *
-genatrfilenamefromid (ident)
-     char *ident;
+static char *genatrfilenamefromid (char *ident)
 {
   int i;
   char *s, *sx;
-  obstack_grow (&osExtspec, ident, strlen (ident));
-  obstack_grow0 (&osExtspec, ".atr", 4);
-  s= obstack_finish (&osExtspec);
+  obstack_grow (&os_extspec, ident, strlen (ident));
+  obstack_grow0 (&os_extspec, ".atr", 4);
+  s= obstack_finish (&os_extspec);
 
   for (i = strlen (s) - 5; i >= 0; i--)
     if (s[i] >= 'A' && s[i] <= 'Z')
       s[i] += 32;		/* LOWERCASE */
   sx= tag (s);
-  obstack_free (&osExtspec, s);
+  obstack_free (&os_extspec, s);
   return sx;
 }
 
 /******************************************************************************
                                               GENATRFILENAMEFROMFILENAME     */
 
-static char *
-genatrfilenamefromfilename (filename)
-char *filename;
+static char *genatrfilenamefromfilename (char *filename)
 {
   char *s, *sx;
   int len = strlen (filename);
@@ -239,28 +242,25 @@ char *filename;
   if (len >=4 && !(strcmp (&filename[len - 4], ".sim")
                   && strcmp (&filename[len - 4], ".SIM")
                   && strcmp (&filename[len - 4], ".cim")
-                  && strcmp (&filename[len - 4], ".CIM")))
-    obstack_grow (&osExtspec, filename, len - 4);
+		   && strcmp (&filename[len - 4], ".CIM")))
+    obstack_grow (&os_extspec, filename, len - 4);
   else
-    obstack_grow (&osExtspec, filename, len);
+    obstack_grow (&os_extspec, filename, len);
 
-  obstack_grow0 (&osExtspec, ".atr", 4);
-  s= obstack_finish (&osExtspec);
+  obstack_grow0 (&os_extspec, ".atr", 4);
+  s= obstack_finish (&os_extspec);
   sx= tag (s);
-  obstack_free (&osExtspec, s);
+  obstack_free (&os_extspec, s);
   return sx;
 }
 
 /******************************************************************************
                                                               EXTERNAL_IS_IN */
 
-static char 
-external_is_in (ident, kind)
-     char *ident;
-     char kind;
+static char external_is_in (char *ident, char kind)
 {
-  struct DECL *rd;
-  struct BLOCK *rb;
+  decl_t *rd;
+  block_t *rb;
 
   rb = cblock;
 
@@ -274,10 +274,9 @@ external_is_in (ident, kind)
 /******************************************************************************
                                                                     NEXTDECL */
 
-static char *lesinn ();
+static char *lesinn (char *filename);
 
-static nextdecl (f, filename, timestamp)
-     FILE *f; char *filename, *timestamp;
+static nextdecl (FILE *f, char *filename, char *timestamp)
 {
   char type, kind, categ;
   char tegn;
@@ -294,18 +293,18 @@ static nextdecl (f, filename, timestamp)
     return (FALSE);
   else if (categ == START_NEW_EXTERNAL_SPEC)
     {
-      char *localTimestamp;
-      char *localFilename;
+      char *local_timestamp;
+      char *local_filename;
       type = getc (f);
       kind = getc (f);
 
       ident = getname (f);	/* Leser navnet */
-      localTimestamp= getname (f); /* tidsmerket   */
-      localFilename= getname (f);    /* filnavnet    */
+      local_timestamp= getname (f); /* tidsmerket   */
+      local_filename= getname (f);    /* filnavnet    */
 
       if (!external_is_in (ident, kind))
 	{
-	  if (localTimestamp != lesinn (localFilename))
+	  if (local_timestamp != lesinn (local_filename))
 	    merror (4, filename);
 	}
       return (TRUE);
@@ -347,8 +346,8 @@ static nextdecl (f, filename, timestamp)
 		codeclass = CCCPROC;
 	    }
 	}
-      regDecl (ident, type, kind, categ);
-      beginBlock (kind);
+      reg_decl (ident, type, kind, categ);
+      begin_block (kind);
 
       cblock->timestamp= timestamp;
       cblock->filename= filename;
@@ -357,6 +356,11 @@ static nextdecl (f, filename, timestamp)
 	{
 	  getval (f, cblock->fornest);
 	  getval (f, cblock->connest);
+#if ACSTACK_IN_OBJ
+	  getval (f, cblock->maxusedref);
+	  getval (f, cblock->maxusedtxt);
+	  getval (f, cblock->maxusedval);
+#endif
 	}
       getval (f, cblock->ptypno);
       if (getc (f) == '%')
@@ -364,7 +368,7 @@ static nextdecl (f, filename, timestamp)
       getval (f, cblock->ent);
       /* Les inn parametere, virtuelle, hidden, protected og deklarasjoner */
       while (nextdecl (f, filename, timestamp));
-      endBlock (rtname, codeclass);
+      end_block (rtname, codeclass);
       break;
     default:
       if (type == TREF)
@@ -374,7 +378,7 @@ static nextdecl (f, filename, timestamp)
       switch (categ)
 	{
 	case CCONST:
-	  regDecl (ident, type, kind, categ);
+	  reg_decl (ident, type, kind, categ);
 	  if (type == TTEXT)
 	    {
 	      int i;
@@ -395,7 +399,7 @@ static nextdecl (f, filename, timestamp)
 	    }
 	  break;
 	default:
-	  regDecl (ident, type, kind, categ);
+	  reg_decl (ident, type, kind, categ);
 	  if (type == TLABEL)
 	    getconst (f, cprevdecl->plev);
 	  break;
@@ -409,8 +413,7 @@ static nextdecl (f, filename, timestamp)
 /******************************************************************************
                                                                       LESINN */
 
-static char *lesinn (filename)
-     char *filename;
+static char *lesinn (char *filename)
 {
   struct stamp *st;
   char *timestamp;
@@ -437,7 +440,7 @@ static char *lesinn (filename)
   for (st = first_stamp; st != NULL; st = st->next)
     if (st->timestamp == timestamp)
       goto found;
-  st = (struct stamp *) obstack_alloc (&osExtspec, sizeof (struct stamp));
+  st = (struct stamp *) obstack_alloc (&os_extspec, sizeof (struct stamp));
   st->timestamp = timestamp;
   st->next = first_stamp;
   st->lest_inn = FALSE;
@@ -450,21 +453,21 @@ found:
   /* Leser inn liste med tidsmerker */
   while (getc (f) == ' ')
     {
-      char *localTimestamp= getname (f);
-      char *localFilename= getname (f);
+      char *local_timestamp= getname (f);
+      char *local_filename= getname (f);
 
       for (st = first_stamp; st != NULL; st = st->next)
-	if (st->timestamp == localTimestamp)
+	if (st->timestamp == local_timestamp)
 	  goto find_next;
-      st = (struct stamp *) obstack_alloc (&osExtspec, sizeof (struct stamp));
-      st->timestamp = localTimestamp;
+      st = (struct stamp *) obstack_alloc (&os_extspec, sizeof (struct stamp));
+      st->timestamp = local_timestamp;
       st->next = first_stamp;
       st->lest_inn = FALSE;
-      st->filename = localFilename;
+      st->filename = local_filename;
       first_stamp = st;
     find_next:;
-      if (st->filename != localFilename)
-	merror (11, localFilename);
+      if (st->filename != local_filename)
+	merror (11, local_filename);
     }
 
   while (nextdecl (f, filename, timestamp));
@@ -476,14 +479,11 @@ found:
 /******************************************************************************
                                                         LESINN_EXTERNAL_SPEC */
 
-lesinn_external_spec (ident, filename, kind)
-     char *ident;
-     char *filename;
-     char kind;
+void lesinn_external_spec (char *ident, char *filename, char kind)
 {
   char *hprefquantident;
-  struct BLOCK *hcblock;
-  struct DECL *hclastdecl,
+  block_t *hcblock;
+  decl_t *hclastdecl,
    *rd;
   hprefquantident = prefquantident;
   hcblock = cblock;
@@ -518,7 +518,7 @@ static char link;
 
 /******************************************************************************
                                                            WRITE_INDENTATION */
-write_indentation (f, level) FILE *f; int level;
+static void write_indentation (FILE *f, int level)
 {
   int i;
   fprintf (f, "\n");
@@ -527,7 +527,7 @@ write_indentation (f, level) FILE *f; int level;
 
 /******************************************************************************
                                                               WRITE_CHAR_MIF */
-static write_char_mif (f, c) FILE *f; unsigned char c;
+static void write_char_mif (FILE *f, unsigned char c)
 {
   if ((isprint (c)
 #if ISO_LATIN
@@ -541,7 +541,7 @@ static write_char_mif (f, c) FILE *f; unsigned char c;
 
 /******************************************************************************
                                                               WRITE_TEXT_MIF */
-static write_text_mif (f, s) FILE *f; unsigned char *s;
+static void write_text_mif (FILE *f, unsigned char *s)
 {
   int i;
   fprintf (f, "= \"");
@@ -565,8 +565,7 @@ static write_text_mif (f, s) FILE *f; unsigned char *s;
 /******************************************************************************
                                                               WRITE_DECL_MIF */
 
-static write_decl_mif (f, rd, level)
-       FILE *f; struct DECL *rd; int level;
+static write_decl_mif (FILE *f, decl_t *rd, int level)
 {
   if (rd->kind == KBLOKK || rd->kind == KPRBLK || rd->kind == KFOR || 
       rd->kind == KINSP) return;
@@ -665,9 +664,9 @@ static write_decl_mif (f, rd, level)
     }
   else if (rd->kind == KPROC || rd->kind == KCLASS)
     {
-      struct DECL *rdv;
-      struct BLOCK *rb;
-      struct DECL *rdx;
+      decl_t *rdv;
+      block_t *rb;
+      decl_t *rdx;
       rb = rd->descr;
       if (rd->categ == CEXTROUT)
 	rd->categ = CEXTR;
@@ -696,8 +695,13 @@ static write_decl_mif (f, rd, level)
 #if 0
       /* Fornest,Connest,blno,ent */
       if (rb->quant.kind == KCLASS)
-	fprintf (f, "\n%% f_c_b_e %d %d %d %d",
-			rb->fornest, rb->connest, rb->blno, rb->ent);
+	{
+	  fprintf (f, "\n%% f_c_b_e %d %d ", rb->fornest, rb->connest);
+#if ACSTACK_IN_OBJ
+	  fprintf (f, "%d %d %d ", rb->fornest, rb->connest, rb->maxusedret);
+#endif
+	  fprintf (f, "%d %d", rb->blno, rb->ent);
+	}
 #endif
 
       if (rb->quant.kind == KCLASS)
@@ -748,12 +752,12 @@ static write_decl_mif (f, rd, level)
 		  s[i]='&';
 		  break;
 		}
-	    fprintf (f, s);
+	    fprintf (f, "%s", s);
 	  }
 	else if (rd->type == TCHAR)
 	  write_char_mif (f, rd->value.ival);
 	else
-	  fprintf (f, "= %d", rd->value.ival);
+	  fprintf (f, "= %ld", rd->value.ival);
       if (rd->kind == KARRAY && rd->type != TLABEL)
 	{
 	  int i;
@@ -789,11 +793,11 @@ static write_decl_mif (f, rd, level)
 /******************************************************************************
                                                                WRITE_ALL_MIF */
 
-write_all_mif ()
+static void write_all_mif (void)
 {
   /* Trenger ikke skrive ut lokale deklarasjoner i procedyrer */
 
-  struct DECL *rd;
+  decl_t *rd;
   struct stamp *st;
   FILE *f;
 
@@ -838,8 +842,7 @@ write_all_mif ()
 /******************************************************************************
                                                               WRITE_DECL_EXT */
 
-static write_decl_ext (f, rd)
-       FILE *f; struct DECL *rd;
+static write_decl_ext (FILE *f, decl_t *rd)
 {
   if (rd->kind == KBLOKK || rd->kind == KPRBLK || rd->kind == KFOR || 
       rd->kind == KINSP) ;
@@ -848,8 +851,8 @@ static write_decl_ext (f, rd)
 		    ,rd->ident, rd->descr->timestamp, rd->descr->filename);
   else if (rd->kind == KPROC || rd->kind == KCLASS)
     {
-      struct DECL *rdv;
-      struct BLOCK *rb;
+      decl_t *rdv;
+      block_t *rb;
       rb = rd->descr;
       if (rd->categ == CEXTROUT)
 	rd->categ = CEXTR;
@@ -868,7 +871,12 @@ static write_decl_ext (f, rd)
 
       /* Fornest,Connest,blno,ent */
       if (rb->quant.kind == KCLASS)
-	fprintf (f, "%d %d ", rb->fornest, rb->connest);
+	{
+	  fprintf (f, "%d %d ", rb->fornest, rb->connest);
+#if ACSTACK_IN_OBJ
+	  fprintf (f, "%d %d %d ", rb->fornest, rb->connest, rb->maxusedref);
+#endif
+	}
       fprintf (f, "%d %d", rb->blno, rb->ent);
 
       /* evt. parametere */
@@ -908,17 +916,17 @@ static write_decl_ext (f, rd)
       if (rd->type == TREF)
 	fprintf (f, "%s ", rd->prefqual->ident);
       else if (rd->type == TLABEL)
-	fprintf (f, "%d", rd->plev);
+	fprintf (f, "%ld", rd->plev);
 
       if (rd->categ == CCONST)
 	if (rd->type == TTEXT)
-	  fprintf (f, "%d %s "
+	  fprintf (f, "%ld %s "
 			  ,strlen (rd->value.tval.txt)
 			  ,rd->value.tval.txt);
 	else if (rd->type == TREAL)
 	  fprintf (f, "%.16e ", rd->value.rval);
 	else
-	  fprintf (f, "%d ", rd->value.ival);
+	  fprintf (f, "%ld ", rd->value.ival);
       if (rd->kind == KARRAY)
 	fprintf (f, "%c", (rd->dim + ((short) '0')));
     }
@@ -927,11 +935,11 @@ static write_decl_ext (f, rd)
 /******************************************************************************
                                                                WRITE_ALL_EXT */
 
-write_all_ext ()
+void write_all_ext (void)
 {
   /* Trenger ikke skrive ut lokale deklarasjoner i procedyrer */
 
-  struct DECL *rd;
+  decl_t *rd;
   struct stamp *st;
   FILE *f;
 
@@ -979,11 +987,11 @@ write_all_ext ()
 /******************************************************************************
                                                                 MORE_MODULES */
 
-more_modules ()
+void more_modules (void)
 {
   FILE *f;
   struct stamp *st;
-  char *localTimestamp;
+  char *local_timestamp;
   for (st = first_stamp; st != NULL; st = st->next)
     if (st->lest_inn == FALSE && (f = fopen (st->filename,
 #if OPEN_FILE_IN_BINARY_MODE
@@ -1004,8 +1012,8 @@ more_modules ()
 	
 	/* Leser tidsmerke */
 
-	localTimestamp= getname (f);
-	if (localTimestamp == st->timestamp)
+	local_timestamp= getname (f);
+	if (local_timestamp == st->timestamp)
 	  {
 	    if (option_verbose)
 	      fprintf (stderr, "Reading atr-file %s\n", st->filename);
