@@ -22,7 +22,6 @@
 
 #include <ctype.h>
 #include "gen.h"
-#include "parser.h"
 #include "name.h"
 #include "filelist.h"
 #include "error.h"
@@ -37,14 +36,15 @@ double strtod ();
 
 #include <obstack.h>
 char *xmalloc();
-void free();
 
 #define obstack_chunk_alloc xmalloc
 #define obstack_chunk_free free
 
-static struct obstack osLex, osIfdef;
+static struct obstack os_lex, os_ifdef;
+static char *first_object_allocated_ptr_lex;
+static char *first_object_allocated_ptr_ifdef;
 
-#define unput(c) {ungetc (c, includeFile ());}
+#define unput(c) {ungetc (c, include_file ());}
 static int notintext = TRUE;
 
 #define  newlexchar (lexchar=input())
@@ -71,10 +71,11 @@ char external = FALSE;	/* Har man sett "EXTERNAL PROC/CLASS =" angir
 				 * som ikke skal behandles som
 				 * en text-konstant. */
 
-struct ifdefstack
+typedef struct _ifdefstack ifdefstack_t;
+struct _ifdefstack
 {
   char ifdef;
-  struct ifdefstack *prev;
+  ifdefstack_t *prev;
 }  *ifdefp;
 
 char *flag, mellflag, bl_in_dir_line;
@@ -93,8 +94,7 @@ char staticblock = OFF;
  * Samt fjerne ^@ fra input
  * Dette skal dog ikke gjres innenfor text eller karakter -konstanter */
 
-static int 
-input ()
+static int input (void)
 {
   int yytchar;
   if (end_of_file)
@@ -105,7 +105,7 @@ input ()
   else
     do
       {
-	yytchar = getc (includeFile ());
+	yytchar = getc (include_file ());
       }
     while (yytchar == 0L);
   if (iscntrl (yytchar) && !isspace (yytchar) && yytchar != '\b'
@@ -169,9 +169,7 @@ input ()
 /******************************************************************************
                                                              PRINT_LEXSYMBOL */
 
-static print_lexsymbol (lextok, yylvalp)
-     int lextok;
-     YYSTYPE *yylvalp;
+void print_lexsymbol (int lextok, YYSTYPE *yylvalp)
 {
   int yyleng;
   switch (lextok)
@@ -366,7 +364,7 @@ static print_lexsymbol (lextok, yylvalp)
       printf ("& ");
       break;
     case HINTEGERKONST:
-      printf ("%d ", yylvalp->ival);
+      printf ("%ld ", yylvalp->ival);
       break;
     case HREALKONST:
       sprintf ((char *) yytext, "%.16e", yylvalp->rval);
@@ -380,12 +378,12 @@ static print_lexsymbol (lextok, yylvalp)
     case HCHARACTERKONST:
       if (iscntrl (yylvalp->ival)
 	  || yylvalp->ival == '\'')
-	printf ("'!%d!'", yylvalp->ival);
+	printf ("'!%ld!'", yylvalp->ival);
       else
-	printf ("'%c' ", yylvalp->ival);
+	printf ("'%c' ", (char) yylvalp->ival);
       break;
     case HTEXTKONST:
-      sprintf ((char *) yytext, "\"%s\"", yylvalp->ival);
+      sprintf ((char *) yytext, "\"%s\"", yylvalp->tval);
       for (yyleng = 0; yytext[yyleng]; yyleng++)
 	if (yytext[yyleng] == '\\')
 	  {
@@ -489,10 +487,7 @@ static print_lexsymbol (lextok, yylvalp)
 
 /* Rutine for } lage et heltall gitt et tall som er kodet tekstlig. */
 
-static long 
-radix (r, t)
-     int r;
-     char *t;
+static long radix (int r, char *t)
 {
   long maxint_div_r = MAX_INT / r;
 
@@ -531,36 +526,36 @@ radix (r, t)
 /******************************************************************************
 				                    SCANNAME & SCANNOWS      */
 
-static scanNows ()
+static void scan_nows (void)
 {
-  obstack_free (&osLex, yytext);
+  obstack_free (&os_lex, yytext);
   while (lexchar != '\n' && lexchar != EOF 
 	 && lexchar != ' ' && lexchar != '\t')
     {
-      obstack_1grow (&osLex, lexchar);
+      obstack_1grow (&os_lex, lexchar);
       newlexchar;
     }
-  obstack_1grow (&osLex, 0);
-  yytext= obstack_finish (&osLex);
+  obstack_1grow (&os_lex, 0);
+  yytext= obstack_finish (&os_lex);
 }
 
-static scanName ()
+static scan_name (void)
 {
-  obstack_free (&osLex, yytext);
+  obstack_free (&os_lex, yytext);
   while ((isalnum (lexchar) || lexchar == '_'))
     {
-      obstack_1grow (&osLex, lexchar);
+      obstack_1grow (&os_lex, lexchar);
       newlexchar;
     }
-  obstack_1grow (&osLex, 0);
-  yytext= obstack_finish (&osLex);
+  obstack_1grow (&os_lex, 0);
+  yytext= obstack_finish (&os_lex);
 }
 
 
 /******************************************************************************
 				                              SCANIFDEF      */
 
-static scanIfdef ()
+static void scan_ifdef (void)
 {
   char scan;
   char elsedef;
@@ -570,11 +565,11 @@ static scanIfdef ()
     {
       if (!strcmp (yytext, "ENDIF"))
 	{
-	  if (ifdefp == includeIfdefp ()) lerror (23);
+	  if (ifdefp == include_ifdefp ()) lerror (23);
 	  else 
 	    {
-	      struct ifdefstack *prev= ifdefp->prev;
-	      obstack_free (&osIfdef, ifdefp);
+	      ifdefstack_t *prev= ifdefp->prev;
+	      obstack_free (&os_ifdef, ifdefp);
 	      ifdefp= prev;
 	    }
 	}
@@ -615,7 +610,7 @@ static scanIfdef ()
 		newlexchar;
 	      if (isalpha (lexchar) || lexchar == '_')
 		{
-		  scanName ();
+		  scan_name ();
 	      
 		  if (elsedef == TRUE)
 		    {
@@ -628,14 +623,14 @@ static scanIfdef ()
 		    }
 		  else
 		    {
-		      struct ifdefstack *prev= ifdefp;
-		      ifdefp= (struct ifdefstack *)
-			obstack_alloc (&osIfdef, sizeof (struct ifdefstack));
+		      ifdefstack_t *prev= ifdefp;
+		      ifdefp= (ifdefstack_t *)
+			obstack_alloc (&os_ifdef, sizeof (ifdefstack_t));
 		      ifdefp->prev= prev;
 		      ifdefp->ifdef= 0;
 		      scan = FALSE;
 		    }
-		  ifdefp->ifdef = ifdefName (tag (yytext)) | IFGREN | scan;
+		  ifdefp->ifdef = ifdef_name (tag (yytext)) | IFGREN | scan;
 		}
 	      else 
 		{
@@ -651,7 +646,7 @@ static scanIfdef ()
 		ifdefp->ifdef++;
 	    }
 	}
-      if ((ifdefp->prev != includeIfdefp ()) && (ifdefp != includeIfdefp ()))
+      if ((ifdefp->prev != include_ifdefp ()) && (ifdefp != include_ifdefp ()))
 	{
 	  if (!((ifdefp->prev->ifdef == (IFGREN | TRUE)) ||
 		(ifdefp->prev->ifdef == (ELSEGREN | FALSE))))
@@ -673,7 +668,7 @@ static scanIfdef ()
 	       (newlexchar, bl_in_dir_line = TRUE) :
 	       ((bl_in_dir_line = FALSE), TRUE)) && isalpha (lexchar))
 	    {
-	      scanName ();
+	      scan_name ();
 	      break;
 	    }
 	}
@@ -683,13 +678,13 @@ static scanIfdef ()
 /******************************************************************************
 				                              SCANDIRFLAGS   */
 
-static scanDirflags ()
+static void scan_dirflags (void)
 {
   while (lexchar == ' ' | lexchar == '\t')
     newlexchar;
   if (isalpha (lexchar))
     {
-      scanName ();
+      scan_name ();
 
       if (lexchar == '\n' | lexchar == EOF
 	  | lexchar == ' ' | lexchar == '\t')
@@ -730,7 +725,7 @@ static scanDirflags ()
 /******************************************************************************
                                                                    DIRLINE   */
 
-static scanDirline ()
+static void scan_dirline (void)
 {
   FILE *file;
   lineno += antnewline;
@@ -746,7 +741,7 @@ static scanDirline ()
     bl_in_dir_line = FALSE;
   if (isalpha (lexchar))
     {
-      scanName ();
+      scan_name ();
       if (lexchar == '\n' | lexchar == EOF
 	  | lexchar == ' ' | lexchar == '\t')
 	{
@@ -756,7 +751,7 @@ static scanDirline ()
 	      if (!strcmp (yytext, "CASESENSITIVE"))
 		{
 		  flag = &sensitive;
-		  scanDirflags ();
+		  scan_dirflags ();
 		}
 	      else if (!strcmp (yytext, "COMMENT"))
 		{
@@ -774,7 +769,7 @@ static scanDirline ()
 			    option_bl_in_dir_line) ? newlexchar : 0, TRUE) 
 			  && isalpha (lexchar))
 			{
-			  scanName ();
+			  scan_name ();
 			  
 			  if (!strcmp (yytext, "COMMENT"))
 			    comlev++;
@@ -792,9 +787,9 @@ static scanDirline ()
 		    newlexchar;
 		  if (isalpha (lexchar) | lexchar == '_')
 		    {
-		      scanName ();
+		      scan_name ();
 		      
-		      defineName (tag (yytext), TRUE);
+		      define_name (tag (yytext), TRUE);
 		    }
 		  else if (!bl_in_dir_line) lerror (8);
 		}
@@ -803,30 +798,29 @@ static scanDirline ()
 	    case 'E':
 	      if (!strcmp (yytext, "EOF"))
 		{
-		  //fclose (includeFile ());
 		  end_of_file = 2;
 		  return;
 		}
-	      else if (!strcmp (yytext, "ELSE")) scanIfdef ();
-	      else if (!strcmp (yytext, "ELSEDEF")) scanIfdef ();
-	      else if (!strcmp (yytext, "ELSENOTDEF")) scanIfdef ();
-	      else if (!strcmp (yytext, "ENDIF")) scanIfdef ();
+	      else if (!strcmp (yytext, "ELSE")) scan_ifdef ();
+	      else if (!strcmp (yytext, "ELSEDEF")) scan_ifdef ();
+	      else if (!strcmp (yytext, "ELSENOTDEF")) scan_ifdef ();
+	      else if (!strcmp (yytext, "ENDIF")) scan_ifdef ();
 	      else if (!strcmp (yytext, "ENDCOMMENT")) lerror (15);
 	      else if (!bl_in_dir_line) lerror (8);
 	      break;
 	    case 'I':
-	      if (!strcmp (yytext, "IFDEF")) scanIfdef ();
-	      else if (!strcmp (yytext, "IFNOTDEF")) scanIfdef ();
-	      else if (!strcmp (yytext, "INCLUDE") || 
+	      if (!strcmp (yytext, "IFDEF")) scan_ifdef ();
+	      else if (!strcmp (yytext, "IFNOTDEF")) scan_ifdef ();
+	      else if (!strcmp (yytext, "INCLUDE") ||
 		       !strcmp (yytext, "INSERT"))
 		{
 		  notintext = FALSE;
-		  defineName (tag ("INCLUDED"), TRUE);
+		  define_name (tag ("INCLUDED"), TRUE);
 		  while (lexchar == ' ' | lexchar == '\t')
 		    newlexchar;
 		  if (lexchar != '\n' | lexchar != EOF)
 		    {
-		      scanNows ();
+		      scan_nows ();
 		      
 		      notintext = TRUE;
 
@@ -838,7 +832,7 @@ static scanDirline ()
 		{
 		  flag = &flaggpass2;
 		  mellflag = MINDEXTEST;
-		  scanDirflags ();
+		  scan_dirflags ();
 		}
 	      else if (!bl_in_dir_line) lerror (8);
 	      break;
@@ -851,14 +845,14 @@ static scanDirline ()
 		    newlexchar;
 		  if (isdigit (lexchar))
 		    {
-		      obstack_free (&osLex, yytext);
+		      obstack_free (&os_lex, yytext);
 		      while (isalnum (lexchar) || lexchar == '_')
 			{
-			  if (lexchar != '_') obstack_1grow (&osLex, lexchar);
+			  if (lexchar != '_') obstack_1grow (&os_lex, lexchar);
 			  newlexchar;
 			}
-		      obstack_1grow (&osLex, 0);
-		      yytext= obstack_finish (&osLex);
+		      obstack_1grow (&os_lex, 0);
+		      yytext= obstack_finish (&os_lex);
 		  
 		      nylinje = radix (10, yytext);
 		      notintext = FALSE;
@@ -866,7 +860,7 @@ static scanDirline ()
 			newlexchar;
 		      if (lexchar != '\n' & lexchar != EOF)
 			{
-			  scanNows ();
+			  scan_nows ();
 		      
 			  setfilmap (tag (yytext), nylinje);
 			}
@@ -885,10 +879,10 @@ static scanDirline ()
 		    newlexchar;
 		  if (isalpha (lexchar) | lexchar == '_')
 		    {
-		      scanName ();
+		      scan_name ();
 
 		      mainroutine= yytext;
-		      yytext= obstack_finish (&osLex);
+		      yytext= obstack_finish (&os_lex);
 		    }
 		  else if (!bl_in_dir_line) lerror (8);
 		}
@@ -900,13 +894,13 @@ static scanDirline ()
 	      else if (!strcmp (yytext, "NAMEASVAR"))
 		{
 		  flag = &nameasvar;
-		  scanDirflags ();
+		  scan_dirflags ();
 		}
 	      else if (!strcmp (yytext, "NONETEST"))
 		{
 		  flag = &flaggpass2;
 		  mellflag = MNONETEST;
-		  scanDirflags ();
+		  scan_dirflags ();
 		}
 	      else if (!bl_in_dir_line) lerror (8);
 	      break;
@@ -919,12 +913,12 @@ static scanDirline ()
 		{
 		  flag = &flaggpass2;
 		  mellflag = MSTRIPSIDEEFFECTS;
-		  scanDirflags ();
+		  scan_dirflags ();
 		}
 	      else if (!strcmp (yytext, "STATICBLOCK"))
 		{
 		  flag = &staticblock;
-		  scanDirflags ();
+		  scan_dirflags ();
 		}
 	      else if (!bl_in_dir_line) lerror (8);
 	      break;
@@ -935,10 +929,10 @@ static scanDirline ()
 		    newlexchar;
 		  if (isalpha (lexchar) | lexchar == '_')
 		    {
-		      scanName ();
+		      scan_name ();
 		  
 		      directive_timestamp= yytext;
-		      yytext= obstack_finish (&osLex);
+		      yytext= obstack_finish (&os_lex);
 		    }
 		  else if (!bl_in_dir_line) lerror (8);
 		}
@@ -952,9 +946,9 @@ static scanDirline ()
 		    newlexchar;
 		  if (isalpha (lexchar) | lexchar == '_')
 		    {
-		      scanName ();
+		      scan_name ();
 
-		      defineName (tag (yytext), FALSE);
+		      define_name (tag (yytext), FALSE);
 		    }
 		  else if (!bl_in_dir_line) lerror (8);
 		}
@@ -968,7 +962,7 @@ static scanDirline ()
   else
     /* Hvis det er en blank eller tom linje er hele linja en kommentar */
     if (lexchar != ' ' & lexchar != '\t' & lexchar != '\n'
-	 & lexchar != '\r' & lexchar != '!' & lexchar != EOF)
+	& lexchar != '\r' & lexchar != '!' & lexchar != EOF)
       if (!bl_in_dir_line) lerror (8);
 
   while (lexchar != '\n' && lexchar != EOF) newlexchar;
@@ -981,30 +975,40 @@ static scanDirline ()
 /******************************************************************************
                                                                    INITLEX   */
 
-int initLex (sourcename) char *sourcename;
+void lex_init (void)
 {
-  obstack_init (&osLex);
-  yytext= obstack_finish (&osLex);
-  obstack_init (&osIfdef);
-  ifdefp= obstack_alloc (&osIfdef, sizeof (struct ifdefstack));
+  obstack_init (&os_lex);
+  first_object_allocated_ptr_lex= obstack_alloc (&os_lex, 0);
+
+  obstack_init (&os_ifdef);
+  first_object_allocated_ptr_ifdef= obstack_alloc (&os_ifdef, 0);
+}
+
+int lex_init_pass1 (char *sourcename)
+{
+  yytext= obstack_finish (&os_lex);
+  ifdefp= obstack_alloc (&os_ifdef, sizeof (ifdefstack_t));
   ifdefp->prev= NULL;
   ifdefp->ifdef= 0;
-  if (maplineInit (sourcename, ifdefp)) return (TRUE);
+  if (mapline_init (sourcename, ifdefp)) return (TRUE);
   lineno = 1L;
   while (newlexchar == '%')
-    scanDirline ();
+    scan_dirline ();
   unput (lexchar);
   return FALSE;
 }
 
+void lex_reinit (void)
+{
+  obstack_free (&os_lex, first_object_allocated_ptr_lex);
+  obstack_free (&os_ifdef, first_object_allocated_ptr_ifdef);
+}
 /******************************************************************************
   						          PUTCHARACTER       */
 
 /* Hjelpe-prosedyre for } bygge opp et konstant-tektsobjekt. */
 
-static char *
-putcharacter (character)
-     unsigned char character;
+static char *putcharacter (unsigned char character)
 {
   static char s[10];
   if (external == TRUE)
@@ -1023,16 +1027,15 @@ putcharacter (character)
  *  for } bygge opp et konstant-tekstobjekt.
  *  Denne rutinen kalles for hvert tegn som skal inn i tekst-objektet. */
 
-static putchartext (character)
-     unsigned char character;
+static putchartext ( unsigned char character)
 {
   char *s;
   s = putcharacter (character);
-  obstack_grow (&osLex, s, strlen (s));
+  obstack_grow (&os_lex, s, strlen (s));
 }
 
 /******************************************************************************
-                                   				GETTEXT      */
+                                   			  GETQUOTEDTEXT      */
 
 /* Denne rutinen bygger opp et internt konstant-tekstobjekt og returnerer
  * en peker til det. Teksten er bygget opp p} en slik m}te at den 
@@ -1044,16 +1047,15 @@ static putchartext (character)
  * Disser er sstrcmp() og sstrlen() (sjekker.c).
  */
 
-static char *
-gettext ()
+static char *getquotedtext (void)
 {
   char *s;
 
-  if (obstack_object_size (&osLex) >= MAX_TEXT_CHAR)
+  if (obstack_object_size (&os_lex) >= MAX_TEXT_CHAR)
     lerror (44);
-  obstack_1grow (&osLex, 0);
-  s= obstack_finish (&osLex);
-  yytext= obstack_finish (&osLex);
+  obstack_1grow (&os_lex, 0);
+  s= obstack_finish (&os_lex);
+  yytext= obstack_finish (&os_lex);
   leerror = FALSE;
   return (s);
 }
@@ -1063,10 +1065,9 @@ gettext ()
 
 /* Returnerer et token til parser. */
 
-int 
-yylex ()
+int yylex (void)
 {
-  char firstLexchar;
+  char first_lexchar;
   int reported;
 
   while (TRUE)
@@ -1086,7 +1087,7 @@ yylex ()
       }
     if (isalpha (newlexchar))
       {
-	scanName ();
+	scan_name ();
 	
 	unput (lexchar);
 	switch (yytext[0])
@@ -1140,12 +1141,12 @@ yylex ()
 			{
 			  antnewline++;
 			  while (newlexchar == '%')
-			    scanDirline ();
+			    scan_dirline ();
 			  notintext = TRUE;
 			}
 		      else if (lexchar == EOF)
 			{
-			  //unput (lexchar);
+			  unput (lexchar);
 			  return (HEND);
 			}
 		      else if (lexchar == ';')
@@ -1450,36 +1451,36 @@ yylex ()
 	  {
 	  dotdigit:
 	    /* Behandling av tall som starter med tegnet '.' */
-	    obstack_free (&osLex, yytext);
+	    obstack_free (&os_lex, yytext);
 	    lexradix = 10;
 	  digitsdot:
-	    obstack_1grow (&osLex, '.');
+	    obstack_1grow (&os_lex, '.');
 	    if (lexchar >= '0' & lexchar <= '9')
-	      obstack_1grow (&osLex, lexchar);
+	      obstack_1grow (&os_lex, lexchar);
 	    while (newlexchar >= '0' && lexchar <= '9' || lexchar == '_')
 	      if (lexchar != '_')
-		obstack_1grow (&osLex, lexchar);
+		obstack_1grow (&os_lex, lexchar);
 	    if (lexchar == '&')
 	      {
 		newlexchar;
 	      digitsexp:
 		if (lexchar == '&')
 		  newlexchar;
-		obstack_1grow (&osLex, 'e');
+		obstack_1grow (&os_lex, 'e');
 		if (lexchar == '-')
 		  {
-		    obstack_1grow (&osLex, '-');
+		    obstack_1grow (&os_lex, '-');
 		    newlexchar;
 		  }
 		else if (lexchar == '+')
 		  newlexchar;
 		if (lexchar >= '0' & lexchar <= '9')
-		  obstack_1grow (&osLex, lexchar);
+		  obstack_1grow (&os_lex, lexchar);
 		while (newlexchar >= '0' && lexchar <= '9' || lexchar == '_')
-		  obstack_1grow (&osLex, lexchar);
+		  obstack_1grow (&os_lex, lexchar);
 	      }
-	    obstack_1grow (&osLex, 0);
-	    yytext= obstack_finish (&osLex);
+	    obstack_1grow (&os_lex, 0);
+	    yytext= obstack_finish (&os_lex);
 
 	    unput (lexchar);
 
@@ -1527,8 +1528,8 @@ yylex ()
 	  {
 	    lexradix = 10;
 
-	    obstack_free (&osLex, yytext);
-	    obstack_1grow (&osLex, '1');
+	    obstack_free (&os_lex, yytext);
+	    obstack_1grow (&os_lex, '1');
 
 	    goto digitsexp;
 	  }
@@ -1541,7 +1542,7 @@ yylex ()
 	  {
 	    antnewline++;
 	    while (newlexchar == '%')
-	      scanDirline ();
+	      scan_dirline ();
 	    unput (lexchar);
 	  }
 	if (lexchar != ';')
@@ -1632,7 +1633,7 @@ yylex ()
 	notintext = TRUE;
 	return (HCHARACTERKONST);
       case '\"':
-	obstack_free (&osLex, yytext);
+	obstack_free (&os_lex, yytext);
 	notintext = FALSE;
 	newlexchar;
 	while (TRUE)
@@ -1743,7 +1744,7 @@ yylex ()
 		    else
 		      {
 			unput (lexchar);
-			yylval.tval = gettext ();
+			yylval.tval = getquotedtext ();
 			notintext = TRUE;
 			return (HTEXTKONST);
 		      }
@@ -1753,7 +1754,7 @@ yylex ()
 	      {
 		antnewline++;
 		lerror (4);
-		yylval.tval = gettext ();
+		yylval.tval = getquotedtext ();
 		notintext = TRUE;
 		return (HTEXTKONST);
 	      }
@@ -1761,7 +1762,7 @@ yylex ()
 	      {
 		unput (lexchar);
 		lerror (5);
-		yylval.tval = gettext ();
+		yylval.tval = getquotedtext ();
 		notintext = TRUE;
 		return (HTEXTKONST);
 	      }
@@ -1778,25 +1779,25 @@ yylex ()
       case '8':
       case '9':
 	lexradix = 10;
-	firstLexchar= lexchar;
+	first_lexchar= lexchar;
 
-	obstack_free (&osLex, yytext);
-	obstack_1grow (&osLex, lexchar);
-	if (newlexchar == 'R' && (firstLexchar == '2' | firstLexchar == '4' 
-				  | firstLexchar == '8'))
+	obstack_free (&os_lex, yytext);
+	obstack_1grow (&os_lex, lexchar);
+	if (newlexchar == 'R' && (first_lexchar == '2' | first_lexchar == '4' 
+				  | first_lexchar == '8'))
 	  {
-	    lexradix = firstLexchar - '0';
-	    yytext= obstack_finish (&osLex);
-	    obstack_free (&osLex, yytext);
+	    lexradix = first_lexchar - '0';
+	    yytext= obstack_finish (&os_lex);
+	    obstack_free (&os_lex, yytext);
 	  }
-	else if (firstLexchar == '1' && lexchar == '6')
+	else if (first_lexchar == '1' && lexchar == '6')
 	  {
-	    obstack_1grow (&osLex, lexchar);
+	    obstack_1grow (&os_lex, lexchar);
 	    if (newlexchar == 'R')
 	      {
 		lexradix = 16;
-		yytext= obstack_finish (&osLex);
-		obstack_free (&osLex, yytext);
+		yytext= obstack_finish (&os_lex);
+		obstack_free (&os_lex, yytext);
 	      }
 	    else
 	      unput (lexchar);
@@ -1807,9 +1808,9 @@ yylex ()
 	       || lexchar == '_')
 	  if (lexchar == '_');
 	  else if (isdigit (lexchar))
-	    obstack_1grow (&osLex, lexchar);
+	    obstack_1grow (&os_lex, lexchar);
 	  else
-	    obstack_1grow (&osLex, lexchar + ('9' + 1 - 'A'));
+	    obstack_1grow (&os_lex, lexchar + ('9' + 1 - 'A'));
 	if (lexchar == '.' && lexradix == 10)
 	  {
 	    newlexchar;
@@ -1820,31 +1821,31 @@ yylex ()
 	    newlexchar;
 	    goto digitsexp;
 	  }
-	obstack_1grow (&osLex, 0);
-	yytext= obstack_finish (&osLex);
+	obstack_1grow (&os_lex, 0);
+	yytext= obstack_finish (&os_lex);
 
 	unput (lexchar);
 	yylval.ival = radix (lexradix, yytext);
 	return (HINTEGERKONST);
 
       case EOF:
-	if (ifdefp != includeIfdefp ())
+	if (ifdefp != include_ifdefp ())
 	  {
 	    lerror (24);
-	    ifdefp = (struct ifdefstack *) includeIfdefp ();
+	    ifdefp = (ifdefstack_t *) include_ifdefp ();
 	  }
-	fclose (includeFile ());	
+	fclose (include_file ());	
 	popfilmap ();
-	if (noFilemap ())
+	if (no_filemap ())
 	  return (NOSYMBOL);
-	defineName (tag ("INCLUDED"), FALSE);
+	define_name (tag ("INCLUDED"), FALSE);
 	/* Ingen break her */
       case '\n':			/* NL (LF) */
 	lineno++;
 	if (!option_write_tokens)
 	  mout (MNEWLINE);
 	while (newlexchar == '%')
-	  scanDirline ();
+	  scan_dirline ();
 	unput (lexchar);
 	break;
       case ' ':
@@ -1864,7 +1865,7 @@ yylex ()
 /******************************************************************************
                                                        SCAN_AND_WRITE_TOKENS */
 
-scan_and_write_tokens ()
+void scan_and_write_tokens (void)
 {
   int token;
   long line = 1L;
