@@ -16,12 +16,17 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */
 
+#include "parser.h"
+
 extern char external;
 extern long lineno;
 extern char nameasvar;
 extern char sensitive;
 extern char staticblock;
 
-extern yylex ();
-extern initLex ();
-extern scan_and_write_tokens ();
+int yylex (void);
+void lex_init (void);
+int lex_init_pass1 (char *sourcename);
+void lex_reinit (void);
+void scan_and_write_tokens (void);
+void print_lexsymbol (int lextok, YYSTYPE *yylvalp);
