@@ -17,84 +17,97 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */
 
 #include <obstack.h>
+#include "mellbuilder.h"
+#include "config.h"
+
+#if STDC_HEADERS || HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+#include "config.h"
+
+#if STDC_HEADERS
+#include <stdlib.h>
+#endif
 
 char *xmalloc();
-void free();
 
 #define obstack_chunk_alloc xmalloc
 #define obstack_chunk_free free
 
-static struct obstack osMell;
+static struct obstack os_mell;
+static char *first_object_allocated_ptr_mell;
+static char *last_object_allocated_ptr_mell;
 
-static char *mstring,  *mend;
 char *mpointer;
 
 /******************************************************************************
                                                                 MBUILDERINIT */
 
-mbuilderInit()
+void mbuilder_init(void)
 {
-  obstack_init(&osMell);
+  obstack_init(&os_mell);
 }
 
 /******************************************************************************
                                                                         MOUT */
 
-mout(x)unsigned char x;
+void mout(unsigned char x)
 {
-  obstack_1grow(&osMell, x);
+  obstack_1grow(&os_mell, x);
 }
 
 /******************************************************************************
                                                                     MOUTIVAL */
 
-moutIval(x)long x;
+void mout_ival(long x)
 {
-  obstack_grow(&osMell, &x, sizeof (long));
+  obstack_grow(&os_mell, &x, sizeof (long));
 }
 
 /******************************************************************************
                                                                     MOUTRVAL */
 
-moutRval(x)double x;
+void mout_rval(double x)
 {
-  obstack_grow(&osMell, &x,sizeof (double));
+  obstack_grow(&os_mell, &x,sizeof (double));
 }
 
 /******************************************************************************
                                                                     MOUTTVAL */
 
-moutTval(x)char *x;
+void mout_tval(char *x)
 {
-  obstack_grow(&osMell, &x, sizeof (char *));
+  obstack_grow(&os_mell, &x, sizeof (char *));
 }
 
 /******************************************************************************
                                                                       MOUTID */
 
-moutId(x)char *x;
+void mout_id(char *x)
 {
-  obstack_grow(&osMell, &x, sizeof (char *));
+  obstack_grow(&os_mell, &x, sizeof (char *));
 }
 
 /******************************************************************************
                                                               MBUILDERREINIT */
 
-mbuilderReinit()
+void mbuilder_init_pass2(void)
 {
   long i;
-  i= obstack_object_size(&osMell);
-  mpointer= mstring= (char *)obstack_finish (&osMell);
-  mend= mpointer+i;
+  i= obstack_object_size(&os_mell);
+  mpointer= first_object_allocated_ptr_mell= (char *)obstack_finish (&os_mell);
+  last_object_allocated_ptr_mell= mpointer+i;
 }
 
 /******************************************************************************
                                                                          MIN */
 
-int min()
+int min(void)
 {
   unsigned char x;
-  if (mpointer>=mend) return -1;
+  if (mpointer>=last_object_allocated_ptr_mell) return -1;
   x= *(mpointer++);
   return (x);
 }
@@ -102,7 +115,7 @@ int min()
 /******************************************************************************
                                                                      MINIVAL */
 
-long minIval()
+long min_ival(void)
 {
   long x;
   memmove (&x,mpointer,sizeof(long));
@@ -113,7 +126,7 @@ long minIval()
 /******************************************************************************
                                                                      MINRVAL */
 
-double minRval()
+double min_rval(void)
 {
   double x;
   memmove (&x,mpointer,sizeof (double));
@@ -124,7 +137,7 @@ double minRval()
 /******************************************************************************
                                                                      MINTVAL */
 
-char *minTval()
+char *min_tval(void)
 {
   char *x;
   memmove(&x,mpointer,sizeof(char *));
@@ -135,7 +148,7 @@ char *minTval()
 /******************************************************************************
                                                                        MINID */
 
-char *minId()
+char *min_id(void)
 {
   char *x;
   memmove (&x,mpointer,sizeof(char *));
@@ -143,4 +156,16 @@ char *minId()
   return(x);
 }
 
+/******************************************************************************
+                                                                       MINID */
+
+void mbuilder_reinit(void)
+{
+  if (first_object_allocated_ptr_mell == 0)
+    first_object_allocated_ptr_mell= (char *)obstack_finish (&os_mell);
+
+  obstack_free (&os_mell, first_object_allocated_ptr_mell);
+
+  first_object_allocated_ptr_mell= 0;
+}
 
