@@ -30,24 +30,19 @@
 
 #include <obstack.h>
 
-#include <string.h>
-
 char *xmalloc();
-void free();
 
 #define obstack_chunk_alloc xmalloc
 #define obstack_chunk_free free
 
-static struct obstack osName;
+static struct obstack os_name;
 
 static void *hashlist[NAMEPRIMEVALUE];
 
 /******************************************************************************
                                                                    TAG       */
 
-char *
-tag (t)
-     char t[];
+char *tag (char t[])
 {
   int leng;
   long hash;
@@ -67,14 +62,10 @@ tag (t)
       prevlist = list;
     }
 
-#if 0
-  obstack_ptr_grow(&osName, NULL);
-#else
-  obstack_grow(&osName, &ptr, sizeof (void *));
-#endif
-  obstack_grow0 (&osName, t, leng);
-  obstack_1grow (&osName, FALSE);
-  list= (void * *)obstack_finish (&osName);
+  obstack_grow(&os_name, &ptr, sizeof (void *));
+  obstack_grow0 (&os_name, t, leng);
+  obstack_1grow (&os_name, FALSE);
+  list= (void * *)obstack_finish (&os_name);
 
   if (prevlist == NULL)
     hashlist[hash] = list;
@@ -87,15 +78,14 @@ tag (t)
 /******************************************************************************
                                                     DEFINENAME & IFDEFNAME   */
 
-defineName (t, d) char *t; char d;
+void define_name (char *t, char d)
 {
   while (*t != 0) t++;
   t++;
   *t= d;
 }
 
-char
-ifdefName (t) char *t;
+char ifdef_name (char *t)
 {
   while (*t != 0) t++;
   t++;
@@ -106,16 +96,16 @@ ifdefName (t) char *t;
 /******************************************************************************
                                                                     INITNAME */
 
-initName ()
+void init_name (void)
 {
-  obstack_init(&osName);
-  defineName (tag ("CIM"), TRUE);
+  obstack_init(&os_name);
+  define_name (tag ("CIM"), TRUE);
 #if INT_64
-  defineName (tag ("INTEGER_64"), TRUE);
+  define_name (tag ("INTEGER_64"), TRUE);
 #endif
 
-  defineName (tag (CPU_TYPE), TRUE);
-  defineName (tag (MANUFACTURER), TRUE);
-  defineName (tag (OS_TYPE), TRUE);
-  defineName (tag (OS_TYPE_VERSION), TRUE);
+  define_name (tag (CPU_TYPE), TRUE);
+  define_name (tag (MANUFACTURER), TRUE);
+  define_name (tag (OS_TYPE), TRUE);
+  define_name (tag (OS_TYPE_VERSION), TRUE);
 }
