@@ -18,131 +18,134 @@
 
 #include <stdio.h>
 #include <obstack.h>
+#include "newstr.h"
+#include "config.h"
+
+#if STDC_HEADERS || HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+
+#if STDC_HEADERS
+#include <stdlib.h>
+#endif
+
 
 char *xmalloc();
-void free();
 
 #define obstack_chunk_alloc xmalloc
 #define obstack_chunk_free free
 
-static struct obstack osNewstr;
+static struct obstack os_newstr;
 
 /******************************************************************************
                                                                   INITNEWSTR */
-void initNewstr ()
+void init_newstr (void)
 {
-  obstack_init(&osNewstr);
+  obstack_init(&os_newstr);
 }
 
 /******************************************************************************
                                                                  NEWSTRGROW1 */
 
-void newstrGrown(s1, n)
-     char *s1; int n;
+void newstr_grown(char *s1, int n)
 {
-  obstack_grow (&osNewstr, s1, n);
+  obstack_grow (&os_newstr, s1, n);
 }
 
 /******************************************************************************
                                                                  NEWSTRGROW1 */
 
-void newstrGrow1(s1)
-     char *s1;
+void newstr_grow1(char *s1)
 {
-  obstack_grow (&osNewstr, s1, strlen(s1));
+  obstack_grow (&os_newstr, s1, strlen(s1));
 }
 
 /******************************************************************************
                                                                  NEWSTRGROW1 */
 
-void newstrGrow2(s1, s2)
-     char *s1, *s2;
+void newstr_grow2(char *s1, char *s2)
 {
-  obstack_grow (&osNewstr, s1, strlen(s1));
-  obstack_grow (&osNewstr, s2, strlen(s2));
+  obstack_grow (&os_newstr, s1, strlen(s1));
+  obstack_grow (&os_newstr, s2, strlen(s2));
 }
 
 /******************************************************************************
                                                                 NEWSTRFINISH */
 
-char *newstrFinish()
+char *newstr_finish(void)
 {
-  obstack_1grow (&osNewstr, 0);
-  return obstack_finish (&osNewstr);;
+  obstack_1grow (&os_newstr, 0);
+  return obstack_finish (&os_newstr);;
 }
 
 /******************************************************************************
                                                                   NEWSTRCAT1 */
 
-char * newstrcat1(s1)
-     char *s1;
+char *newstrcat1(char *s1)
 {
-  obstack_grow0 (&osNewstr, s1, strlen(s1));
-  return obstack_finish (&osNewstr);;
+  obstack_grow0 (&os_newstr, s1, strlen(s1));
+  return obstack_finish (&os_newstr);;
 }
 
 /******************************************************************************
                                                                   NEWSTRCAT2 */
 
-char * newstrcat2(s1, s2)
-     char *s1, *s2;
+char *newstrcat2(char *s1, char *s2)
 {
-  obstack_grow (&osNewstr, s1, strlen(s1));
-  obstack_grow0 (&osNewstr, s2, strlen(s2));
-  return obstack_finish (&osNewstr);;
+  obstack_grow (&os_newstr, s1, strlen(s1));
+  obstack_grow0 (&os_newstr, s2, strlen(s2));
+  return obstack_finish (&os_newstr);;
 }
 
 /******************************************************************************
                                                                   NEWSTRCAT3 */
 
-char * newstrcat3(s1, s2, s3)
-     char *s1, *s2, *s3;
+char *newstrcat3(char *s1, char *s2, char *s3)
 {
-  obstack_grow (&osNewstr, s1, strlen(s1));
-  obstack_grow (&osNewstr, s2, strlen(s2));
-  obstack_grow0 (&osNewstr, s3, strlen(s3));
-  return obstack_finish (&osNewstr);;
+  obstack_grow (&os_newstr, s1, strlen(s1));
+  obstack_grow (&os_newstr, s2, strlen(s2));
+  obstack_grow0 (&os_newstr, s3, strlen(s3));
+  return obstack_finish (&os_newstr);;
 }
 
 /******************************************************************************
                                                                   NEWSTRCAT4 */
 
-char * newstrcat4(s1, s2, s3, s4)
-     char *s1, *s2, *s3, *s4;
+char *newstrcat4(char *s1, char *s2, char *s3, char *s4)
 {
-  obstack_grow (&osNewstr, s1, strlen(s1));
-  obstack_grow (&osNewstr, s2, strlen(s2));
-  obstack_grow (&osNewstr, s3, strlen(s3));
-  obstack_grow0 (&osNewstr, s4, strlen(s4));
-  return obstack_finish (&osNewstr);;
+  obstack_grow (&os_newstr, s1, strlen(s1));
+  obstack_grow (&os_newstr, s2, strlen(s2));
+  obstack_grow (&os_newstr, s3, strlen(s3));
+  obstack_grow0 (&os_newstr, s4, strlen(s4));
+  return obstack_finish (&os_newstr);;
 }
 
 /******************************************************************************
                                                                   NEWSTRCAT5 */
 
-char * newstrcat5(s1, s2, s3, s4, s5)
-     char *s1, *s2, *s3, *s4, *s5;
+char *newstrcat5(char *s1, char *s2, char *s3, char *s4, char *s5)
 {
-  obstack_grow (&osNewstr, s1, strlen(s1));
-  obstack_grow (&osNewstr, s2, strlen(s2));
-  obstack_grow (&osNewstr, s3, strlen(s3));
-  obstack_grow (&osNewstr, s4, strlen(s4));
-  obstack_grow0 (&osNewstr, s5, strlen(s5));
-  return obstack_finish (&osNewstr);;
+  obstack_grow (&os_newstr, s1, strlen(s1));
+  obstack_grow (&os_newstr, s2, strlen(s2));
+  obstack_grow (&os_newstr, s3, strlen(s3));
+  obstack_grow (&os_newstr, s4, strlen(s4));
+  obstack_grow0 (&os_newstr, s5, strlen(s5));
+  return obstack_finish (&os_newstr);;
 }
 
 /******************************************************************************
                                                                   NEWSTRCAT6 */
 
-char * newstrcat6(s1, s2, s3, s4, s5, s6)
-     char *s1, *s2, *s3, *s4, *s5, *s6;
+char *newstrcat6(char *s1, char *s2, char *s3, char *s4, char *s5, char *s6)
 {
-  obstack_grow (&osNewstr, s1, strlen(s1));
-  obstack_grow (&osNewstr, s2, strlen(s2));
-  obstack_grow (&osNewstr, s3, strlen(s3));
-  obstack_grow (&osNewstr, s4, strlen(s4));
-  obstack_grow (&osNewstr, s5, strlen(s5));
-  obstack_grow0 (&osNewstr, s6, strlen(s6));
-  return obstack_finish (&osNewstr);;
+  obstack_grow (&os_newstr, s1, strlen(s1));
+  obstack_grow (&os_newstr, s2, strlen(s2));
+  obstack_grow (&os_newstr, s3, strlen(s3));
+  obstack_grow (&os_newstr, s4, strlen(s4));
+  obstack_grow (&os_newstr, s5, strlen(s5));
+  obstack_grow0 (&os_newstr, s6, strlen(s6));
+  return obstack_finish (&os_newstr);;
 }
 
