@@ -20,6 +20,8 @@
 #include "gen.h"
 #include "extspec.h"
 #include "error.h"
+#include "passes.h"
+#include "dump.h"
 
 char not_reached;
 
@@ -28,21 +30,21 @@ char *mainroutine = "main";
 /******************************************************************************
                                                                  SENTLISTGEN */
 
-void sentListGen (parentSent, lab) struct SENT *parentSent; int lab;
+static void sent_list_gen (sent_t *parent_sent, int lab)
 {
-  struct SENT *sent;
+  sent_t *sent;
 
-  for (sent= parentSent->first; sent!=NULL; sent= sent->next)
+  for (sent= parent_sent->first; sent!=NULL; sent= sent->next)
     {
       lineno= sent->line;
       nonetest= sent->nonetest;
       indextest= sent->indextest;
       stripsideeffects= sent->stripsideeffects;
-      sentGen (sent, lab);
-      cblock= parentSent->cblock;
+      sent_gen (sent, lab);
+      cblock= parent_sent->cblock;
       if (cblock) cblev= cblock->blev;
     }
-  lineno= parentSent->lastLine;
+  lineno= parent_sent->last_line;
 }
 
 
@@ -51,8 +53,9 @@ void sentListGen (parentSent, lab) struct SENT *parentSent; int lab;
 /******************************************************************************
                                                                      GENINIT */
 
-genInit ()
+static void gen_init (void)
 {
+#if 0
   fprintf (ccode, "/*Cim_ccode*/\n");
   if (!separat_comp)
     {
@@ -60,27 +63,59 @@ genInit ()
     }
   fprintf (ccode, "#include \"%s/cim.h\"\n", 
 	   includedir);
+#endif
 }
 
 /******************************************************************************
                                                                    MODULEGEN */
 
-moduleGen (sent) struct SENT *sent;
+static void module_gen (sent_t *sent)
 {
   int i;
+
+  fprintf (ccode, "/*Cim_ccode*/\n");
+  if (!separat_comp)
+    {
+      fprintf (ccode, "int __start_data_segment=1;\n");
+    }
+  fprintf (ccode, "#include \"%s/cim.h\"\n", 
+	   includedir);
+
+#ifdef DEBUG
+  if (option_dump_build)
+    sent_dump (main_sent, 0);
+#endif
+
+  sent_check (sent, TRUE);
+
+  if (anterror) return;
+
+#ifdef DEBUG
+  if (option_dump_check)
+    sent_dump (main_sent, 0);
+#endif
+
+  sent_trans (main_sent);
+
+#ifdef DEBUG
+  if (option_dump_trans)
+    sent_dump (main_sent, 0);
+#endif
+
   structure ();
+
   if (separat_comp)
     {
       fprintf (ccode, "void ");
       genmodulemark(NULL);
-      fprintf (ccode, "(){");
+      fprintf (ccode, "(void){");
       if (!option_line)
 	fprintf (ccode, "__curent_map=__map%s;", timestamp);
       fprintf (ccode, "goto __s;");
     }
   else
     {
-      fprintf (ccode, "%s(__argc,__argv)int __argc;char *__argv[];{"
+      fprintf (ccode, "int %s(int __argc, char *__argv[]){"
 	       "__progname= __argv[0];"
 	       ,mainroutine);
 
@@ -100,7 +135,7 @@ moduleGen (sent) struct SENT *sent;
 	fprintf (ccode, "__curent_map=__mapmain;");
     }
 
-  sentListGen (sent);
+  sent_list_gen (sent, 0);
 
   if (separat_comp)
     {
@@ -139,7 +174,7 @@ moduleGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                     BLOCKGEN */
 
-blockGen (sent) struct SENT *sent;
+static void block_gen (sent_t *sent)
 {
   cblock= sent->cblock;
   cblev= cblock->blev;
@@ -153,8 +188,8 @@ blockGen (sent) struct SENT *sent;
   fprintf (ccode, ");");
 
   gotollabel (sent->cblock->ent = newllabel ());
-  sentListGen (sent);
-
+  sent_list_gen (sent, 0);
+  
   if (not_reached == FALSE)
     fprintf (ccode, "__rbe();");
 }
@@ -162,7 +197,7 @@ blockGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                   PRBLOCKGEN */
 
-prblockGen (sent) struct SENT *sent;
+static void prblock_gen (sent_t *sent)
 {
   int labexit;
   if (not_reached == FALSE)
@@ -187,21 +222,21 @@ prblockGen (sent) struct SENT *sent;
   fprintf (ccode, ");");
   gotoswitch ();
   
-  sentListGen (sent, sent->cblock->ent+1);
+  sent_list_gen (sent, sent->cblock->ent+1);
   if (not_reached == FALSE)
-    fprintf (ccode, "__rendclass(%d);", sent->cblock->quant.plev);
+    fprintf (ccode, "__rendclass(%ld);", sent->cblock->quant.plev);
   exitlabel (labexit);
 }
 
 /******************************************************************************
                                                                 PROCEDUREGEN */
 
-procedureGen (sent) struct SENT *sent;
+static void procedure_gen (sent_t *sent)
 {
   cblock= sent->cblock;
   cblev= cblock->blev;
   fprintf (ccode, "/* START PROCEDURE %s */", sent->cblock->quant.ident);
-  sentListGen (sent);
+  sent_list_gen (sent, 0);
   if (not_reached == FALSE)
     {
       genline ();
@@ -232,14 +267,14 @@ procedureGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                     CLASSGEN */
 
-classGen (sent) struct SENT *sent;
+static void class_gen (sent_t *sent)
 {
   cblock= sent->cblock;
   cblev= cblock->blev;
   fprintf (ccode, "/* START CLASS %s */", sent->cblock->quant.ident);
-  sentListGen (sent, sent->cblock->ent+1);
+  sent_list_gen (sent, sent->cblock->ent+1);
   genline ();
-  fprintf (ccode, "__rendclass(%d);", sent->cblock->quant.plev);
+  fprintf (ccode, "__rendclass(%ld);", sent->cblock->quant.plev);
   gotoswitch ();
   fprintf (ccode, "/* SLUTT CLASS %s */", sent->cblock->quant.ident);
 }
@@ -247,7 +282,7 @@ classGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                   INSPECTGEN */
 
-inspectGen (sent) struct SENT *sent;
+static void inspect_gen (sent_t *sent)
 {
   int labnull, labexit;
   if (not_reached == FALSE)
@@ -259,15 +294,14 @@ inspectGen (sent) struct SENT *sent;
   cblev= cblock->blev;
   genvalue (sent->iexp); fprintf (ccode, ";");
 
-  fprintf (ccode, "((__bs%d *)__lb)->c%d=", 
-	   sent->cblock->quant.match->descr->blno,
-	   sent->cblock->connest);
+  gen_con_ref (sent->cblock->connest);
+  fprintf (ccode, "=");
   genvalue (sent->exp);
   fprintf (ccode, ";");
 
-  fprintf (ccode, "if(((__bs%d *)__lb)->c%d==__NULL)", 
-	   sent->cblock->quant.match->descr->blno, 
-	   sent->cblock->connest);
+  fprintf (ccode, "if(");
+  gen_con_ref (sent->cblock->connest);
+  fprintf (ccode, "==__NULL)");
 
   labexit = newllabel ();
 
@@ -280,11 +314,12 @@ inspectGen (sent) struct SENT *sent;
 
 
   if (sent->first!=NULL && sent->first->token == MWHEN)
-    fprintf (ccode, "__pp=((__bs%d *)__lb)->c%d->pp; ",
-	     sent->cblock->quant.match->descr->blno, 
-	     sent->cblock->connest);
-
-  sentListGen (sent, labexit);
+    {
+      fprintf (ccode, "__pp=");
+      gen_con_ref (sent->cblock->connest);
+      fprintf (ccode, "->pp; ");
+    }
+  sent_list_gen (sent, labexit);
 
   if (sent->last!=NULL && sent->last->token == MOTHERWISE)
     {
@@ -292,7 +327,7 @@ inspectGen (sent) struct SENT *sent;
       cblock= sent->last->cblock;
       cblev= cblock->blev;
       
-      sentListGen (sent->last);
+      sent_list_gen (sent->last, 0);
   
       if (not_reached == FALSE)
 	genline ();
@@ -303,12 +338,12 @@ inspectGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                        DOGEN */
 
-doGen (sent, labexit) struct SENT *sent; int labexit;
+static void do_gen (sent_t *sent, int labexit)
 {
   cblock= sent->cblock;
   cblev= cblock->blev;
 
-  sentListGen (sent);
+  sent_list_gen (sent, 0);
 
   if (not_reached == FALSE)
     {
@@ -320,13 +355,13 @@ doGen (sent, labexit) struct SENT *sent; int labexit;
 /******************************************************************************
                                                                      WHENGEN */
 
-whenGen (sent, labexit) struct SENT *sent; int labexit;
+static void when_gen (sent_t *sent, int labexit)
 {
   int labnextcase;
   cblock= sent->cblock;
   cblev= cblock->blev;
 
-  fprintf (ccode, "if(__pp->plev < %d || __pp->pref[%d]!= ", 
+  fprintf (ccode, "if(__pp->plev < %ld || __pp->pref[%ld]!= ", 
 	   sent->exp->rd->plev, sent->exp->rd->plev);
 
   gen_adr_prot (ccode, sent->exp->rd);
@@ -334,7 +369,7 @@ whenGen (sent, labexit) struct SENT *sent; int labexit;
 
   gotollabel (labnextcase = newllabel ());
 
-  sentListGen (sent);
+  sent_list_gen (sent, 0);
 
   if (not_reached == FALSE)
     {
@@ -347,23 +382,21 @@ whenGen (sent, labexit) struct SENT *sent; int labexit;
 /******************************************************************************
                                                                 OTHERWISEGEN */
 
-otherwiseGen (sent) struct SENT *sent;
+static void otherwise_gen (sent_t *sent)
 {
 }
 
 /******************************************************************************
                                                        GFORELEM              */
 /* Genererer kode for en for lkke for ett liste element                     */
-static forelemgen (re, rex, labcontinue, labdo, labexit, single, 
-		   notlastdefault, listnrp)
-     struct EXP *re, *rex;
-     int labcontinue, labdo, labexit, single, notlastdefault;
-     int *listnrp;
+static int forelemgen (exp_t *re, exp_t *rex,
+		   int labcontinue, int labdo, int labexit, int single, int notlastdefault,
+		   int *listnrp)
 {
-  struct EXP *rey;
+  exp_t *rey;
   int labnext;
 
-  struct EXP *reconc, *red;
+  exp_t *reconc, *red;
 
   rey= rex->left;
   switch (rey->token)
@@ -383,9 +416,9 @@ static forelemgen (re, rex, labcontinue, labdo, labexit, single,
 	}
       else
 	{
-	  fprintf (ccode, "{((__bs%d *)__lb)->f%d= %d;", 
-		   cblock->quant.match->descr->blno, 
-		   cblock->fornest, ++*listnrp);
+	  fprintf (ccode, "{");
+	  gen_for_val(cblock->fornest);
+	  fprintf (ccode, "= %d;", ++*listnrp);
 	  gotollabel (labdo);
 	  fprintf (ccode, "}");
 	  
@@ -412,10 +445,8 @@ static forelemgen (re, rex, labcontinue, labdo, labexit, single,
 	typellabel (labcontinue);
       else if (notlastdefault)
 	{
-	  fprintf (ccode, "((__bs%d *)__lb)->f%d= %d;", 
-		   cblock->quant.match->descr->blno, 
-		   cblock->fornest, ++*listnrp);
-	  fprintf (ccode, "   case %d:", *listnrp);
+	  gen_for_val(cblock->fornest);
+	  fprintf (ccode, "= %d;", ++*listnrp);
 	}
       genvalue (rey->left); fprintf (ccode, ";");
       fprintf (ccode, "if(");
@@ -431,9 +462,8 @@ static forelemgen (re, rex, labcontinue, labdo, labexit, single,
       genvalue (rey); fprintf (ccode, ";");
       if (!single)
 	{
-	  fprintf (ccode, "((__bs%d *)__lb)->f%d= %d;", 
-		   cblock->quant.match->descr->blno,
-		   cblock->fornest, ++*listnrp);
+	  gen_for_val(cblock->fornest);
+	  fprintf (ccode, "= %d;", ++*listnrp);
 	  gotollabel (labdo);
 	  fprintf (ccode, "   case %d:", *listnrp);
 	}
@@ -446,29 +476,27 @@ static forelemgen (re, rex, labcontinue, labdo, labexit, single,
 /******************************************************************************
                                                       FORGEN                 */
 /* Genererer kode for en for l|kke med et antall liste elementer             */
-forgen (re, labcontinue, labdo, labexit)
-     struct EXP *re;
-     int labcontinue, labdo, labexit;
+static int forgen (exp_t *re, int labcontinue, int labdo, int labexit)
 {
   int notlastdefault=FALSE;
-  struct EXP *rex;
+  exp_t *rex;
   int labnext;
 
   int listnr=0;
 
   if (re->right->right->token == MENDSEP)
-    return forelemgen (re, re->right, labcontinue, labdo, labexit, TRUE);
+    return forelemgen (re, re->right, labcontinue, labdo, labexit, TRUE, 0, NULL);
 
-  fprintf (ccode, "((__bs%d *)__lb)->f%d=1;", 
-		  cblock->quant.match->descr->blno,
-		  cblock->fornest);
+  gen_for_val(cblock->fornest);
+  fprintf (ccode, "=1;");
 
   gotollabel (labnext= newllabel ());
   typellabel (labcontinue);
 				
-  fprintf (ccode, "switch (((__bs%d *)__lb)->f%d ){", 
-	   cblock->quant.match->descr->blno,
-	   cblock->fornest);
+  fprintf (ccode, "switch (");
+  gen_for_val(cblock->fornest);
+  fprintf (ccode, " ){"); 
+
   typellabel (labnext);
 
   for (rex = re->right; rex->token != MENDSEP; rex = rex->right)
@@ -485,7 +513,7 @@ forgen (re, labcontinue, labdo, labexit)
 /******************************************************************************
                                                                     FORDOGEN */
 
-fordoGen (sent) struct SENT *sent;
+static void fordo_gen (sent_t *sent)
 {
   int labcontinue, labdo, labexit, iterate;
   if (not_reached == FALSE)
@@ -504,7 +532,7 @@ fordoGen (sent) struct SENT *sent;
 
   typellabel (labdo);
 
-  sentListGen (sent);
+  sent_list_gen (sent, 0);
 
   if (iterate)
     {
@@ -520,7 +548,7 @@ fordoGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                     WHILEGEN */
 
-whileGen (sent) struct SENT *sent;
+static void while_gen (sent_t *sent)
 {
   int labstart, labexit;
   if (not_reached == FALSE)
@@ -535,7 +563,7 @@ whileGen (sent) struct SENT *sent;
   fprintf (ccode, "))");
   gotollabel (labexit= newllabel ());
 
-  sentListGen (sent);
+  sent_list_gen (sent, 0);
 
   if (not_reached == FALSE)
     {
@@ -548,7 +576,7 @@ whileGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                        IFGEN */
 
-ifGen (sent) struct SENT *sent;
+static void if_gen (sent_t *sent)
 {
   int labelse, labexit;
   if (not_reached == FALSE)
@@ -565,13 +593,13 @@ ifGen (sent) struct SENT *sent;
   if (sent->last->token == MTHEN)
     {
       gotollabel (labexit);
-      sentListGen (sent->first);      
+      sent_list_gen (sent->first, 0);      
     }
   else
     {
       gotollabel (labelse= newllabel ());
 
-      sentListGen (sent->first);      
+      sent_list_gen (sent->first, 0);      
 
       if (not_reached == FALSE)
       {
@@ -580,7 +608,7 @@ ifGen (sent) struct SENT *sent;
       }
       typellabel (labelse);
 
-      sentListGen (sent->last);      
+      sent_list_gen (sent->last, 0);      
     }
   if (not_reached == FALSE)
     genline ();
@@ -590,7 +618,7 @@ ifGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                      GOTOGEN */
 
-gotoGen (sent) struct SENT *sent;
+static void goto_gen (sent_t *sent)
 {
   if (not_reached == FALSE)
     genline ();
@@ -604,17 +632,17 @@ gotoGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                     INNERGEN */
 
-innerGen (sent, lab) struct SENT *sent; int lab;
+static void inner_gen (sent_t *sent, int lab)
 {
   genline ();
-  fprintf (ccode, "__rinner(%d);", sent->cblock->quant.plev);
+  fprintf (ccode, "__rinner(%ld);", sent->cblock->quant.plev);
   exitlabel (lab+1);
 }
 
 /******************************************************************************
                                                                     ENTRYGEN */
 
-entryGen (sent) struct SENT *sent;
+static void entry_gen (sent_t *sent)
 {
   typelabel (sent->cblock->ent);
 }
@@ -622,7 +650,7 @@ entryGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                BLOCKENTRYGEN */
 
-blockEntryGen (sent) struct SENT *sent;
+static void block_entry_gen (sent_t *sent)
 {
   typellabel (sent->cblock->ent);
 }
@@ -630,9 +658,9 @@ blockEntryGen (sent) struct SENT *sent;
 /******************************************************************************
                                                            PROCEDUREENTRYGEN */
 
-procedureEntryGen (sent) struct SENT *sent;
+static void procedure_entry_gen (sent_t *sent)
 {
-  struct DECL *rd= sent->cblock->parloc;
+  decl_t *rd= sent->cblock->parloc;
   int i;
 
   typelabel (sent->cblock->ent);
@@ -645,9 +673,9 @@ procedureEntryGen (sent) struct SENT *sent;
 			  ,rd->encl->blno,rd->ident);
 	  fprintf (ccode, ")!=__NULL && (");
 	  if (rd->prefqual->plev >= DEF_PLEV_TAB_SIZE)
-	    fprintf (ccode, "__bp->pp->plev<%d || ",
+	    fprintf (ccode, "__bp->pp->plev<%ld || ",
 			    rd->prefqual->plev);
-	  fprintf (ccode, "__bp->pp->pref[%d]!= ",
+	  fprintf (ccode, "__bp->pp->pref[%ld]!= ",
 			  rd->prefqual->plev);
 	  gen_adr_prot (ccode, rd->prefqual);
 	  fprintf (ccode, "))?(__dhp)__rerror(__errqual):__bp);");
@@ -660,9 +688,9 @@ procedureEntryGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                 ENDSWITCHGEN */
 
-endswitchGen (sent) struct SENT *sent;
+static void endswitch_gen (sent_t *sent)
 {
-  struct EXP *re= sent->exp, *rex;
+  exp_t *re= sent->exp, *rex;
   int i = 1;
   if (not_reached == FALSE)
     genline ();
@@ -696,7 +724,7 @@ endswitchGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                 ENDASSIGNGEN */
 
-endassignGen (sent) struct SENT *sent;
+static void endassign_gen (sent_t *sent)
 {
   if (not_reached == FALSE)
     genline ();
@@ -710,9 +738,9 @@ endassignGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                  ENDARRAYGEN */
 
-endarrayGen (sent) struct SENT *sent;
+static void endarray_gen (sent_t *sent)
 {
-  struct EXP *re= sent->exp, *re1, *re2;
+  exp_t *re= sent->exp, *re1, *re2;
   int i;
   char ifskrevet = FALSE;
 
@@ -834,23 +862,23 @@ endarrayGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                   ENDDECLGEN */
 
-enddeclGen (sent, lab) struct SENT *sent;
+static void enddecl_gen (sent_t *sent, int lab)
 {
   if (not_reached == FALSE)
     genline ();
   else
     not_reached= FALSE;
 
-  fprintf (ccode, "__renddecl(%d);", sent->cblock->quant.plev);
+  fprintf (ccode, "__renddecl(%ld);", sent->cblock->quant.plev);
   exitlabel (lab);
 }
 
 /******************************************************************************
                                                                  ENDLABELGEN */
 
-endlabelGen (sent) struct SENT *sent;
+static void endlabel_gen (sent_t *sent)
 {
-  struct EXP *re= sent->exp;
+  exp_t *re= sent->exp;
   if (not_reached == FALSE)
     genline ();
   else
@@ -872,7 +900,7 @@ endlabelGen (sent) struct SENT *sent;
 
 /******************************************************************************
                                                                  GOTOSTOPGEN */
-gotoStopGen (sent) struct SENT *sent;
+static void goto_stop_gen (sent_t *sent)
 {
   fprintf (ccode, "goto __slutt;");
 }
@@ -881,7 +909,7 @@ gotoStopGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                     THUNKGEN */
 
-thunkGen (sent) struct SENT *sent;
+static void thunk_gen (sent_t *sent)
 {
   int labbypass;
   cblock= sent->cblock;
@@ -914,85 +942,85 @@ thunkGen (sent) struct SENT *sent;
 /******************************************************************************
                                                                      SENTGEN */
 
-void sentGen (sent, lab) struct SENT *sent;
+void sent_gen (sent_t *sent, int lab)
 {
   switch (sent->token)
     {
     case MMODULE:
-      moduleGen (sent);
+      module_gen (sent);
       break;
     case MBLOCK:
-      blockGen (sent);
+      block_gen (sent);
       break;
     case MPRBLOCK:
-      prblockGen (sent);
+      prblock_gen (sent);
       break;
     case MPROCEDURE:
-      procedureGen (sent);
+      procedure_gen (sent);
       break;
     case MCLASS:
-      classGen (sent);
+      class_gen (sent);
       break;
     case MINSPECT:
-      inspectGen (sent);
+      inspect_gen (sent);
       break;
     case MDO:
-      doGen (sent, lab);
+      do_gen (sent, lab);
       break;
     case MWHEN:
-      whenGen (sent, lab);
+      when_gen (sent, lab);
       break;
     case MOTHERWISE:
-      otherwiseGen (sent);
+      otherwise_gen (sent);
       break;
     case MFORDO:
-      fordoGen (sent);
+      fordo_gen (sent);
       break;
     case MWHILE:
-      whileGen (sent);
+      while_gen (sent);
       break;
     case MIF:
-      ifGen (sent);
+      if_gen (sent);
       break;
     case MGOTO:
-      gotoGen (sent);
+      goto_gen (sent);
       break;
     case MINNER:
-      innerGen (sent, lab);
+      inner_gen (sent, lab);
       break;
     case MENTRY:
-      entryGen (sent);
+      entry_gen (sent);
       break;
     case MBLOCKENTRY:
-      blockEntryGen (sent);
+      block_entry_gen (sent);
       break;
     case MPROCEDUREENTRY:
-      procedureEntryGen (sent);
+      procedure_entry_gen (sent);
       break;
     case MENDSWITCH:
-      endswitchGen (sent);
+      endswitch_gen (sent);
       break;
     case MENDASSIGN:
-      endassignGen (sent);
+      endassign_gen (sent);
       break;
     case MENDARRAY:
-      endarrayGen (sent);
+      endarray_gen (sent);
       break;
     case MENDDECL:
-      enddeclGen (sent, lab);
+      enddecl_gen (sent, lab);
       break;
     case MENDLABEL:
-      endlabelGen (sent);
+      endlabel_gen (sent);
       break;
     case MGOTOSTOP:
-      gotoStopGen (sent);
+      goto_stop_gen (sent);
       break;
     case MTHUNKSIMPLEADDRESS:
     case MTHUNKSIMPLEVALUE:
     case MTHUNKLABLE:
     case MTHUNKARRAY:
     case MTHUNKPROCEDURE:
-      thunkGen (sent);
+      thunk_gen (sent);
       break;
     }
 }
