@@ -20,7 +20,7 @@
 
 static int dim;
 /******************************************************************************
-                                                                     SavePar */
+                                                                     SAVEPAR */
 
 /* Denne rutinen saver verdien til en variabel som er brukt som parameter
  * til en av random drawing prosedyrene eller en c-prosedyre.
@@ -29,15 +29,10 @@ static int dim;
 
 static int stackno;
 
-static struct EXP *savepar (ret, re, up, ident, type, first)
-     struct EXP *ret,
-       *re;
-     char up;
-     char *ident;
-     char type;
-     char first;
+static exp_t *savepar (exp_t *ret, exp_t *re, char up, char *ident,
+		       char type, char first, int minval, int minref, int mintxt)
 {
-  struct EXP *rex;
+  exp_t *rex;
 
   if (first) stackno=0;
   
@@ -54,14 +49,18 @@ static struct EXP *savepar (ret, re, up, ident, type, first)
       else if (rex->left == re)
 	{
 	  if (rex->right != NULL)
-	    savepar (ret, rex->right, FALSE, ident, type, FALSE);
-	  savepar (ret, rex, TRUE, ident, type, FALSE);
+	    savepar (ret, rex->right, FALSE, ident, type, FALSE,
+		     minval, minref, mintxt);
+	  savepar (ret, rex, TRUE, ident, type, FALSE,
+		   minval, minref, mintxt);
 	} 
       else
 	{
 	  if (rex->left != NULL)
-	    savepar (ret, rex->left, FALSE, ident, type, FALSE);
-	  savepar (ret, rex, TRUE, ident, type, FALSE);
+	    savepar (ret, rex->left, FALSE, ident, type, FALSE,
+		     minval, minref, mintxt);
+	  savepar (ret, rex, TRUE, ident, type, FALSE,
+		   minval, minref, mintxt);
 	}
     }
   else
@@ -74,20 +73,20 @@ static struct EXP *savepar (ret, re, up, ident, type, first)
 	    ;
 	  else
 	    {
-	      struct EXP *restack1, *restack2, *reconc;
+	      exp_t *restack1, *restack2, *reconc;
 	      
 	      if (stackno == 0)
 		{
 		  switch (type)
 		    {
 		    case TREF:
-		      stackno= findallentry (ret, re, USEDREF);
+		      stackno= findallentry (ret, re, USEDREF, minref);
 		      break;
 		    case TTEXT:
-		      stackno= findallentry (ret, re, USEDTXT);
+		      stackno= findallentry (ret, re, USEDTXT, mintxt);
 		      break;
 		    default:
-		      stackno= findallentry (ret, re, USEDVAL);
+		      stackno= findallentry (ret, re, USEDVAL, minval);
 		      break;
 		    }
 		  
@@ -102,14 +101,13 @@ static struct EXP *savepar (ret, re, up, ident, type, first)
 		    makeexp(rex->type==TTEXT? MREFASSIGNT:MASSIGN, 
 			    restack2=makeexp (MSTACK, NULL,NULL), re);
 		  
-		  restack1->value.entry= restack2->value.ival= stackno;
+		  restack1->value.entry= restack2->value.entry= stackno;
 		  restack1->type= restack2->type= type;
 		  return reconc;
 		}
 	      else
 		{
 		  re->token = MSTACK;
-		  fprintf (ccode, ";");
 		  re->value.entry= stackno;
 		}
 	    }
@@ -117,9 +115,11 @@ static struct EXP *savepar (ret, re, up, ident, type, first)
       else
 	{
 	  if (re->right != NULL)
-	    savepar (ret, re->right, FALSE, ident, type, FALSE);
+	    savepar (ret, re->right, FALSE, ident, type, FALSE,
+		     minval, minref, mintxt);
 	  if (re->left != NULL)
-	    savepar (ret, re->left, FALSE, ident, type, FALSE);
+	    savepar (ret, re->left, FALSE, ident, type, FALSE,
+		     minval, minref, mintxt);
 	}
     }
   return NULL;
@@ -130,9 +130,7 @@ static struct EXP *savepar (ret, re, up, ident, type, first)
 
 char usedentry[STACK_SIZE + 1];
 
-static 
-findsubentry (re)
-     struct EXP *re;
+static void findsubentry (exp_t *re)
 {
   switch (re->token)
     {
@@ -140,13 +138,13 @@ findsubentry (re)
       switch (re->type)
 	{
 	case TREF:
-	  usedentry[re->value.ival] |= USEDREF;
+	  usedentry[re->value.entry] |= USEDREF;
 	  break;
 	case TTEXT:
-	  usedentry[re->value.ival] |= USEDTXT;
+	  usedentry[re->value.entry] |= USEDTXT;
 	  break;
 	default:
-	  usedentry[re->value.ival] |= USEDVAL;
+	  usedentry[re->value.entry] |= USEDVAL;
 	  break;
 	}
       break;
@@ -168,15 +166,11 @@ findsubentry (re)
 /******************************************************************************
                                                            FINDALLENTRY      */
 
-int 
-findallentry (ret, re, type)
-     struct EXP *ret,
-      *re;
-     int type;
+int findallentry (exp_t *ret, exp_t *re, int type, int min)
 {
   int i,
     max = 0;
-  struct EXP *rex;
+  exp_t *rex;
 
   if (is_after_dot(re))
     re = re->up;
@@ -200,29 +194,58 @@ findallentry (ret, re, type)
     }
   if (type & MAXUSED)
     {
-      for (i = 1; i <= STACK_SIZE; i++)
+      for (i = min; i <= STACK_SIZE; i++)
 	if ((usedentry[i] & type) != 0)
 	  max = i;
       return (max);
     }
   else
-    for (i = 1; i <= STACK_SIZE; i++)
+    for (i = min; i <= STACK_SIZE; i++)
       if ((usedentry[i] & type) == 0)
-	return (i);
+	{
+#if ACSTACK_IN_OBJ
+	  block_t *rb;
+	  switch (cblock->quant.kind)
+	    {
+	    case KFOR:
+	    case KINSP:
+	    case KCON:
+	      rb= cblock->quant.match->descr;
+	      break;
+	    default:
+	      rb=cblock;
+	    }
+	  switch (type)
+	    {
+	    case USEDREF:
+	      if (i > rb->maxusedref) rb->maxusedref= i;
+	      break;
+	    case USEDTXT:
+	      if (i > rb->maxusedtxt) rb->maxusedtxt= i;
+	      break;
+	    case USEDVAL:
+	      if (i > rb->maxusedval) rb->maxusedval= i;
+	      break;
+	    }
+#endif	  
+	  return (i);
+	}
   gerror (87);
 }
 
 /******************************************************************************
                                                                  ANT_STACK   */
 
-long ant_stack (ret, re)
-     struct EXP *ret,
-       *re;
+long ant_stack (exp_t *ret, exp_t *re, int minval, int minref, int mintxt)
 {
+#if ACSTACK_IN_OBJ
+  return (0);
+#else
   return 
-    (((long) findallentry (ret, re, USEDVAL | MAXUSED)) << 16 
-     | ((long) findallentry (ret, re, USEDREF | MAXUSED)) << 8 
-     | (findallentry (ret, re, USEDTXT | MAXUSED)));
+    (((long) findallentry (ret, re, USEDVAL | MAXUSED, minval)) << 16 
+     | ((long) findallentry (ret, re, USEDREF | MAXUSED, minref)) << 8 
+     | (findallentry (ret, re, USEDTXT | MAXUSED, mintxt)));
+#endif
 }
 
 /******************************************************************************
@@ -231,13 +254,10 @@ long ant_stack (ret, re)
 /* This routine traverse a expression tree upwards.
  * For every leftside */
 
-static struct EXP * genstack (ret, re, only_pointers)
-     struct EXP *ret,
-      *re;
-     char only_pointers;
+static exp_t *genstack (exp_t *ret, exp_t *re, char only_pointers, int minval, int minref, int mintxt)
 {
   int i;
-  struct EXP *rex, *reconc=NULL;
+  exp_t *rex, *reconc=NULL;
   rex = re->up;
   while (rex != ret & rex->left == re)
     {
@@ -246,8 +266,10 @@ static struct EXP * genstack (ret, re, only_pointers)
     }
   if (rex == ret)
     return reconc;
-  reconc= genstack (ret, rex, only_pointers);
- 
+  reconc= genstack (ret, rex, only_pointers, minval, minref, mintxt);
+
+  if (rex->left == NULL) return reconc;
+
   /* N er alt ovenfor lagt p stakken, og det gjenstr bare  sjekke om
    * denne noden har en ventre-side med noe som m legges p stakken */
 
@@ -298,11 +320,11 @@ static struct EXP * genstack (ret, re, only_pointers)
       { 
 	int entry;
 	int type= rex->left->type;
-	struct EXP *restack;
+	exp_t *restack;
 	switch (rex->left->type)
 	  {
 	  case TREF:
-	    entry= findallentry (ret, rex->left, USEDREF);
+	    entry= findallentry (ret, rex->left, USEDREF, minref);
 	    break;
 	  case TTEXT:
 	    /* Sjekker om det er kall paa en av text-attributt prosedyrene
@@ -311,12 +333,12 @@ static struct EXP * genstack (ret, re, only_pointers)
 	      return reconc;
 	    if (only_pointers && rex->up->token != MVALASSIGNT)
 	      return reconc;
-	    entry= findallentry (ret, rex->left, USEDTXT);
+	    entry= findallentry (ret, rex->left, USEDTXT, mintxt);
 	    break;
 	  default:
 	    if (only_pointers)
 	      return reconc;
-	    entry= findallentry (ret, rex->left, USEDVAL);
+	    entry= findallentry (ret, rex->left, USEDVAL, minval);
 	    break;
 	  }
 
@@ -331,7 +353,7 @@ static struct EXP * genstack (ret, re, only_pointers)
 	if (rex->token == MBOUNDPARSEP && rex->right != re && 	
 	    !only_pointers)	/* sjekk at det er slik at rex->right!=NULL */
 	  {
-	    entry= findallentry (ret, rex->right, USEDVAL);
+	    entry= findallentry (ret, rex->right, USEDVAL, minval);
 	    reconc= concexp (reconc, makeexp(rex->left->type==TTEXT? MREFASSIGNT:MASSIGN,
 					     restack=makeexp (MSTACK, 
 							      NULL,NULL),
@@ -354,9 +376,7 @@ static struct EXP * genstack (ret, re, only_pointers)
  * genvalue() kalles. Brukes i forbindelse med if i uttrykk og i forbindelse
  * med ORELSE og ANDTHEN */
 
-static char 
-workbeforetest (re)
-     struct EXP *re;
+static char workbeforetest (exp_t *re)
 {
   int token;			/* token er deklarert som int fordi
 				 * kompilatoren ga warning om at constant 136 
@@ -380,9 +400,9 @@ workbeforetest (re)
 /******************************************************************************
                                                                   TRANSPARAM */
 
-transparam (re) struct EXP *re;
+static void transparam (exp_t *ret, exp_t *re, int minval, int minref, int mintxt)
 {
-  struct EXP *rex, *rexp, *rey;
+  exp_t *rex, *rexp, *rey;
   char index_is_const = TRUE;
   rexp=re;
   for (rex = re->right; rex->token != MENDSEP; rex = rex->right)
@@ -450,7 +470,14 @@ transparam (re) struct EXP *re;
       else
 	{
 	trcall:
-	  rey= transcall (rex, rex->left);
+#if ACSTACK_IN_OBJ
+	  rey= transcall (rex, rex->left,
+			  findallentry (ret, re, USEDVAL | MAXUSED, minval)+1,
+			  findallentry (ret, re, USEDREF | MAXUSED, minref)+1,
+			  findallentry (ret, re, USEDTXT | MAXUSED, mintxt)+1);
+#else
+	  rey= transcall (rex, rex->left, 1, 1, 1);
+#endif
 	  if (rey!=NULL)
 	    {
 	      rexp->right=makeexp (MSENTCONC, rey, rex);
@@ -465,25 +492,25 @@ transparam (re) struct EXP *re;
 /******************************************************************************
                                                               TRANSCALL      */
 
-struct EXP *transcall (ret, re)
-     struct EXP *ret,
-      *re;
+exp_t *transcall (exp_t *ret, exp_t *re, int minval, int minref, int mintxt)
 {
-  struct EXP *rex, *reconc=NULL;
+  exp_t *rex, *reconc=NULL;
   short entry;
 
   switch (re->token)
     {
     case MNEWARG:
-      transparam (re);
-      reconc= genstack (ret, re, FALSE);
-      re->value.n_of_stack_elements= ant_stack (ret, re);
+      transparam (ret, re, minval, minref, mintxt);
+      reconc= genstack (ret, re, FALSE, minval, minref, mintxt);
+      re->value.n_of_stack_elements= ant_stack (ret, re,
+						minval, minref, mintxt);
       reconc= concexp (reconc, replacenode (&re, MSTACK));
 
       rex= makeexp (MASSIGND, makeexp (MSTACK, NULL, NULL),
 		    makeexp (MEXITARGUMENT, NULL, NULL));
       rex->type= rex->left->type= rex->right->type= TREF;
-      rex->left->value.entry= re->value.entry= findallentry (ret, re, USEDREF);
+      rex->left->value.entry= re->value.entry= 
+	findallentry (ret, re, USEDREF, minref);
       reconc= concexp (reconc, rex);
       break;
     case MPROCARG:
@@ -493,14 +520,17 @@ struct EXP *transcall (ret, re)
 	{
 	case CCNO:
 	  if(is_after_dot(re))
-	    reconc= concexp (reconc, genstack (ret, re->up, FALSE));
+	    reconc= concexp (reconc, genstack (ret, re->up, FALSE,
+					       minval, minref, mintxt));
 	  else
-	    reconc= concexp (reconc, genstack (ret, re, FALSE));
-	  transparam (re);
+	    reconc= concexp (reconc, genstack (ret, re, FALSE,
+					       minval, minref, mintxt));
+	  transparam (ret, re, minval, minref, mintxt);
 	  if (re->rd->categ == CNAME)
 	    {
 	      rex= copytree (re);
-	      rex->value.ival= ant_stack (ret, re);
+	      rex->value.n_of_stack_elements= 
+		ant_stack (ret, re, minval, minref, mintxt);
 	      rex->token= MNAMEREADACESS;
 	      reconc= concexp (reconc, rex);
 	    }
@@ -508,25 +538,31 @@ struct EXP *transcall (ret, re)
 	  switch (re->type)
 	    {
 	    case TREF:
-	      entry= findallentry (ret, re, USEDREF);
+	      entry= findallentry (ret, re, USEDREF, minref);
 	      break;
 	    case TTEXT:
-	      entry= findallentry (ret, re, USEDTXT);
+	      entry= findallentry (ret, re, USEDTXT, mintxt);
 	      break;
 	    case TNOTY:
 	      break;
 	    default:
-	      entry= findallentry (ret, re, USEDVAL);
+	      entry= findallentry (ret, re, USEDVAL, minval);
 	      break;
 	    }
 
-	  re->value.combined_stack.entry=entry;
-
-	  re->value.combined_stack.n_of_stack_elements= ant_stack(ret, re);
+	  re->value.n_of_stack_elements= 
+	    ant_stack(ret, re, minval, minref, mintxt);
 
 	  reconc= concexp (reconc, replacenode (&re, MSTACK));
-	  re->value.entry=entry;
 
+	  if (re->type != TNOTY)
+	    {
+	      rex= makeexp (MASSIGND, makeexp (MSTACK, NULL, NULL),
+			    makeexp (MEXITARGUMENT, NULL, NULL));
+	      rex->type= rex->left->type= rex->right->type= re->type;
+	      rex->left->value.entry= re->value.entry= entry;
+	      reconc= concexp (reconc, rex);
+	    }
 	  break;
 	case CCCPROC:
 	  /* Bare text-prosedyrer som er danger. Resten er  NOTDANGER.
@@ -541,20 +577,27 @@ struct EXP *transcall (ret, re)
 		  rex->left->token == MIDENTIFIER)
 		reconc= concexp (reconc, savepar (ret, re, TRUE, 
 						  rex->left->rd->ident,
-						  rex->left->rd->type, TRUE));
+						  rex->left->rd->type, TRUE,
+						  minval, minref, mintxt));
 	    }
 	  for (rex = re->right; rex->token != MENDSEP; 
 	       rex = rex->right)
-	    reconc= concexp (reconc, transcall (ret, rex->left));
+	    reconc= concexp (reconc, transcall (ret, rex->left, 
+						minval, minref, mintxt));
 	  if (re->type == TTEXT)
 	    {
-	      entry= findallentry (ret, re, USEDTXT);
-	      re->value.combined_stack.entry= entry;
-	      re->value.combined_stack.n_of_stack_elements= 
-		ant_stack (ret, re);
+	      entry= findallentry (ret, re, USEDTXT, mintxt);
+	      re->value.n_of_stack_elements= 
+		ant_stack (ret, re, minval, minref, mintxt);
 
 	      reconc= concexp (reconc, replacenode (&re, MSTACK));
-	      re->value.entry=entry;
+	      re->value.entry= entry;
+
+	      rex= makeexp (MASSIGND, makeexp (MSTACK, NULL, NULL),
+			    makeexp (MEXITARGUMENT, NULL, NULL));
+	      rex->type= rex->left->type= rex->right->type= re->type;
+	      rex->left->value.entry= re->value.entry= entry;
+	      reconc= concexp (reconc, rex);
 	    }
 	  break;
 	case CCFILEDANGER:
@@ -566,12 +609,15 @@ struct EXP *transcall (ret, re)
 	  if (re->danger)
 	    {
 	      if (is_after_dot (re) && re->up->left->type == TTEXT)
-		reconc= genstack (ret, re->up->left, FALSE);
+		reconc= genstack (ret, re->up->left, FALSE,
+				  minval, minref, mintxt);
 	      else
-		reconc= genstack (ret, re, FALSE);
+		reconc= genstack (ret, re, FALSE,
+				  minval, minref, mintxt);
 
 	      for (rex = re->right; rex->token != MENDSEP; rex = rex->right)
-		reconc= concexp (reconc, transcall (ret, rex->left));
+		reconc= concexp (reconc, transcall (ret, rex->left,
+						    minval, minref, mintxt));
       
 	      if (re->rd->descr->codeclass == CCRANDOMRUTDANGER)
 		{
@@ -579,47 +625,60 @@ struct EXP *transcall (ret, re)
 		  /* er en NAME parameter. Det skal sjekkes om */
 		  /* denne variabelen er brukt flere ganger i uttrykket */
 		  for (rex= re; rex->right->token != MENDSEP; rex= rex->right);
-		  reconc= concexp (reconc, savepar (ret, re, 
-						    rex->left->rd, TRUE));
+		  reconc= concexp (reconc, savepar (ret, re, TRUE,  /* TBD IS THIS CORRECT, and the following */
+						    rex->left->rd->ident,
+						    rex->left->rd->type, TRUE,
+						    minval, minref, mintxt));
 		}
 
 	      switch (re->type)
 		{
 		case TREF:
-		  entry= re->value.combined_stack.entry= 
-		    findallentry (ret, re, USEDREF);
+		  entry= findallentry (ret, re, USEDREF, minref);
 		  break;
 		case TTEXT:
-		  entry= re->value.combined_stack.entry= 
-		    findallentry (ret, re, USEDTXT);
+		  entry= findallentry (ret, re, USEDTXT, mintxt);
 		  break;
 		case TNOTY:
 		  break;
 		default:
-		  entry= re->value.combined_stack.entry= 
-		    findallentry (ret, re, USEDVAL);
+		  entry= findallentry (ret, re, USEDVAL, minval);
 		  break;
 		}
 	      
-	      re->value.combined_stack.n_of_stack_elements= 
-		ant_stack (ret, re);
+	      re->value.n_of_stack_elements= 
+		ant_stack (ret, re, minval, minref, mintxt);
 
-	      reconc= concexp (reconc, replacenode (&re, MSTACK));
-	      re->value.entry=entry;
+	      if (re->type == TNOTY)
+		{
+		  reconc= concexp (reconc, replacenode (&re, MSTACK));
+		  re->value.entry= entry;
+		}
+	      else
+		{
+		  rex= makeexp (MASSIGND, makeexp (MSTACK, NULL, NULL),
+				replacenode (&re, MSTACK));
+		  rex->type= rex->left->type= rex->right->type= re->type;
+		  rex->left->value.entry= re->value.entry= entry;
+		  reconc= concexp (reconc, rex);
+		}
 	      break;
 	    }
 	  /* Ingen break her */
 	default:
 	  for (rex = re->right; rex->token != MENDSEP; rex = rex->right)
-	    reconc= concexp (reconc,transcall (ret, rex->left));
+	    reconc= concexp (reconc,transcall (ret, rex->left,
+					       minval, minref, mintxt));
 	  break;
 	}
       break;
     case MASSIGNR:
       if (re->danger)
-	reconc= genstack (ret, re, TRUE);
-      reconc= concexp (reconc, transcall (ret, re->left));
-      reconc= concexp (reconc, transcall (ret, re->right));
+	reconc= genstack (ret, re, TRUE, minval, minref, mintxt);
+      reconc= concexp (reconc, transcall (ret, re->left,
+					  minval, minref, mintxt));
+      reconc= concexp (reconc, transcall (ret, re->right,
+					  minval, minref, mintxt));
       if ((rex = re->left)->token == MNAMEADR && rex->type == TREF)
 	{
 	  reconc= concexp (reconc, makeexp(MINSTRONGEST,copytree(re->left), 
@@ -628,15 +687,18 @@ struct EXP *transcall (ret, re)
       break;
     case MREFASSIGNT:
       if (re->danger)
-	reconc= genstack (ret, re, TRUE);
-      reconc= concexp (reconc, transcall (ret, re->left));
-      reconc= concexp (reconc, transcall (ret, re->right));
+	reconc= genstack (ret, re, TRUE, minval, minref, mintxt);
+      reconc= concexp (reconc, transcall (ret, re->left,
+					  minval, minref, mintxt));
+      reconc= concexp (reconc, transcall (ret, re->right,
+					  minval, minref, mintxt));
       break;
     case MARRAYARG:
-      reconc= genstack (ret, re, FALSE);
+      reconc= genstack (ret, re, FALSE, minval, minref, mintxt);
       if (re->type == TLABEL)
 	{
-	  reconc= concexp (reconc, transcall (ret, re->right->left));
+	  reconc= concexp (reconc, transcall (ret, re->right->left,
+					      minval, minref, mintxt));
 	  break;
 	}
 
@@ -645,14 +707,16 @@ struct EXP *transcall (ret, re)
       re->left= makeexp (MARRAYADR, NULL, NULL);
       re->left->up = re;
       re->left->value.stack.ref_entry= re->value.stack.ref_entry= 
-	findallentry (ret, re, USEDREF);
+	findallentry (ret, re, USEDREF, minref);
       re->left->value.stack.val_entry= re->value.stack.val_entry= 
-	findallentry (ret, re, USEDVAL);
+	findallentry (ret, re, USEDVAL, minval);
       if (re->rd->categ == CNAME)
 	{
-	  reconc= concexp (reconc, genstack (ret, re, FALSE));
+	  reconc= concexp (reconc, genstack (ret, re, FALSE,
+					     minval, minref, mintxt));
 	  rex= copytree (re);
-	  rex->value.n_of_stack_elements= ant_stack (ret, re);
+	  rex->value.n_of_stack_elements= ant_stack (ret, re,
+						     minval, minref, mintxt);
 	  rex->token= MNAMEREADACESS;
 	  reconc= concexp (reconc, rex);
 
@@ -662,16 +726,20 @@ struct EXP *transcall (ret, re)
 	  rex->left->value.entry= re->value.stack.ref_entry;
 	  reconc= concexp (reconc, rex);
 	}
-      reconc= concexp (reconc, transcall (ret, re->right));
+      reconc= concexp (reconc, transcall (ret, re->right,
+					  minval, minref, mintxt));
       re->left= NULL;
+
       reconc= concexp (reconc, replacenode (&re, MARRAYADR));
       break;
     case MIDENTIFIER:
       if (re->rd->categ == CNAME)
 	{
-	  reconc= concexp (reconc, genstack (ret, re, FALSE));
+	  reconc= concexp (reconc, genstack (ret, re, FALSE,
+					     minval, minref, mintxt));
 	  rex= copytree (re);
-	  rex->value.n_of_stack_elements= ant_stack (ret, re);
+	  rex->value.n_of_stack_elements= ant_stack (ret, re,
+						     minval, minref, mintxt);
 
 	  if (((re->up->token == MASSIGN || re->up->token == MASSIGNR ||
 		re->up->token == MVALASSIGNT || re->up->token == MREFASSIGNT)
@@ -687,14 +755,14 @@ struct EXP *transcall (ret, re)
 			    makeexp (MEXITARGUMENT, NULL, NULL));
 	      rex->type= rex->left->type= rex->right->type= TREF;
 	      rex->left->value.entry= re->value.stack.ref_entry= 
-		findallentry (ret, re, USEDREF);
+		findallentry (ret, re, USEDREF, minref);
 	      reconc= concexp (reconc, rex);
 
 	      rex= makeexp (MASSIGND, makeexp (MSTACK, NULL, NULL),
 			    makeexp (MEXITARGUMENT, NULL, NULL));
 	      rex->type= rex->left->type= rex->right->type= TINTG;
 	      rex->left->value.entry= re->value.stack.val_entry= 
-		findallentry (ret, re, USEDVAL);
+		findallentry (ret, re, USEDVAL, minval);
 	      reconc= concexp (reconc, rex);
 
 	      re->token = MNAMEADR;
@@ -712,11 +780,11 @@ struct EXP *transcall (ret, re)
 		{
 		  rex= copytree (re);
 		  rex->value.stack.val_entry= re->value.stack.val_entry= 
-		    findallentry (ret, re, USEDVAL);
+		    findallentry (ret, re, USEDVAL, minval);
 		  rex->value.stack.ref_entry= re->value.stack.ref_entry= 
-		    findallentry (ret, re, USEDREF);
+		    findallentry (ret, re, USEDREF, minref);
 		  rex->value.stack.txt_entry= re->value.stack.txt_entry= 
-		    findallentry (ret, re, USEDTXT);
+		    findallentry (ret, re, USEDTXT, mintxt);
 		  rex->token= MNAMEREADTEXT;
 		  reconc= concexp (reconc, rex);
 
@@ -728,7 +796,8 @@ struct EXP *transcall (ret, re)
 				makeexp (MEXITARGUMENT, NULL, NULL));
 		  rex->type= rex->left->type= rex->right->type= re->type;
 		  rex->left->value.entry= re->value.entry= 
-		    findallentry (ret, re, re->type == TREF?USEDREF:USEDVAL);
+		    findallentry (ret, re, re->type == TREF?USEDREF:USEDVAL,
+				  re->type == TREF?minref:minval);
 		  reconc= concexp (reconc, rex);
 		  re->token = MSTACK;
 		}
@@ -737,56 +806,69 @@ struct EXP *transcall (ret, re)
       break;
     case MANDTHENE:
     case MORELSEE:
-      reconc= transcall (ret, re->left);
+      reconc= transcall (ret, re->left, minval, minref, mintxt);
 
       if (workbeforetest (re->right))
 	{
 	  int i;
-	  reconc= concexp (reconc, genstack (ret, re, FALSE));
+	  reconc= concexp (reconc, genstack (ret, re, FALSE,
+					     minval, minref, mintxt));
 	  rex= makeexp (re->token == MANDTHENE ? MANDTHEN : MORELSE, 
-			copytree (re->left), transcall (ret, re->right));
+			copytree (re->left), transcall (ret, re->right,
+							minval, minref, 
+							mintxt));
 	  rex->type= re->type;
 	  reconc= concexp (reconc, rex);
 	}
       break;
     case MIFE:
-      reconc= transcall (ret, re->left);
+      reconc= transcall (ret, re->left, minval, minref, mintxt);
       if (workbeforetest (re->right))
 	{
-	  reconc= concexp (reconc, genstack (ret, re->right, FALSE));
-	  rex= makeexp (MIF, re->left, transcall (ret, re->right));
+	  reconc= concexp (reconc, genstack (ret, re->right, FALSE,
+					     minval, minref, mintxt));
+	  rex= makeexp (MIF, re->left, transcall (ret, re->right, 
+						  minval, minref, mintxt));
 	  rex->type= re->type;
 	  rex->qual= re->qual;
 	  reconc= concexp (reconc, rex);
 	}
       break;
     case MELSEE:
-      rex= makeexp (MELSE, transcall (ret, re->left), 
-		    transcall (ret, re->right));
+      rex= makeexp (MELSE, transcall (ret, re->left, minval, minref, mintxt), 
+		    transcall (ret, re->right, minval, minref, mintxt));
       rex->type= re->type;
       rex->qual= re->qual;
       reconc= rex;
       break;
     case MCONC:
-      reconc= transcall (ret, re->left);
-      reconc= concexp (reconc, transcall (ret, re->right));
+      reconc= transcall (ret, re->left, minval, minref, mintxt);
+      reconc= concexp (reconc, transcall (ret, re->right,
+					  minval, minref, mintxt));
 
-      re->value.combined_stack.entry= findallentry (ret, re, USEDTXT);
-      re->value.combined_stack.n_of_stack_elements= ant_stack (ret, re);
+      re->value.n_of_stack_elements= 
+	ant_stack  (ret, re, minval, minref, mintxt);
       rex= newexp ();
       *rex= *re;
       rex->left->up= rex->right->up= rex;
       reconc= concexp (reconc, rex);
 
-      re->value.entry= rex->value.combined_stack.entry;
+      rex= makeexp (MASSIGND, makeexp (MSTACK, NULL, NULL),
+		    makeexp (MEXITARGUMENT, NULL, NULL));
+      rex->type= rex->left->type= rex->right->type= TTEXT;
+      rex->left->value.entry= re->value.entry= 
+	findallentry (ret, re, USEDTXT, mintxt);
+      reconc= concexp (reconc, rex);
+
       re->token = MSTACK;
       re->left = re->right = NULL;
       break;
     default:
       if (re->left != NULL)
-	reconc= transcall (ret, re->left);
+	reconc= transcall (ret, re->left, minval, minref, mintxt);
       if (re->right != NULL)
-	reconc= concexp (reconc, transcall (ret, re->right));
+	reconc= concexp (reconc, transcall (ret, re->right,
+					    minval, minref, mintxt));
     }
   return reconc;
 }
